<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'bewsa: adult, adult, ton ċar tal-ġilda, u ton medju-ċar tal-ġilda',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'bewsa: adult, adult, ton ċar tal-ġilda, u ton medju tal-ġilda',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'bewsa: adult, adult, ton ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'bewsa: adult, adult, ton ċar tal-ġilda, u ton skur tal-ġilda',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'bewsa: adult, adult, ton medju-ċar tal-ġilda, u ton ċar tal-ġilda',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'bewsa: adult, adult, ton medju-ċar tal-ġilda, u ton medju tal-ġilda',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'bewsa: adult, adult, ton medju-ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'bewsa: adult, adult, ton medju-ċar tal-ġilda, u ton skur tal-ġilda',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'bewsa: adult, adult, ton medju tal-ġilda, u ton ċar tal-ġilda',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'bewsa: adult, adult, ton medju tal-ġilda, u ton medju-ċar tal-ġilda',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'bewsa: adult, adult, ton medju tal-ġilda, u ton medju-skur tal-ġilda',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'bewsa: adult, adult, ton medju tal-ġilda, u ton skur tal-ġilda',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'bewsa: adult, adult, ton medju-skur tal-ġilda, u ton ċar tal-ġilda',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'bewsa: adult, adult, ton medju-skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'bewsa: adult, adult, ton medju-skur tal-ġilda, u ton medju tal-ġilda',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'bewsa: adult, adult, ton medju-skur tal-ġilda, u ton skur tal-ġilda',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'bewsa: adult, adult, ton skur tal-ġilda, u ton ċar tal-ġilda',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'bewsa: adult, adult, ton skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'bewsa: adult, adult, ton skur tal-ġilda, u ton medju tal-ġilda',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'bewsa: adult, adult, ton skur tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏻‍❤‍💋‍👨🏻' => 'bewsa: raġel, raġel, u ton ċar tal-ġilda',
    '👨🏻‍❤‍💋‍👨🏼' => 'bewsa: raġel, raġel, ton ċar tal-ġilda, u ton medju-ċar tal-ġilda',
    '👨🏻‍❤‍💋‍👨🏽' => 'bewsa: raġel, raġel, ton ċar tal-ġilda, u ton medju tal-ġilda',
    '👨🏻‍❤‍💋‍👨🏾' => 'bewsa: raġel, raġel, ton ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏻‍❤‍💋‍👨🏿' => 'bewsa: raġel, raġel, ton ċar tal-ġilda, u ton skur tal-ġilda',
    '👨🏼‍❤‍💋‍👨🏻' => 'bewsa: raġel, raġel, ton medju-ċar tal-ġilda, u ton ċar tal-ġilda',
    '👨🏼‍❤‍💋‍👨🏼' => 'bewsa: raġel, raġel, u ton medju-ċar tal-ġilda',
    '👨🏼‍❤‍💋‍👨🏽' => 'bewsa: raġel, raġel, ton medju-ċar tal-ġilda, u ton medju tal-ġilda',
    '👨🏼‍❤‍💋‍👨🏾' => 'bewsa: raġel, raġel, ton medju-ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏼‍❤‍💋‍👨🏿' => 'bewsa: raġel, raġel, ton medju-ċar tal-ġilda, u ton skur tal-ġilda',
    '👨🏽‍❤‍💋‍👨🏻' => 'bewsa: raġel, raġel, ton medju tal-ġilda, u ton ċar tal-ġilda',
    '👨🏽‍❤‍💋‍👨🏼' => 'bewsa: raġel, raġel, ton medju tal-ġilda, u ton medju-ċar tal-ġilda',
    '👨🏽‍❤‍💋‍👨🏽' => 'bewsa: raġel, raġel, u ton medju tal-ġilda',
    '👨🏽‍❤‍💋‍👨🏾' => 'bewsa: raġel, raġel, ton medju tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏽‍❤‍💋‍👨🏿' => 'bewsa: raġel, raġel, ton medju tal-ġilda, u ton skur tal-ġilda',
    '👨🏾‍❤‍💋‍👨🏻' => 'bewsa: raġel, raġel, ton medju-skur tal-ġilda, u ton ċar tal-ġilda',
    '👨🏾‍❤‍💋‍👨🏼' => 'bewsa: raġel, raġel, ton medju-skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👨🏾‍❤‍💋‍👨🏽' => 'bewsa: raġel, raġel, ton medju-skur tal-ġilda, u ton medju tal-ġilda',
    '👨🏾‍❤‍💋‍👨🏾' => 'bewsa: raġel, raġel, u ton medju-skur tal-ġilda',
    '👨🏾‍❤‍💋‍👨🏿' => 'bewsa: raġel, raġel, ton medju-skur tal-ġilda, u ton skur tal-ġilda',
    '👨🏿‍❤‍💋‍👨🏻' => 'bewsa: raġel, raġel, ton skur tal-ġilda, u ton ċar tal-ġilda',
    '👨🏿‍❤‍💋‍👨🏼' => 'bewsa: raġel, raġel, ton skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👨🏿‍❤‍💋‍👨🏽' => 'bewsa: raġel, raġel, ton skur tal-ġilda, u ton medju tal-ġilda',
    '👨🏿‍❤‍💋‍👨🏾' => 'bewsa: raġel, raġel, ton skur tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏿‍❤‍💋‍👨🏿' => 'bewsa: raġel, raġel, u ton skur tal-ġilda',
    '👩🏻‍❤‍💋‍👨🏻' => 'bewsa: mara, raġel, u ton ċar tal-ġilda',
    '👩🏻‍❤‍💋‍👨🏼' => 'bewsa: mara, raġel, ton ċar tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏻‍❤‍💋‍👨🏽' => 'bewsa: mara, raġel, ton ċar tal-ġilda, u ton medju tal-ġilda',
    '👩🏻‍❤‍💋‍👨🏾' => 'bewsa: mara, raġel, ton ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏻‍❤‍💋‍👨🏿' => 'bewsa: mara, raġel, ton ċar tal-ġilda, u ton skur tal-ġilda',
    '👩🏼‍❤‍💋‍👨🏻' => 'bewsa: mara, raġel, ton medju-ċar tal-ġilda, u ton ċar tal-ġilda',
    '👩🏼‍❤‍💋‍👨🏼' => 'bewsa: mara, raġel, u ton medju-ċar tal-ġilda',
    '👩🏼‍❤‍💋‍👨🏽' => 'bewsa: mara, raġel, ton medju-ċar tal-ġilda, u ton medju tal-ġilda',
    '👩🏼‍❤‍💋‍👨🏾' => 'bewsa: mara, raġel, ton medju-ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏼‍❤‍💋‍👨🏿' => 'bewsa: mara, raġel, ton medju-ċar tal-ġilda, u ton skur tal-ġilda',
    '👩🏽‍❤‍💋‍👨🏻' => 'bewsa: mara, raġel, ton medju tal-ġilda, u ton ċar tal-ġilda',
    '👩🏽‍❤‍💋‍👨🏼' => 'bewsa: mara, raġel, ton medju tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏽‍❤‍💋‍👨🏽' => 'bewsa: mara, raġel, u ton medju tal-ġilda',
    '👩🏽‍❤‍💋‍👨🏾' => 'bewsa: mara, raġel, ton medju tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏽‍❤‍💋‍👨🏿' => 'bewsa: mara, raġel, ton medju tal-ġilda, u ton skur tal-ġilda',
    '👩🏾‍❤‍💋‍👨🏻' => 'bewsa: mara, raġel, ton medju-skur tal-ġilda, u ton ċar tal-ġilda',
    '👩🏾‍❤‍💋‍👨🏼' => 'bewsa: mara, raġel, ton medju-skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏾‍❤‍💋‍👨🏽' => 'bewsa: mara, raġel, ton medju-skur tal-ġilda, u ton medju tal-ġilda',
    '👩🏾‍❤‍💋‍👨🏾' => 'bewsa: mara, raġel, u ton medju-skur tal-ġilda',
    '👩🏾‍❤‍💋‍👨🏿' => 'bewsa: mara, raġel, ton medju-skur tal-ġilda, u ton skur tal-ġilda',
    '👩🏿‍❤‍💋‍👨🏻' => 'bewsa: mara, raġel, ton skur tal-ġilda, u ton ċar tal-ġilda',
    '👩🏿‍❤‍💋‍👨🏼' => 'bewsa: mara, raġel, ton skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏿‍❤‍💋‍👨🏽' => 'bewsa: mara, raġel, ton skur tal-ġilda, u ton medju tal-ġilda',
    '👩🏿‍❤‍💋‍👨🏾' => 'bewsa: mara, raġel, ton skur tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏿‍❤‍💋‍👨🏿' => 'bewsa: mara, raġel, u ton skur tal-ġilda',
    '👩🏻‍❤‍💋‍👩🏻' => 'bewsa: mara, mara, u ton ċar tal-ġilda',
    '👩🏻‍❤‍💋‍👩🏼' => 'bewsa: mara, mara, ton ċar tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏻‍❤‍💋‍👩🏽' => 'bewsa: mara, mara, ton ċar tal-ġilda, u ton medju tal-ġilda',
    '👩🏻‍❤‍💋‍👩🏾' => 'bewsa: mara, mara, ton ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏻‍❤‍💋‍👩🏿' => 'bewsa: mara, mara, ton ċar tal-ġilda, u ton skur tal-ġilda',
    '👩🏼‍❤‍💋‍👩🏻' => 'bewsa: mara, mara, ton medju-ċar tal-ġilda, u ton ċar tal-ġilda',
    '👩🏼‍❤‍💋‍👩🏼' => 'bewsa: mara, mara, u ton medju-ċar tal-ġilda',
    '👩🏼‍❤‍💋‍👩🏽' => 'bewsa: mara, mara, ton medju-ċar tal-ġilda, u ton medju tal-ġilda',
    '👩🏼‍❤‍💋‍👩🏾' => 'bewsa: mara, mara, ton medju-ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏼‍❤‍💋‍👩🏿' => 'bewsa: mara, mara, ton medju-ċar tal-ġilda, u ton skur tal-ġilda',
    '👩🏽‍❤‍💋‍👩🏻' => 'bewsa: mara, mara, ton medju tal-ġilda, u ton ċar tal-ġilda',
    '👩🏽‍❤‍💋‍👩🏼' => 'bewsa: mara, mara, ton medju tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏽‍❤‍💋‍👩🏽' => 'bewsa: mara, mara, u ton medju tal-ġilda',
    '👩🏽‍❤‍💋‍👩🏾' => 'bewsa: mara, mara, ton medju tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏽‍❤‍💋‍👩🏿' => 'bewsa: mara, mara, ton medju tal-ġilda, u ton skur tal-ġilda',
    '👩🏾‍❤‍💋‍👩🏻' => 'bewsa: mara, mara, ton medju-skur tal-ġilda, u ton ċar tal-ġilda',
    '👩🏾‍❤‍💋‍👩🏼' => 'bewsa: mara, mara, ton medju-skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏾‍❤‍💋‍👩🏽' => 'bewsa: mara, mara, ton medju-skur tal-ġilda, u ton medju tal-ġilda',
    '👩🏾‍❤‍💋‍👩🏾' => 'bewsa: mara, mara, u ton medju-skur tal-ġilda',
    '👩🏾‍❤‍💋‍👩🏿' => 'bewsa: mara, mara, ton medju-skur tal-ġilda, u ton skur tal-ġilda',
    '👩🏿‍❤‍💋‍👩🏻' => 'bewsa: mara, mara, ton skur tal-ġilda, u ton ċar tal-ġilda',
    '👩🏿‍❤‍💋‍👩🏼' => 'bewsa: mara, mara, ton skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏿‍❤‍💋‍👩🏽' => 'bewsa: mara, mara, ton skur tal-ġilda, u ton medju tal-ġilda',
    '👩🏿‍❤‍💋‍👩🏾' => 'bewsa: mara, mara, ton skur tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏿‍❤‍💋‍👩🏿' => 'bewsa: mara, mara, u ton skur tal-ġilda',
    '🧑🏻‍🫯‍🧑🏼' => 'persuna jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '🧑🏻‍🫯‍🧑🏽' => 'persuna jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju tal-ġilda',
    '🧑🏻‍🫯‍🧑🏾' => 'persuna jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '🧑🏻‍🫯‍🧑🏿' => 'persuna jagħmlu r-wrestling: ton ċar tal-ġilda u ton skur tal-ġilda',
    '🧑🏼‍🫯‍🧑🏻' => 'persuna jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '🧑🏼‍🫯‍🧑🏽' => 'persuna jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '🧑🏼‍🫯‍🧑🏾' => 'persuna jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '🧑🏼‍🫯‍🧑🏿' => 'persuna jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '🧑🏽‍🫯‍🧑🏻' => 'persuna jagħmlu r-wrestling: ton medju tal-ġilda u ton ċar tal-ġilda',
    '🧑🏽‍🫯‍🧑🏼' => 'persuna jagħmlu r-wrestling: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '🧑🏽‍🫯‍🧑🏾' => 'persuna jagħmlu r-wrestling: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '🧑🏽‍🫯‍🧑🏿' => 'persuna jagħmlu r-wrestling: ton medju tal-ġilda u ton skur tal-ġilda',
    '🧑🏾‍🫯‍🧑🏻' => 'persuna jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '🧑🏾‍🫯‍🧑🏼' => 'persuna jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '🧑🏾‍🫯‍🧑🏽' => 'persuna jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '🧑🏾‍🫯‍🧑🏿' => 'persuna jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '🧑🏿‍🫯‍🧑🏻' => 'persuna jagħmlu r-wrestling: ton skur tal-ġilda u ton ċar tal-ġilda',
    '🧑🏿‍🫯‍🧑🏼' => 'persuna jagħmlu r-wrestling: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '🧑🏿‍🫯‍🧑🏽' => 'persuna jagħmlu r-wrestling: ton skur tal-ġilda u ton medju tal-ġilda',
    '🧑🏿‍🫯‍🧑🏾' => 'persuna jagħmlu r-wrestling: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '🧑🏻‍❤‍🧑🏼' => 'koppja b’qalb: adult, adult, ton ċar tal-ġilda, u ton medju-ċar tal-ġilda',
    '🧑🏻‍❤‍🧑🏽' => 'koppja b’qalb: adult, adult, ton ċar tal-ġilda, u ton medju tal-ġilda',
    '🧑🏻‍❤‍🧑🏾' => 'koppja b’qalb: adult, adult, ton ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '🧑🏻‍❤‍🧑🏿' => 'koppja b’qalb: adult, adult, ton ċar tal-ġilda, u ton skur tal-ġilda',
    '🧑🏼‍❤‍🧑🏻' => 'koppja b’qalb: adult, adult, ton medju-ċar tal-ġilda, u ton ċar tal-ġilda',
    '🧑🏼‍❤‍🧑🏽' => 'koppja b’qalb: adult, adult, ton medju-ċar tal-ġilda, u ton medju tal-ġilda',
    '🧑🏼‍❤‍🧑🏾' => 'koppja b’qalb: adult, adult, ton medju-ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '🧑🏼‍❤‍🧑🏿' => 'koppja b’qalb: adult, adult, ton medju-ċar tal-ġilda, u ton skur tal-ġilda',
    '🧑🏽‍❤‍🧑🏻' => 'koppja b’qalb: adult, adult, ton medju tal-ġilda, u ton ċar tal-ġilda',
    '🧑🏽‍❤‍🧑🏼' => 'koppja b’qalb: adult, adult, ton medju tal-ġilda, u ton medju-ċar tal-ġilda',
    '🧑🏽‍❤‍🧑🏾' => 'koppja b’qalb: adult, adult, ton medju tal-ġilda, u ton medju-skur tal-ġilda',
    '🧑🏽‍❤‍🧑🏿' => 'koppja b’qalb: adult, adult, ton medju tal-ġilda, u ton skur tal-ġilda',
    '🧑🏾‍❤‍🧑🏻' => 'koppja b’qalb: adult, adult, ton medju-skur tal-ġilda, u ton ċar tal-ġilda',
    '🧑🏾‍❤‍🧑🏼' => 'koppja b’qalb: adult, adult, ton medju-skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '🧑🏾‍❤‍🧑🏽' => 'koppja b’qalb: adult, adult, ton medju-skur tal-ġilda, u ton medju tal-ġilda',
    '🧑🏾‍❤‍🧑🏿' => 'koppja b’qalb: adult, adult, ton medju-skur tal-ġilda, u ton skur tal-ġilda',
    '🧑🏿‍❤‍🧑🏻' => 'koppja b’qalb: adult, adult, ton skur tal-ġilda, u ton ċar tal-ġilda',
    '🧑🏿‍❤‍🧑🏼' => 'koppja b’qalb: adult, adult, ton skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '🧑🏿‍❤‍🧑🏽' => 'koppja b’qalb: adult, adult, ton skur tal-ġilda, u ton medju tal-ġilda',
    '🧑🏿‍❤‍🧑🏾' => 'koppja b’qalb: adult, adult, ton skur tal-ġilda, u ton medju-skur tal-ġilda',
    '🧑🏻‍🐰‍🧑🏼' => 'persuni b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '🧑🏻‍🐰‍🧑🏽' => 'persuni b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju tal-ġilda',
    '🧑🏻‍🐰‍🧑🏾' => 'persuni b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '🧑🏻‍🐰‍🧑🏿' => 'persuni b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton skur tal-ġilda',
    '🧑🏼‍🐰‍🧑🏻' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '🧑🏼‍🐰‍🧑🏽' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '🧑🏼‍🐰‍🧑🏾' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '🧑🏼‍🐰‍🧑🏿' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '🧑🏽‍🐰‍🧑🏻' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton ċar tal-ġilda',
    '🧑🏽‍🐰‍🧑🏼' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '🧑🏽‍🐰‍🧑🏾' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '🧑🏽‍🐰‍🧑🏿' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton skur tal-ġilda',
    '🧑🏾‍🐰‍🧑🏻' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '🧑🏾‍🐰‍🧑🏼' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '🧑🏾‍🐰‍🧑🏽' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '🧑🏾‍🐰‍🧑🏿' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '🧑🏿‍🐰‍🧑🏻' => 'persuni b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton ċar tal-ġilda',
    '🧑🏿‍🐰‍🧑🏼' => 'persuni b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '🧑🏿‍🐰‍🧑🏽' => 'persuni b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju tal-ġilda',
    '🧑🏿‍🐰‍🧑🏾' => 'persuni b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏻‍🫯‍👨🏼' => 'irġiel jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏻‍🫯‍👨🏽' => 'irġiel jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju tal-ġilda',
    '👨🏻‍🫯‍👨🏾' => 'irġiel jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏻‍🫯‍👨🏿' => 'irġiel jagħmlu r-wrestling: ton ċar tal-ġilda u ton skur tal-ġilda',
    '👨🏼‍🫯‍👨🏻' => 'irġiel jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '👨🏼‍🫯‍👨🏽' => 'irġiel jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '👨🏼‍🫯‍👨🏾' => 'irġiel jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏼‍🫯‍👨🏿' => 'irġiel jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '👨🏽‍🫯‍👨🏻' => 'irġiel jagħmlu r-wrestling: ton medju tal-ġilda u ton ċar tal-ġilda',
    '👨🏽‍🫯‍👨🏼' => 'irġiel jagħmlu r-wrestling: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏽‍🫯‍👨🏾' => 'irġiel jagħmlu r-wrestling: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏽‍🫯‍👨🏿' => 'irġiel jagħmlu r-wrestling: ton medju tal-ġilda u ton skur tal-ġilda',
    '👨🏾‍🫯‍👨🏻' => 'irġiel jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '👨🏾‍🫯‍👨🏼' => 'irġiel jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏾‍🫯‍👨🏽' => 'irġiel jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '👨🏾‍🫯‍👨🏿' => 'irġiel jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '👨🏿‍🫯‍👨🏻' => 'irġiel jagħmlu r-wrestling: ton skur tal-ġilda u ton ċar tal-ġilda',
    '👨🏿‍🫯‍👨🏼' => 'irġiel jagħmlu r-wrestling: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏿‍🫯‍👨🏽' => 'irġiel jagħmlu r-wrestling: ton skur tal-ġilda u ton medju tal-ġilda',
    '👨🏿‍🫯‍👨🏾' => 'irġiel jagħmlu r-wrestling: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏻‍❤‍👨🏻' => 'koppja b’qalb: raġel, raġel, u ton ċar tal-ġilda',
    '👨🏻‍❤‍👨🏼' => 'koppja b’qalb: raġel, raġel, ton ċar tal-ġilda, u ton medju-ċar tal-ġilda',
    '👨🏻‍❤‍👨🏽' => 'koppja b’qalb: raġel, raġel, ton ċar tal-ġilda, u ton medju tal-ġilda',
    '👨🏻‍❤‍👨🏾' => 'koppja b’qalb: raġel, raġel, ton ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏻‍❤‍👨🏿' => 'koppja b’qalb: raġel, raġel, ton ċar tal-ġilda, u ton skur tal-ġilda',
    '👨🏼‍❤‍👨🏻' => 'koppja b’qalb: raġel, raġel, ton medju-ċar tal-ġilda, u ton ċar tal-ġilda',
    '👨🏼‍❤‍👨🏼' => 'koppja b’qalb: raġel, raġel, u ton medju-ċar tal-ġilda',
    '👨🏼‍❤‍👨🏽' => 'koppja b’qalb: raġel, raġel, ton medju-ċar tal-ġilda, u ton medju tal-ġilda',
    '👨🏼‍❤‍👨🏾' => 'koppja b’qalb: raġel, raġel, ton medju-ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏼‍❤‍👨🏿' => 'koppja b’qalb: raġel, raġel, ton medju-ċar tal-ġilda, u ton skur tal-ġilda',
    '👨🏽‍❤‍👨🏻' => 'koppja b’qalb: raġel, raġel, ton medju tal-ġilda, u ton ċar tal-ġilda',
    '👨🏽‍❤‍👨🏼' => 'koppja b’qalb: raġel, raġel, ton medju tal-ġilda, u ton medju-ċar tal-ġilda',
    '👨🏽‍❤‍👨🏽' => 'koppja b’qalb: raġel, raġel, u ton medju tal-ġilda',
    '👨🏽‍❤‍👨🏾' => 'koppja b’qalb: raġel, raġel, ton medju tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏽‍❤‍👨🏿' => 'koppja b’qalb: raġel, raġel, ton medju tal-ġilda, u ton skur tal-ġilda',
    '👨🏾‍❤‍👨🏻' => 'koppja b’qalb: raġel, raġel, ton medju-skur tal-ġilda, u ton ċar tal-ġilda',
    '👨🏾‍❤‍👨🏼' => 'koppja b’qalb: raġel, raġel, ton medju-skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👨🏾‍❤‍👨🏽' => 'koppja b’qalb: raġel, raġel, ton medju-skur tal-ġilda, u ton medju tal-ġilda',
    '👨🏾‍❤‍👨🏾' => 'koppja b’qalb: raġel, raġel, u ton medju-skur tal-ġilda',
    '👨🏾‍❤‍👨🏿' => 'koppja b’qalb: raġel, raġel, ton medju-skur tal-ġilda, u ton skur tal-ġilda',
    '👨🏿‍❤‍👨🏻' => 'koppja b’qalb: raġel, raġel, ton skur tal-ġilda, u ton ċar tal-ġilda',
    '👨🏿‍❤‍👨🏼' => 'koppja b’qalb: raġel, raġel, ton skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👨🏿‍❤‍👨🏽' => 'koppja b’qalb: raġel, raġel, ton skur tal-ġilda, u ton medju tal-ġilda',
    '👨🏿‍❤‍👨🏾' => 'koppja b’qalb: raġel, raġel, ton skur tal-ġilda, u ton medju-skur tal-ġilda',
    '👨🏿‍❤‍👨🏿' => 'koppja b’qalb: raġel, raġel, u ton skur tal-ġilda',
    '👨🏻‍🐰‍👨🏼' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏻‍🐰‍👨🏽' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju tal-ġilda',
    '👨🏻‍🐰‍👨🏾' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏻‍🐰‍👨🏿' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton skur tal-ġilda',
    '👨🏼‍🐰‍👨🏻' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '👨🏼‍🐰‍👨🏽' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '👨🏼‍🐰‍👨🏾' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏼‍🐰‍👨🏿' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '👨🏽‍🐰‍👨🏻' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton ċar tal-ġilda',
    '👨🏽‍🐰‍👨🏼' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏽‍🐰‍👨🏾' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏽‍🐰‍👨🏿' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton skur tal-ġilda',
    '👨🏾‍🐰‍👨🏻' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '👨🏾‍🐰‍👨🏼' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏾‍🐰‍👨🏽' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '👨🏾‍🐰‍👨🏿' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '👨🏿‍🐰‍👨🏻' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton ċar tal-ġilda',
    '👨🏿‍🐰‍👨🏼' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏿‍🐰‍👨🏽' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju tal-ġilda',
    '👨🏿‍🐰‍👨🏾' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏻‍🫯‍👩🏼' => 'nisa jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏻‍🫯‍👩🏽' => 'nisa jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju tal-ġilda',
    '👩🏻‍🫯‍👩🏾' => 'nisa jagħmlu r-wrestling: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏻‍🫯‍👩🏿' => 'nisa jagħmlu r-wrestling: ton ċar tal-ġilda u ton skur tal-ġilda',
    '👩🏼‍🫯‍👩🏻' => 'nisa jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '👩🏼‍🫯‍👩🏽' => 'nisa jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '👩🏼‍🫯‍👩🏾' => 'nisa jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏼‍🫯‍👩🏿' => 'nisa jagħmlu r-wrestling: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '👩🏽‍🫯‍👩🏻' => 'nisa jagħmlu r-wrestling: ton medju tal-ġilda u ton ċar tal-ġilda',
    '👩🏽‍🫯‍👩🏼' => 'nisa jagħmlu r-wrestling: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏽‍🫯‍👩🏾' => 'nisa jagħmlu r-wrestling: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏽‍🫯‍👩🏿' => 'nisa jagħmlu r-wrestling: ton medju tal-ġilda u ton skur tal-ġilda',
    '👩🏾‍🫯‍👩🏻' => 'nisa jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '👩🏾‍🫯‍👩🏼' => 'nisa jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏾‍🫯‍👩🏽' => 'nisa jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '👩🏾‍🫯‍👩🏿' => 'nisa jagħmlu r-wrestling: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '👩🏿‍🫯‍👩🏻' => 'nisa jagħmlu r-wrestling: ton skur tal-ġilda u ton ċar tal-ġilda',
    '👩🏿‍🫯‍👩🏼' => 'nisa jagħmlu r-wrestling: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏿‍🫯‍👩🏽' => 'nisa jagħmlu r-wrestling: ton skur tal-ġilda u ton medju tal-ġilda',
    '👩🏿‍🫯‍👩🏾' => 'nisa jagħmlu r-wrestling: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏻‍❤‍👨🏻' => 'koppja b’qalb: mara, raġel, u ton ċar tal-ġilda',
    '👩🏻‍❤‍👨🏼' => 'koppja b’qalb: mara, raġel, ton ċar tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏻‍❤‍👨🏽' => 'koppja b’qalb: mara, raġel, ton ċar tal-ġilda, u ton medju tal-ġilda',
    '👩🏻‍❤‍👨🏾' => 'koppja b’qalb: mara, raġel, ton ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏻‍❤‍👨🏿' => 'koppja b’qalb: mara, raġel, ton ċar tal-ġilda, u ton skur tal-ġilda',
    '👩🏼‍❤‍👨🏻' => 'koppja b’qalb: mara, raġel, ton medju-ċar tal-ġilda, u ton ċar tal-ġilda',
    '👩🏼‍❤‍👨🏼' => 'koppja b’qalb: mara, raġel, u ton medju-ċar tal-ġilda',
    '👩🏼‍❤‍👨🏽' => 'koppja b’qalb: mara, raġel, ton medju-ċar tal-ġilda, u ton medju tal-ġilda',
    '👩🏼‍❤‍👨🏾' => 'koppja b’qalb: mara, raġel, ton medju-ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏼‍❤‍👨🏿' => 'koppja b’qalb: mara, raġel, ton medju-ċar tal-ġilda, u ton skur tal-ġilda',
    '👩🏽‍❤‍👨🏻' => 'koppja b’qalb: mara, raġel, ton medju tal-ġilda, u ton ċar tal-ġilda',
    '👩🏽‍❤‍👨🏼' => 'koppja b’qalb: mara, raġel, ton medju tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏽‍❤‍👨🏽' => 'koppja b’qalb: mara, raġel, u ton medju tal-ġilda',
    '👩🏽‍❤‍👨🏾' => 'koppja b’qalb: mara, raġel, ton medju tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏽‍❤‍👨🏿' => 'koppja b’qalb: mara, raġel, ton medju tal-ġilda, u ton skur tal-ġilda',
    '👩🏾‍❤‍👨🏻' => 'koppja b’qalb: mara, raġel, ton medju-skur tal-ġilda, u ton ċar tal-ġilda',
    '👩🏾‍❤‍👨🏼' => 'koppja b’qalb: mara, raġel, ton medju-skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏾‍❤‍👨🏽' => 'koppja b’qalb: mara, raġel, ton medju-skur tal-ġilda, u ton medju tal-ġilda',
    '👩🏾‍❤‍👨🏾' => 'koppja b’qalb: mara, raġel, u ton medju-skur tal-ġilda',
    '👩🏾‍❤‍👨🏿' => 'koppja b’qalb: mara, raġel, ton medju-skur tal-ġilda, u ton skur tal-ġilda',
    '👩🏿‍❤‍👨🏻' => 'koppja b’qalb: mara, raġel, ton skur tal-ġilda, u ton ċar tal-ġilda',
    '👩🏿‍❤‍👨🏼' => 'koppja b’qalb: mara, raġel, ton skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏿‍❤‍👨🏽' => 'koppja b’qalb: mara, raġel, ton skur tal-ġilda, u ton medju tal-ġilda',
    '👩🏿‍❤‍👨🏾' => 'koppja b’qalb: mara, raġel, ton skur tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏿‍❤‍👨🏿' => 'koppja b’qalb: mara, raġel, u ton skur tal-ġilda',
    '👩🏻‍❤‍👩🏻' => 'koppja b’qalb: mara, mara, u ton ċar tal-ġilda',
    '👩🏻‍❤‍👩🏼' => 'koppja b’qalb: mara, mara, ton ċar tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏻‍❤‍👩🏽' => 'koppja b’qalb: mara, mara, ton ċar tal-ġilda, u ton medju tal-ġilda',
    '👩🏻‍❤‍👩🏾' => 'koppja b’qalb: mara, mara, ton ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏻‍❤‍👩🏿' => 'koppja b’qalb: mara, mara, ton ċar tal-ġilda, u ton skur tal-ġilda',
    '👩🏼‍❤‍👩🏻' => 'koppja b’qalb: mara, mara, ton medju-ċar tal-ġilda, u ton ċar tal-ġilda',
    '👩🏼‍❤‍👩🏼' => 'koppja b’qalb: mara, mara, u ton medju-ċar tal-ġilda',
    '👩🏼‍❤‍👩🏽' => 'koppja b’qalb: mara, mara, ton medju-ċar tal-ġilda, u ton medju tal-ġilda',
    '👩🏼‍❤‍👩🏾' => 'koppja b’qalb: mara, mara, ton medju-ċar tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏼‍❤‍👩🏿' => 'koppja b’qalb: mara, mara, ton medju-ċar tal-ġilda, u ton skur tal-ġilda',
    '👩🏽‍❤‍👩🏻' => 'koppja b’qalb: mara, mara, ton medju tal-ġilda, u ton ċar tal-ġilda',
    '👩🏽‍❤‍👩🏼' => 'koppja b’qalb: mara, mara, ton medju tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏽‍❤‍👩🏽' => 'koppja b’qalb: mara, mara, u ton medju tal-ġilda',
    '👩🏽‍❤‍👩🏾' => 'koppja b’qalb: mara, mara, ton medju tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏽‍❤‍👩🏿' => 'koppja b’qalb: mara, mara, ton medju tal-ġilda, u ton skur tal-ġilda',
    '👩🏾‍❤‍👩🏻' => 'koppja b’qalb: mara, mara, ton medju-skur tal-ġilda, u ton ċar tal-ġilda',
    '👩🏾‍❤‍👩🏼' => 'koppja b’qalb: mara, mara, ton medju-skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏾‍❤‍👩🏽' => 'koppja b’qalb: mara, mara, ton medju-skur tal-ġilda, u ton medju tal-ġilda',
    '👩🏾‍❤‍👩🏾' => 'koppja b’qalb: mara, mara, u ton medju-skur tal-ġilda',
    '👩🏾‍❤‍👩🏿' => 'koppja b’qalb: mara, mara, ton medju-skur tal-ġilda, u ton skur tal-ġilda',
    '👩🏿‍❤‍👩🏻' => 'koppja b’qalb: mara, mara, ton skur tal-ġilda, u ton ċar tal-ġilda',
    '👩🏿‍❤‍👩🏼' => 'koppja b’qalb: mara, mara, ton skur tal-ġilda, u ton medju-ċar tal-ġilda',
    '👩🏿‍❤‍👩🏽' => 'koppja b’qalb: mara, mara, ton skur tal-ġilda, u ton medju tal-ġilda',
    '👩🏿‍❤‍👩🏾' => 'koppja b’qalb: mara, mara, ton skur tal-ġilda, u ton medju-skur tal-ġilda',
    '👩🏿‍❤‍👩🏿' => 'koppja b’qalb: mara, mara, u ton skur tal-ġilda',
    '👩🏻‍🐰‍👩🏼' => 'nisa b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏻‍🐰‍👩🏽' => 'nisa b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju tal-ġilda',
    '👩🏻‍🐰‍👩🏾' => 'nisa b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏻‍🐰‍👩🏿' => 'nisa b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda u ton skur tal-ġilda',
    '👩🏼‍🐰‍👩🏻' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '👩🏼‍🐰‍👩🏽' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '👩🏼‍🐰‍👩🏾' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏼‍🐰‍👩🏿' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '👩🏽‍🐰‍👩🏻' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton ċar tal-ġilda',
    '👩🏽‍🐰‍👩🏼' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏽‍🐰‍👩🏾' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏽‍🐰‍👩🏿' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda u ton skur tal-ġilda',
    '👩🏾‍🐰‍👩🏻' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '👩🏾‍🐰‍👩🏼' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏾‍🐰‍👩🏽' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '👩🏾‍🐰‍👩🏿' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '👩🏿‍🐰‍👩🏻' => 'nisa b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton ċar tal-ġilda',
    '👩🏿‍🐰‍👩🏼' => 'nisa b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏿‍🐰‍👩🏽' => 'nisa b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju tal-ġilda',
    '👩🏿‍🐰‍👩🏾' => 'nisa b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏻‍🤝‍👩🏼' => 'żewġ nisa jżommu jdejhom: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏻‍🤝‍👩🏽' => 'żewġ nisa jżommu jdejhom: ton ċar tal-ġilda u ton medju tal-ġilda',
    '👩🏻‍🤝‍👩🏾' => 'żewġ nisa jżommu jdejhom: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏻‍🤝‍👩🏿' => 'żewġ nisa jżommu jdejhom: ton ċar tal-ġilda u ton skur tal-ġilda',
    '👩🏼‍🤝‍👩🏻' => 'żewġ nisa jżommu jdejhom: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '👩🏼‍🤝‍👩🏽' => 'żewġ nisa jżommu jdejhom: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '👩🏼‍🤝‍👩🏾' => 'żewġ nisa jżommu jdejhom: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏼‍🤝‍👩🏿' => 'żewġ nisa jżommu jdejhom: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '👩🏽‍🤝‍👩🏻' => 'żewġ nisa jżommu jdejhom: ton medju tal-ġilda u ton ċar tal-ġilda',
    '👩🏽‍🤝‍👩🏼' => 'żewġ nisa jżommu jdejhom: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏽‍🤝‍👩🏾' => 'żewġ nisa jżommu jdejhom: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏽‍🤝‍👩🏿' => 'żewġ nisa jżommu jdejhom: ton medju tal-ġilda u ton skur tal-ġilda',
    '👩🏾‍🤝‍👩🏻' => 'żewġ nisa jżommu jdejhom: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '👩🏾‍🤝‍👩🏼' => 'żewġ nisa jżommu jdejhom: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏾‍🤝‍👩🏽' => 'żewġ nisa jżommu jdejhom: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '👩🏾‍🤝‍👩🏿' => 'żewġ nisa jżommu jdejhom: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '👩🏿‍🤝‍👩🏻' => 'żewġ nisa jżommu jdejhom: ton skur tal-ġilda u ton ċar tal-ġilda',
    '👩🏿‍🤝‍👩🏼' => 'żewġ nisa jżommu jdejhom: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏿‍🤝‍👩🏽' => 'żewġ nisa jżommu jdejhom: ton skur tal-ġilda u ton medju tal-ġilda',
    '👩🏿‍🤝‍👩🏾' => 'żewġ nisa jżommu jdejhom: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏻‍🤝‍👨🏼' => 'raġel u mara jżommu jdejhom: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏻‍🤝‍👨🏽' => 'raġel u mara jżommu jdejhom: ton ċar tal-ġilda u ton medju tal-ġilda',
    '👩🏻‍🤝‍👨🏾' => 'raġel u mara jżommu jdejhom: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏻‍🤝‍👨🏿' => 'raġel u mara jżommu jdejhom: ton ċar tal-ġilda u ton skur tal-ġilda',
    '👩🏼‍🤝‍👨🏻' => 'raġel u mara jżommu jdejhom: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '👩🏼‍🤝‍👨🏽' => 'raġel u mara jżommu jdejhom: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '👩🏼‍🤝‍👨🏾' => 'raġel u mara jżommu jdejhom: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏼‍🤝‍👨🏿' => 'raġel u mara jżommu jdejhom: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '👩🏽‍🤝‍👨🏻' => 'raġel u mara jżommu jdejhom: ton medju tal-ġilda u ton ċar tal-ġilda',
    '👩🏽‍🤝‍👨🏼' => 'raġel u mara jżommu jdejhom: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏽‍🤝‍👨🏾' => 'raġel u mara jżommu jdejhom: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '👩🏽‍🤝‍👨🏿' => 'raġel u mara jżommu jdejhom: ton medju tal-ġilda u ton skur tal-ġilda',
    '👩🏾‍🤝‍👨🏻' => 'raġel u mara jżommu jdejhom: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '👩🏾‍🤝‍👨🏼' => 'raġel u mara jżommu jdejhom: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏾‍🤝‍👨🏽' => 'raġel u mara jżommu jdejhom: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '👩🏾‍🤝‍👨🏿' => 'raġel u mara jżommu jdejhom: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '👩🏿‍🤝‍👨🏻' => 'raġel u mara jżommu jdejhom: ton skur tal-ġilda u ton ċar tal-ġilda',
    '👩🏿‍🤝‍👨🏼' => 'raġel u mara jżommu jdejhom: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👩🏿‍🤝‍👨🏽' => 'raġel u mara jżommu jdejhom: ton skur tal-ġilda u ton medju tal-ġilda',
    '👩🏿‍🤝‍👨🏾' => 'raġel u mara jżommu jdejhom: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏻‍🤝‍👨🏼' => 'żewġt irġiel iżommu jdejhom: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏻‍🤝‍👨🏽' => 'żewġt irġiel iżommu jdejhom: ton ċar tal-ġilda u ton medju tal-ġilda',
    '👨🏻‍🤝‍👨🏾' => 'żewġt irġiel iżommu jdejhom: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏻‍🤝‍👨🏿' => 'żewġt irġiel iżommu jdejhom: ton ċar tal-ġilda u ton skur tal-ġilda',
    '👨🏼‍🤝‍👨🏻' => 'żewġt irġiel iżommu jdejhom: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '👨🏼‍🤝‍👨🏽' => 'żewġt irġiel iżommu jdejhom: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '👨🏼‍🤝‍👨🏾' => 'żewġt irġiel iżommu jdejhom: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏼‍🤝‍👨🏿' => 'żewġt irġiel iżommu jdejhom: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '👨🏽‍🤝‍👨🏻' => 'żewġt irġiel iżommu jdejhom: ton medju tal-ġilda u ton ċar tal-ġilda',
    '👨🏽‍🤝‍👨🏼' => 'żewġt irġiel iżommu jdejhom: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏽‍🤝‍👨🏾' => 'żewġt irġiel iżommu jdejhom: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '👨🏽‍🤝‍👨🏿' => 'żewġt irġiel iżommu jdejhom: ton medju tal-ġilda u ton skur tal-ġilda',
    '👨🏾‍🤝‍👨🏻' => 'żewġt irġiel iżommu jdejhom: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '👨🏾‍🤝‍👨🏼' => 'żewġt irġiel iżommu jdejhom: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏾‍🤝‍👨🏽' => 'żewġt irġiel iżommu jdejhom: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '👨🏾‍🤝‍👨🏿' => 'żewġt irġiel iżommu jdejhom: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '👨🏿‍🤝‍👨🏻' => 'żewġt irġiel iżommu jdejhom: ton skur tal-ġilda u ton ċar tal-ġilda',
    '👨🏿‍🤝‍👨🏼' => 'żewġt irġiel iżommu jdejhom: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '👨🏿‍🤝‍👨🏽' => 'żewġt irġiel iżommu jdejhom: ton skur tal-ġilda u ton medju tal-ġilda',
    '👨🏿‍🤝‍👨🏾' => 'żewġt irġiel iżommu jdejhom: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👩‍❤‍💋‍👨' => 'bewsa: mara u raġel',
    '👨‍❤‍💋‍👨' => 'bewsa: raġel u raġel',
    '👩‍❤‍💋‍👩' => 'bewsa: mara u mara',
    '👨‍👩‍👧‍👦' => 'familja: raġel, mara, tifla, u tifel',
    '👨‍👩‍👦‍👦' => 'familja: raġel, mara, tifel, u tifel',
    '👨‍👩‍👧‍👧' => 'familja: raġel, mara, tifla, u tifla',
    '👨‍👨‍👧‍👦' => 'familja: raġel, raġel, tifla, u tifel',
    '👨‍👨‍👦‍👦' => 'familja: raġel, raġel, tifel, u tifel',
    '👨‍👨‍👧‍👧' => 'familja: raġel, raġel, tifla, u tifla',
    '👩‍👩‍👧‍👦' => 'familja: mara, mara, tifla, u tifel',
    '👩‍👩‍👦‍👦' => 'familja: mara, mara, tifel, u tifel',
    '👩‍👩‍👧‍👧' => 'familja: mara, mara, tifla, u tifla',
    '🫱🏻‍🫲🏼' => 'ħu bl-idejn: ton ċar tal-ġilda u ton medju-ċar tal-ġilda',
    '🫱🏻‍🫲🏽' => 'ħu bl-idejn: ton ċar tal-ġilda u ton medju tal-ġilda',
    '🫱🏻‍🫲🏾' => 'ħu bl-idejn: ton ċar tal-ġilda u ton medju-skur tal-ġilda',
    '🫱🏻‍🫲🏿' => 'ħu bl-idejn: ton ċar tal-ġilda u ton skur tal-ġilda',
    '🫱🏼‍🫲🏻' => 'ħu bl-idejn: ton medju-ċar tal-ġilda u ton ċar tal-ġilda',
    '🫱🏼‍🫲🏽' => 'ħu bl-idejn: ton medju-ċar tal-ġilda u ton medju tal-ġilda',
    '🫱🏼‍🫲🏾' => 'ħu bl-idejn: ton medju-ċar tal-ġilda u ton medju-skur tal-ġilda',
    '🫱🏼‍🫲🏿' => 'ħu bl-idejn: ton medju-ċar tal-ġilda u ton skur tal-ġilda',
    '🫱🏽‍🫲🏻' => 'ħu bl-idejn: ton medju tal-ġilda u ton ċar tal-ġilda',
    '🫱🏽‍🫲🏼' => 'ħu bl-idejn: ton medju tal-ġilda u ton medju-ċar tal-ġilda',
    '🫱🏽‍🫲🏾' => 'ħu bl-idejn: ton medju tal-ġilda u ton medju-skur tal-ġilda',
    '🫱🏽‍🫲🏿' => 'ħu bl-idejn: ton medju tal-ġilda u ton skur tal-ġilda',
    '🫱🏾‍🫲🏻' => 'ħu bl-idejn: ton medju-skur tal-ġilda u ton ċar tal-ġilda',
    '🫱🏾‍🫲🏼' => 'ħu bl-idejn: ton medju-skur tal-ġilda u ton medju-ċar tal-ġilda',
    '🫱🏾‍🫲🏽' => 'ħu bl-idejn: ton medju-skur tal-ġilda u ton medju tal-ġilda',
    '🫱🏾‍🫲🏿' => 'ħu bl-idejn: ton medju-skur tal-ġilda u ton skur tal-ġilda',
    '🫱🏿‍🫲🏻' => 'ħu bl-idejn: ton skur tal-ġilda u ton ċar tal-ġilda',
    '🫱🏿‍🫲🏼' => 'ħu bl-idejn: ton skur tal-ġilda u ton medju-ċar tal-ġilda',
    '🫱🏿‍🫲🏽' => 'ħu bl-idejn: ton skur tal-ġilda u ton medju tal-ġilda',
    '🫱🏿‍🫲🏾' => 'ħu bl-idejn: ton skur tal-ġilda u ton medju-skur tal-ġilda',
    '👩‍❤‍👨' => 'koppja b’qalb: mara u raġel',
    '👨‍❤‍👨' => 'koppja b’qalb: raġel u raġel',
    '👩‍❤‍👩' => 'koppja b’qalb: mara u mara',
    '👨‍👩‍👦' => 'familja: raġel, mara, u tifel',
    '👨‍👩‍👧' => 'familja: raġel, mara, u tifla',
    '👨‍👨‍👦' => 'familja: raġel, raġel, u tifel',
    '👨‍👨‍👧' => 'familja: raġel, raġel, u tifla',
    '👩‍👩‍👦' => 'familja: mara, mara, u tifel',
    '👩‍👩‍👧' => 'familja: mara, mara, u tifla',
    '👨‍👦‍👦' => 'familja: raġel, tifel, u tifel',
    '👨‍👧‍👦' => 'familja: raġel, tifla, u tifel',
    '👨‍👧‍👧' => 'familja: raġel, tifla, u tifla',
    '👩‍👦‍👦' => 'familja: mara, tifel, u tifel',
    '👩‍👧‍👦' => 'familja: mara, tifla, u tifel',
    '👩‍👧‍👧' => 'familja: mara, tifla, u tifla',
    '👱🏻‍♂' => 'raġel b’xagħar isfar: ton ċar tal-ġilda',
    '👱🏼‍♂' => 'raġel b’xagħar isfar: ton medju-ċar tal-ġilda',
    '👱🏽‍♂' => 'raġel b’xagħar isfar: ton medju tal-ġilda',
    '👱🏾‍♂' => 'raġel b’xagħar isfar: ton medju-skur tal-ġilda',
    '👱🏿‍♂' => 'raġel b’xagħar isfar: ton skur tal-ġilda',
    '👱🏻‍♀' => 'mara b’xagħar isfar: ton ċar tal-ġilda',
    '👱🏼‍♀' => 'mara b’xagħar isfar: ton medju-ċar tal-ġilda',
    '👱🏽‍♀' => 'mara b’xagħar isfar: ton medju tal-ġilda',
    '👱🏾‍♀' => 'mara b’xagħar isfar: ton medju-skur tal-ġilda',
    '👱🏿‍♀' => 'mara b’xagħar isfar: ton skur tal-ġilda',
    '🙍🏻‍♂' => 'raġel jitkerrah: ton ċar tal-ġilda',
    '🙍🏼‍♂' => 'raġel jitkerrah: ton medju-ċar tal-ġilda',
    '🙍🏽‍♂' => 'raġel jitkerrah: ton medju tal-ġilda',
    '🙍🏾‍♂' => 'raġel jitkerrah: ton medju-skur tal-ġilda',
    '🙍🏿‍♂' => 'raġel jitkerrah: ton skur tal-ġilda',
    '🙍🏻‍♀' => 'mara titkerrah: ton ċar tal-ġilda',
    '🙍🏼‍♀' => 'mara titkerrah: ton medju-ċar tal-ġilda',
    '🙍🏽‍♀' => 'mara titkerrah: ton medju tal-ġilda',
    '🙍🏾‍♀' => 'mara titkerrah: ton medju-skur tal-ġilda',
    '🙍🏿‍♀' => 'mara titkerrah: ton skur tal-ġilda',
    '🙎🏻‍♂' => 'raġel jisporġi x-xofftejn: ton ċar tal-ġilda',
    '🙎🏼‍♂' => 'raġel jisporġi x-xofftejn: ton medju-ċar tal-ġilda',
    '🙎🏽‍♂' => 'raġel jisporġi x-xofftejn: ton medju tal-ġilda',
    '🙎🏾‍♂' => 'raġel jisporġi x-xofftejn: ton medju-skur tal-ġilda',
    '🙎🏿‍♂' => 'raġel jisporġi x-xofftejn: ton skur tal-ġilda',
    '🙎🏻‍♀' => 'mara tisporġi x-xofftejn: ton ċar tal-ġilda',
    '🙎🏼‍♀' => 'mara tisporġi x-xofftejn: ton medju-ċar tal-ġilda',
    '🙎🏽‍♀' => 'mara tisporġi x-xofftejn: ton medju tal-ġilda',
    '🙎🏾‍♀' => 'mara tisporġi x-xofftejn: ton medju-skur tal-ġilda',
    '🙎🏿‍♀' => 'mara tisporġi x-xofftejn: ton skur tal-ġilda',
    '🙅🏻‍♂' => 'raġel jagħmel sinjal ta’ LE: ton ċar tal-ġilda',
    '🙅🏼‍♂' => 'raġel jagħmel sinjal ta’ LE: ton medju-ċar tal-ġilda',
    '🙅🏽‍♂' => 'raġel jagħmel sinjal ta’ LE: ton medju tal-ġilda',
    '🙅🏾‍♂' => 'raġel jagħmel sinjal ta’ LE: ton medju-skur tal-ġilda',
    '🙅🏿‍♂' => 'raġel jagħmel sinjal ta’ LE: ton skur tal-ġilda',
    '🙅🏻‍♀' => 'mara tagħmel sinjal ta’ LE: ton ċar tal-ġilda',
    '🙅🏼‍♀' => 'mara tagħmel sinjal ta’ LE: ton medju-ċar tal-ġilda',
    '🙅🏽‍♀' => 'mara tagħmel sinjal ta’ LE: ton medju tal-ġilda',
    '🙅🏾‍♀' => 'mara tagħmel sinjal ta’ LE: ton medju-skur tal-ġilda',
    '🙅🏿‍♀' => 'mara tagħmel sinjal ta’ LE: ton skur tal-ġilda',
    '🙆🏻‍♂' => 'raġel jagħmel sinjal ta’ OK: ton ċar tal-ġilda',
    '🙆🏼‍♂' => 'raġel jagħmel sinjal ta’ OK: ton medju-ċar tal-ġilda',
    '🙆🏽‍♂' => 'raġel jagħmel sinjal ta’ OK: ton medju tal-ġilda',
    '🙆🏾‍♂' => 'raġel jagħmel sinjal ta’ OK: ton medju-skur tal-ġilda',
    '🙆🏿‍♂' => 'raġel jagħmel sinjal ta’ OK: ton skur tal-ġilda',
    '🙆🏻‍♀' => 'mara tagħmel sinjal ta’ OK: ton ċar tal-ġilda',
    '🙆🏼‍♀' => 'mara tagħmel sinjal ta’ OK: ton medju-ċar tal-ġilda',
    '🙆🏽‍♀' => 'mara tagħmel sinjal ta’ OK: ton medju tal-ġilda',
    '🙆🏾‍♀' => 'mara tagħmel sinjal ta’ OK: ton medju-skur tal-ġilda',
    '🙆🏿‍♀' => 'mara tagħmel sinjal ta’ OK: ton skur tal-ġilda',
    '💁🏻‍♂' => 'raġel ibaxxi idejh: ton ċar tal-ġilda',
    '💁🏼‍♂' => 'raġel ibaxxi idejh: ton medju-ċar tal-ġilda',
    '💁🏽‍♂' => 'raġel ibaxxi idejh: ton medju tal-ġilda',
    '💁🏾‍♂' => 'raġel ibaxxi idejh: ton medju-skur tal-ġilda',
    '💁🏿‍♂' => 'raġel ibaxxi idejh: ton skur tal-ġilda',
    '💁🏻‍♀' => 'mara tbaxxi idha: ton ċar tal-ġilda',
    '💁🏼‍♀' => 'mara tbaxxi idha: ton medju-ċar tal-ġilda',
    '💁🏽‍♀' => 'mara tbaxxi idha: ton medju tal-ġilda',
    '💁🏾‍♀' => 'mara tbaxxi idha: ton medju-skur tal-ġilda',
    '💁🏿‍♀' => 'mara tbaxxi idha: ton skur tal-ġilda',
    '🙋🏻‍♂' => 'raġel jgħolli idejh: ton ċar tal-ġilda',
    '🙋🏼‍♂' => 'raġel jgħolli idejh: ton medju-ċar tal-ġilda',
    '🙋🏽‍♂' => 'raġel jgħolli idejh: ton medju tal-ġilda',
    '🙋🏾‍♂' => 'raġel jgħolli idejh: ton medju-skur tal-ġilda',
    '🙋🏿‍♂' => 'raġel jgħolli idejh: ton skur tal-ġilda',
    '🙋🏻‍♀' => 'mara tgħolli idha: ton ċar tal-ġilda',
    '🙋🏼‍♀' => 'mara tgħolli idha: ton medju-ċar tal-ġilda',
    '🙋🏽‍♀' => 'mara tgħolli idha: ton medju tal-ġilda',
    '🙋🏾‍♀' => 'mara tgħolli idha: ton medju-skur tal-ġilda',
    '🙋🏿‍♀' => 'mara tgħolli idha: ton skur tal-ġilda',
    '🙇🏻‍♂' => 'raġel jikina: ton ċar tal-ġilda',
    '🙇🏼‍♂' => 'raġel jikina: ton medju-ċar tal-ġilda',
    '🙇🏽‍♂' => 'raġel jikina: ton medju tal-ġilda',
    '🙇🏾‍♂' => 'raġel jikina: ton medju-skur tal-ġilda',
    '🙇🏿‍♂' => 'raġel jikina: ton skur tal-ġilda',
    '🙇🏻‍♀' => 'mara tikina: ton ċar tal-ġilda',
    '🙇🏼‍♀' => 'mara tikina: ton medju-ċar tal-ġilda',
    '🙇🏽‍♀' => 'mara tikina: ton medju tal-ġilda',
    '🙇🏾‍♀' => 'mara tikina: ton medju-skur tal-ġilda',
    '🙇🏿‍♀' => 'mara tikina: ton skur tal-ġilda',
    '🤦🏻‍♂' => 'raġel jagħmel facepalming: ton ċar tal-ġilda',
    '🤦🏼‍♂' => 'raġel jagħmel facepalming: ton medju-ċar tal-ġilda',
    '🤦🏽‍♂' => 'raġel jagħmel facepalming: ton medju tal-ġilda',
    '🤦🏾‍♂' => 'raġel jagħmel facepalming: ton medju-skur tal-ġilda',
    '🤦🏿‍♂' => 'raġel jagħmel facepalming: ton skur tal-ġilda',
    '🤦🏻‍♀' => 'mara tagħmel facepalming: ton ċar tal-ġilda',
    '🤦🏼‍♀' => 'mara tagħmel facepalming: ton medju-ċar tal-ġilda',
    '🤦🏽‍♀' => 'mara tagħmel facepalming: ton medju tal-ġilda',
    '🤦🏾‍♀' => 'mara tagħmel facepalming: ton medju-skur tal-ġilda',
    '🤦🏿‍♀' => 'mara tagħmel facepalming: ton skur tal-ġilda',
    '🤷🏻‍♂' => 'raġel ixengel spallejh: ton ċar tal-ġilda',
    '🤷🏼‍♂' => 'raġel ixengel spallejh: ton medju-ċar tal-ġilda',
    '🤷🏽‍♂' => 'raġel ixengel spallejh: ton medju tal-ġilda',
    '🤷🏾‍♂' => 'raġel ixengel spallejh: ton medju-skur tal-ġilda',
    '🤷🏿‍♂' => 'raġel ixengel spallejh: ton skur tal-ġilda',
    '🤷🏻‍♀' => 'mara xxengel spallejha: ton ċar tal-ġilda',
    '🤷🏼‍♀' => 'mara xxengel spallejha: ton medju-ċar tal-ġilda',
    '🤷🏽‍♀' => 'mara xxengel spallejha: ton medju tal-ġilda',
    '🤷🏾‍♀' => 'mara xxengel spallejha: ton medju-skur tal-ġilda',
    '🤷🏿‍♀' => 'mara xxengel spallejha: ton skur tal-ġilda',
    '👨🏻‍⚕' => 'ħaddiem fil-kura tal-bniedem: ton ċar tal-ġilda',
    '👨🏼‍⚕' => 'ħaddiem fil-kura tal-bniedem: ton medju-ċar tal-ġilda',
    '👨🏽‍⚕' => 'ħaddiem fil-kura tal-bniedem: ton medju tal-ġilda',
    '👨🏾‍⚕' => 'ħaddiem fil-kura tal-bniedem: ton medju-skur tal-ġilda',
    '👨🏿‍⚕' => 'ħaddiem fil-kura tal-bniedem: ton skur tal-ġilda',
    '👩🏻‍⚕' => 'mara fil-kura tas-saħħa: ton ċar tal-ġilda',
    '👩🏼‍⚕' => 'mara fil-kura tas-saħħa: ton medju-ċar tal-ġilda',
    '👩🏽‍⚕' => 'mara fil-kura tas-saħħa: ton medju tal-ġilda',
    '👩🏾‍⚕' => 'mara fil-kura tas-saħħa: ton medju-skur tal-ġilda',
    '👩🏿‍⚕' => 'mara fil-kura tas-saħħa: ton skur tal-ġilda',
    '👨🏻‍🎓' => 'student maskil: ton ċar tal-ġilda',
    '👨🏼‍🎓' => 'student maskil: ton medju-ċar tal-ġilda',
    '👨🏽‍🎓' => 'student maskil: ton medju tal-ġilda',
    '👨🏾‍🎓' => 'student maskil: ton medju-skur tal-ġilda',
    '👨🏿‍🎓' => 'student maskil: ton skur tal-ġilda',
    '👩🏻‍🎓' => 'student femminil: ton ċar tal-ġilda',
    '👩🏼‍🎓' => 'student femminil: ton medju-ċar tal-ġilda',
    '👩🏽‍🎓' => 'student femminil: ton medju tal-ġilda',
    '👩🏾‍🎓' => 'student femminil: ton medju-skur tal-ġilda',
    '👩🏿‍🎓' => 'student femminil: ton skur tal-ġilda',
    '👨🏻‍🏫' => 'għalliem: ton ċar tal-ġilda',
    '👨🏼‍🏫' => 'għalliem: ton medju-ċar tal-ġilda',
    '👨🏽‍🏫' => 'għalliem: ton medju tal-ġilda',
    '👨🏾‍🏫' => 'għalliem: ton medju-skur tal-ġilda',
    '👨🏿‍🏫' => 'għalliem: ton skur tal-ġilda',
    '👩🏻‍🏫' => 'għalliema: ton ċar tal-ġilda',
    '👩🏼‍🏫' => 'għalliema: ton medju-ċar tal-ġilda',
    '👩🏽‍🏫' => 'għalliema: ton medju tal-ġilda',
    '👩🏾‍🏫' => 'għalliema: ton medju-skur tal-ġilda',
    '👩🏿‍🏫' => 'għalliema: ton skur tal-ġilda',
    '👨🏻‍⚖' => 'imħallef maskil: ton ċar tal-ġilda',
    '👨🏼‍⚖' => 'imħallef maskil: ton medju-ċar tal-ġilda',
    '👨🏽‍⚖' => 'imħallef maskil: ton medju tal-ġilda',
    '👨🏾‍⚖' => 'imħallef maskil: ton medju-skur tal-ġilda',
    '👨🏿‍⚖' => 'imħallef maskil: ton skur tal-ġilda',
    '👩🏻‍⚖' => 'imħallef mara: ton ċar tal-ġilda',
    '👩🏼‍⚖' => 'imħallef mara: ton medju-ċar tal-ġilda',
    '👩🏽‍⚖' => 'imħallef mara: ton medju tal-ġilda',
    '👩🏾‍⚖' => 'imħallef mara: ton medju-skur tal-ġilda',
    '👩🏿‍⚖' => 'imħallef mara: ton skur tal-ġilda',
    '👨🏻‍🌾' => 'bidwi maskil: ton ċar tal-ġilda',
    '👨🏼‍🌾' => 'bidwi maskil: ton medju-ċar tal-ġilda',
    '👨🏽‍🌾' => 'bidwi maskil: ton medju tal-ġilda',
    '👨🏾‍🌾' => 'bidwi maskil: ton medju-skur tal-ġilda',
    '👨🏿‍🌾' => 'bidwi maskil: ton skur tal-ġilda',
    '👩🏻‍🌾' => 'bidwi femminil: ton ċar tal-ġilda',
    '👩🏼‍🌾' => 'bidwi femminil: ton medju-ċar tal-ġilda',
    '👩🏽‍🌾' => 'bidwi femminil: ton medju tal-ġilda',
    '👩🏾‍🌾' => 'bidwi femminil: ton medju-skur tal-ġilda',
    '👩🏿‍🌾' => 'bidwi femminil: ton skur tal-ġilda',
    '👨🏻‍🍳' => 'kok maskil: ton ċar tal-ġilda',
    '👨🏼‍🍳' => 'kok maskil: ton medju-ċar tal-ġilda',
    '👨🏽‍🍳' => 'kok maskil: ton medju tal-ġilda',
    '👨🏾‍🍳' => 'kok maskil: ton medju-skur tal-ġilda',
    '👨🏿‍🍳' => 'kok maskil: ton skur tal-ġilda',
    '👩🏻‍🍳' => 'kok femminil: ton ċar tal-ġilda',
    '👩🏼‍🍳' => 'kok femminil: ton medju-ċar tal-ġilda',
    '👩🏽‍🍳' => 'kok femminil: ton medju tal-ġilda',
    '👩🏾‍🍳' => 'kok femminil: ton medju-skur tal-ġilda',
    '👩🏿‍🍳' => 'kok femminil: ton skur tal-ġilda',
    '👨🏻‍🔧' => 'mekkanik maskili: ton ċar tal-ġilda',
    '👨🏼‍🔧' => 'mekkanik maskili: ton medju-ċar tal-ġilda',
    '👨🏽‍🔧' => 'mekkanik maskili: ton medju tal-ġilda',
    '👨🏾‍🔧' => 'mekkanik maskili: ton medju-skur tal-ġilda',
    '👨🏿‍🔧' => 'mekkanik maskili: ton skur tal-ġilda',
    '👩🏻‍🔧' => 'mekkanik mara: ton ċar tal-ġilda',
    '👩🏼‍🔧' => 'mekkanik mara: ton medju-ċar tal-ġilda',
    '👩🏽‍🔧' => 'mekkanik mara: ton medju tal-ġilda',
    '👩🏾‍🔧' => 'mekkanik mara: ton medju-skur tal-ġilda',
    '👩🏿‍🔧' => 'mekkanik mara: ton skur tal-ġilda',
    '👨🏻‍🏭' => 'ħaddiem tal-fabbrika: ton ċar tal-ġilda',
    '👨🏼‍🏭' => 'ħaddiem tal-fabbrika: ton medju-ċar tal-ġilda',
    '👨🏽‍🏭' => 'ħaddiem tal-fabbrika: ton medju tal-ġilda',
    '👨🏾‍🏭' => 'ħaddiem tal-fabbrika: ton medju-skur tal-ġilda',
    '👨🏿‍🏭' => 'ħaddiem tal-fabbrika: ton skur tal-ġilda',
    '👩🏻‍🏭' => 'ħaddiema tal-fabbrika: ton ċar tal-ġilda',
    '👩🏼‍🏭' => 'ħaddiema tal-fabbrika: ton medju-ċar tal-ġilda',
    '👩🏽‍🏭' => 'ħaddiema tal-fabbrika: ton medju tal-ġilda',
    '👩🏾‍🏭' => 'ħaddiema tal-fabbrika: ton medju-skur tal-ġilda',
    '👩🏿‍🏭' => 'ħaddiema tal-fabbrika: ton skur tal-ġilda',
    '👨🏻‍💼' => 'raġel jaħdem f’uffiċċju: ton ċar tal-ġilda',
    '👨🏼‍💼' => 'raġel jaħdem f’uffiċċju: ton medju-ċar tal-ġilda',
    '👨🏽‍💼' => 'raġel jaħdem f’uffiċċju: ton medju tal-ġilda',
    '👨🏾‍💼' => 'raġel jaħdem f’uffiċċju: ton medju-skur tal-ġilda',
    '👨🏿‍💼' => 'raġel jaħdem f’uffiċċju: ton skur tal-ġilda',
    '👩🏻‍💼' => 'mara taħdem f’uffiċċju: ton ċar tal-ġilda',
    '👩🏼‍💼' => 'mara taħdem f’uffiċċju: ton medju-ċar tal-ġilda',
    '👩🏽‍💼' => 'mara taħdem f’uffiċċju: ton medju tal-ġilda',
    '👩🏾‍💼' => 'mara taħdem f’uffiċċju: ton medju-skur tal-ġilda',
    '👩🏿‍💼' => 'mara taħdem f’uffiċċju: ton skur tal-ġilda',
    '👨🏻‍🔬' => 'xjenzat maskili: ton ċar tal-ġilda',
    '👨🏼‍🔬' => 'xjenzat maskili: ton medju-ċar tal-ġilda',
    '👨🏽‍🔬' => 'xjenzat maskili: ton medju tal-ġilda',
    '👨🏾‍🔬' => 'xjenzat maskili: ton medju-skur tal-ġilda',
    '👨🏿‍🔬' => 'xjenzat maskili: ton skur tal-ġilda',
    '👩🏻‍🔬' => 'xjenzata mara: ton ċar tal-ġilda',
    '👩🏼‍🔬' => 'xjenzata mara: ton medju-ċar tal-ġilda',
    '👩🏽‍🔬' => 'xjenzata mara: ton medju tal-ġilda',
    '👩🏾‍🔬' => 'xjenzata mara: ton medju-skur tal-ġilda',
    '👩🏿‍🔬' => 'xjenzata mara: ton skur tal-ġilda',
    '👨🏻‍💻' => 'teknoloġist maskili: ton ċar tal-ġilda',
    '👨🏼‍💻' => 'teknoloġist maskili: ton medju-ċar tal-ġilda',
    '👨🏽‍💻' => 'teknoloġist maskili: ton medju tal-ġilda',
    '👨🏾‍💻' => 'teknoloġist maskili: ton medju-skur tal-ġilda',
    '👨🏿‍💻' => 'teknoloġist maskili: ton skur tal-ġilda',
    '👩🏻‍💻' => 'teknoloġist femminili: ton ċar tal-ġilda',
    '👩🏼‍💻' => 'teknoloġist femminili: ton medju-ċar tal-ġilda',
    '👩🏽‍💻' => 'teknoloġist femminili: ton medju tal-ġilda',
    '👩🏾‍💻' => 'teknoloġist femminili: ton medju-skur tal-ġilda',
    '👩🏿‍💻' => 'teknoloġist femminili: ton skur tal-ġilda',
    '👨🏻‍🎤' => 'kantant maskili: ton ċar tal-ġilda',
    '👨🏼‍🎤' => 'kantant maskili: ton medju-ċar tal-ġilda',
    '👨🏽‍🎤' => 'kantant maskili: ton medju tal-ġilda',
    '👨🏾‍🎤' => 'kantant maskili: ton medju-skur tal-ġilda',
    '👨🏿‍🎤' => 'kantant maskili: ton skur tal-ġilda',
    '👩🏻‍🎤' => 'katant femminil: ton ċar tal-ġilda',
    '👩🏼‍🎤' => 'katant femminil: ton medju-ċar tal-ġilda',
    '👩🏽‍🎤' => 'katant femminil: ton medju tal-ġilda',
    '👩🏾‍🎤' => 'katant femminil: ton medju-skur tal-ġilda',
    '👩🏿‍🎤' => 'katant femminil: ton skur tal-ġilda',
    '👨🏻‍🎨' => 'artist maskili: ton ċar tal-ġilda',
    '👨🏼‍🎨' => 'artist maskili: ton medju-ċar tal-ġilda',
    '👨🏽‍🎨' => 'artist maskili: ton medju tal-ġilda',
    '👨🏾‍🎨' => 'artist maskili: ton medju-skur tal-ġilda',
    '👨🏿‍🎨' => 'artist maskili: ton skur tal-ġilda',
    '👩🏻‍🎨' => 'artist femminil: ton ċar tal-ġilda',
    '👩🏼‍🎨' => 'artist femminil: ton medju-ċar tal-ġilda',
    '👩🏽‍🎨' => 'artist femminil: ton medju tal-ġilda',
    '👩🏾‍🎨' => 'artist femminil: ton medju-skur tal-ġilda',
    '👩🏿‍🎨' => 'artist femminil: ton skur tal-ġilda',
    '👨🏻‍✈' => 'pilota tal-bniedem: ton ċar tal-ġilda',
    '👨🏼‍✈' => 'pilota tal-bniedem: ton medju-ċar tal-ġilda',
    '👨🏽‍✈' => 'pilota tal-bniedem: ton medju tal-ġilda',
    '👨🏾‍✈' => 'pilota tal-bniedem: ton medju-skur tal-ġilda',
    '👨🏿‍✈' => 'pilota tal-bniedem: ton skur tal-ġilda',
    '👩🏻‍✈' => 'pilota mara: ton ċar tal-ġilda',
    '👩🏼‍✈' => 'pilota mara: ton medju-ċar tal-ġilda',
    '👩🏽‍✈' => 'pilota mara: ton medju tal-ġilda',
    '👩🏾‍✈' => 'pilota mara: ton medju-skur tal-ġilda',
    '👩🏿‍✈' => 'pilota mara: ton skur tal-ġilda',
    '👨🏻‍🚀' => 'astronawt maskil: ton ċar tal-ġilda',
    '👨🏼‍🚀' => 'astronawt maskil: ton medju-ċar tal-ġilda',
    '👨🏽‍🚀' => 'astronawt maskil: ton medju tal-ġilda',
    '👨🏾‍🚀' => 'astronawt maskil: ton medju-skur tal-ġilda',
    '👨🏿‍🚀' => 'astronawt maskil: ton skur tal-ġilda',
    '👩🏻‍🚀' => 'astronawta mara: ton ċar tal-ġilda',
    '👩🏼‍🚀' => 'astronawta mara: ton medju-ċar tal-ġilda',
    '👩🏽‍🚀' => 'astronawta mara: ton medju tal-ġilda',
    '👩🏾‍🚀' => 'astronawta mara: ton medju-skur tal-ġilda',
    '👩🏿‍🚀' => 'astronawta mara: ton skur tal-ġilda',
    '👨🏻‍🚒' => 'ħaddiem tat-tifi tan-nar maskil: ton ċar tal-ġilda',
    '👨🏼‍🚒' => 'ħaddiem tat-tifi tan-nar maskil: ton medju-ċar tal-ġilda',
    '👨🏽‍🚒' => 'ħaddiem tat-tifi tan-nar maskil: ton medju tal-ġilda',
    '👨🏾‍🚒' => 'ħaddiem tat-tifi tan-nar maskil: ton medju-skur tal-ġilda',
    '👨🏿‍🚒' => 'ħaddiem tat-tifi tan-nar maskil: ton skur tal-ġilda',
    '👩🏻‍🚒' => 'ħaddiem tat-tifi tan-nar femminil: ton ċar tal-ġilda',
    '👩🏼‍🚒' => 'ħaddiem tat-tifi tan-nar femminil: ton medju-ċar tal-ġilda',
    '👩🏽‍🚒' => 'ħaddiem tat-tifi tan-nar femminil: ton medju tal-ġilda',
    '👩🏾‍🚒' => 'ħaddiem tat-tifi tan-nar femminil: ton medju-skur tal-ġilda',
    '👩🏿‍🚒' => 'ħaddiem tat-tifi tan-nar femminil: ton skur tal-ġilda',
    '👮🏻‍♂' => 'uffiċjal tal-pulizija raġel: ton ċar tal-ġilda',
    '👮🏼‍♂' => 'uffiċjal tal-pulizija raġel: ton medju-ċar tal-ġilda',
    '👮🏽‍♂' => 'uffiċjal tal-pulizija raġel: ton medju tal-ġilda',
    '👮🏾‍♂' => 'uffiċjal tal-pulizija raġel: ton medju-skur tal-ġilda',
    '👮🏿‍♂' => 'uffiċjal tal-pulizija raġel: ton skur tal-ġilda',
    '👮🏻‍♀' => 'uffiċjal tal-pulizija mara: ton ċar tal-ġilda',
    '👮🏼‍♀' => 'uffiċjal tal-pulizija mara: ton medju-ċar tal-ġilda',
    '👮🏽‍♀' => 'uffiċjal tal-pulizija mara: ton medju tal-ġilda',
    '👮🏾‍♀' => 'uffiċjal tal-pulizija mara: ton medju-skur tal-ġilda',
    '👮🏿‍♀' => 'uffiċjal tal-pulizija mara: ton skur tal-ġilda',
    '🕵🏻‍♂' => 'ditektiv raġel: ton ċar tal-ġilda',
    '🕵🏼‍♂' => 'ditektiv raġel: ton medju-ċar tal-ġilda',
    '🕵🏽‍♂' => 'ditektiv raġel: ton medju tal-ġilda',
    '🕵🏾‍♂' => 'ditektiv raġel: ton medju-skur tal-ġilda',
    '🕵🏿‍♂' => 'ditektiv raġel: ton skur tal-ġilda',
    '🕵🏻‍♀' => 'ditektiv mara: ton ċar tal-ġilda',
    '🕵🏼‍♀' => 'ditektiv mara: ton medju-ċar tal-ġilda',
    '🕵🏽‍♀' => 'ditektiv mara: ton medju tal-ġilda',
    '🕵🏾‍♀' => 'ditektiv mara: ton medju-skur tal-ġilda',
    '🕵🏿‍♀' => 'ditektiv mara: ton skur tal-ġilda',
    '💂🏻‍♂' => 'gwardjan raġel: ton ċar tal-ġilda',
    '💂🏼‍♂' => 'gwardjan raġel: ton medju-ċar tal-ġilda',
    '💂🏽‍♂' => 'gwardjan raġel: ton medju tal-ġilda',
    '💂🏾‍♂' => 'gwardjan raġel: ton medju-skur tal-ġilda',
    '💂🏿‍♂' => 'gwardjan raġel: ton skur tal-ġilda',
    '💂🏻‍♀' => 'gwardjan mara: ton ċar tal-ġilda',
    '💂🏼‍♀' => 'gwardjan mara: ton medju-ċar tal-ġilda',
    '💂🏽‍♀' => 'gwardjan mara: ton medju tal-ġilda',
    '💂🏾‍♀' => 'gwardjan mara: ton medju-skur tal-ġilda',
    '💂🏿‍♀' => 'gwardjan mara: ton skur tal-ġilda',
    '👷🏻‍♂' => 'ħaddiem tal-kostruzzjoni maskili: ton ċar tal-ġilda',
    '👷🏼‍♂' => 'ħaddiem tal-kostruzzjoni maskili: ton medju-ċar tal-ġilda',
    '👷🏽‍♂' => 'ħaddiem tal-kostruzzjoni maskili: ton medju tal-ġilda',
    '👷🏾‍♂' => 'ħaddiem tal-kostruzzjoni maskili: ton medju-skur tal-ġilda',
    '👷🏿‍♂' => 'ħaddiem tal-kostruzzjoni maskili: ton skur tal-ġilda',
    '👷🏻‍♀' => 'ħaddiem tal-kostruzzjoni femminili: ton ċar tal-ġilda',
    '👷🏼‍♀' => 'ħaddiem tal-kostruzzjoni femminili: ton medju-ċar tal-ġilda',
    '👷🏽‍♀' => 'ħaddiem tal-kostruzzjoni femminili: ton medju tal-ġilda',
    '👷🏾‍♀' => 'ħaddiem tal-kostruzzjoni femminili: ton medju-skur tal-ġilda',
    '👷🏿‍♀' => 'ħaddiem tal-kostruzzjoni femminili: ton skur tal-ġilda',
    '👳🏻‍♂' => 'raġel liebes turban: ton ċar tal-ġilda',
    '👳🏼‍♂' => 'raġel liebes turban: ton medju-ċar tal-ġilda',
    '👳🏽‍♂' => 'raġel liebes turban: ton medju tal-ġilda',
    '👳🏾‍♂' => 'raġel liebes turban: ton medju-skur tal-ġilda',
    '👳🏿‍♂' => 'raġel liebes turban: ton skur tal-ġilda',
    '👳🏻‍♀' => 'mara liebsa turban: ton ċar tal-ġilda',
    '👳🏼‍♀' => 'mara liebsa turban: ton medju-ċar tal-ġilda',
    '👳🏽‍♀' => 'mara liebsa turban: ton medju tal-ġilda',
    '👳🏾‍♀' => 'mara liebsa turban: ton medju-skur tal-ġilda',
    '👳🏿‍♀' => 'mara liebsa turban: ton skur tal-ġilda',
    '🧙🏻‍♂' => 'raġel magu: ton ċar tal-ġilda',
    '🧙🏼‍♂' => 'raġel magu: ton medju-ċar tal-ġilda',
    '🧙🏽‍♂' => 'raġel magu: ton medju tal-ġilda',
    '🧙🏾‍♂' => 'raġel magu: ton medju-skur tal-ġilda',
    '🧙🏿‍♂' => 'raġel magu: ton skur tal-ġilda',
    '🧙🏻‍♀' => 'mara magu: ton ċar tal-ġilda',
    '🧙🏼‍♀' => 'mara magu: ton medju-ċar tal-ġilda',
    '🧙🏽‍♀' => 'mara magu: ton medju tal-ġilda',
    '🧙🏾‍♀' => 'mara magu: ton medju-skur tal-ġilda',
    '🧙🏿‍♀' => 'mara magu: ton skur tal-ġilda',
    '🧚🏻‍♂' => 'fatat maskil: ton ċar tal-ġilda',
    '🧚🏼‍♂' => 'fatat maskil: ton medju-ċar tal-ġilda',
    '🧚🏽‍♂' => 'fatat maskil: ton medju tal-ġilda',
    '🧚🏾‍♂' => 'fatat maskil: ton medju-skur tal-ġilda',
    '🧚🏿‍♂' => 'fatat maskil: ton skur tal-ġilda',
    '🧚🏻‍♀' => 'fatat femminil: ton ċar tal-ġilda',
    '🧚🏼‍♀' => 'fatat femminil: ton medju-ċar tal-ġilda',
    '🧚🏽‍♀' => 'fatat femminil: ton medju tal-ġilda',
    '🧚🏾‍♀' => 'fatat femminil: ton medju-skur tal-ġilda',
    '🧚🏿‍♀' => 'fatat femminil: ton skur tal-ġilda',
    '🧛🏻‍♂' => 'raġel vampira: ton ċar tal-ġilda',
    '🧛🏼‍♂' => 'raġel vampira: ton medju-ċar tal-ġilda',
    '🧛🏽‍♂' => 'raġel vampira: ton medju tal-ġilda',
    '🧛🏾‍♂' => 'raġel vampira: ton medju-skur tal-ġilda',
    '🧛🏿‍♂' => 'raġel vampira: ton skur tal-ġilda',
    '🧛🏻‍♀' => 'mara vampira: ton ċar tal-ġilda',
    '🧛🏼‍♀' => 'mara vampira: ton medju-ċar tal-ġilda',
    '🧛🏽‍♀' => 'mara vampira: ton medju tal-ġilda',
    '🧛🏾‍♀' => 'mara vampira: ton medju-skur tal-ġilda',
    '🧛🏿‍♀' => 'mara vampira: ton skur tal-ġilda',
    '🧜🏻‍♂' => 'merman: ton ċar tal-ġilda',
    '🧜🏼‍♂' => 'merman: ton medju-ċar tal-ġilda',
    '🧜🏽‍♂' => 'merman: ton medju tal-ġilda',
    '🧜🏾‍♂' => 'merman: ton medju-skur tal-ġilda',
    '🧜🏿‍♂' => 'merman: ton skur tal-ġilda',
    '🧜🏻‍♀' => 'serena: ton ċar tal-ġilda',
    '🧜🏼‍♀' => 'serena: ton medju-ċar tal-ġilda',
    '🧜🏽‍♀' => 'serena: ton medju tal-ġilda',
    '🧜🏾‍♀' => 'serena: ton medju-skur tal-ġilda',
    '🧜🏿‍♀' => 'serena: ton skur tal-ġilda',
    '🧝🏻‍♂' => 'għafrit raġel: ton ċar tal-ġilda',
    '🧝🏼‍♂' => 'għafrit raġel: ton medju-ċar tal-ġilda',
    '🧝🏽‍♂' => 'għafrit raġel: ton medju tal-ġilda',
    '🧝🏾‍♂' => 'għafrit raġel: ton medju-skur tal-ġilda',
    '🧝🏿‍♂' => 'għafrit raġel: ton skur tal-ġilda',
    '🧝🏻‍♀' => 'għafrit mara: ton ċar tal-ġilda',
    '🧝🏼‍♀' => 'għafrit mara: ton medju-ċar tal-ġilda',
    '🧝🏽‍♀' => 'għafrit mara: ton medju tal-ġilda',
    '🧝🏾‍♀' => 'għafrit mara: ton medju-skur tal-ġilda',
    '🧝🏿‍♀' => 'għafrit mara: ton skur tal-ġilda',
    '💆🏻‍♂' => 'raġel jingħata massaġġ: ton ċar tal-ġilda',
    '💆🏼‍♂' => 'raġel jingħata massaġġ: ton medju-ċar tal-ġilda',
    '💆🏽‍♂' => 'raġel jingħata massaġġ: ton medju tal-ġilda',
    '💆🏾‍♂' => 'raġel jingħata massaġġ: ton medju-skur tal-ġilda',
    '💆🏿‍♂' => 'raġel jingħata massaġġ: ton skur tal-ġilda',
    '💆🏻‍♀' => 'mara tingħata massaġġ: ton ċar tal-ġilda',
    '💆🏼‍♀' => 'mara tingħata massaġġ: ton medju-ċar tal-ġilda',
    '💆🏽‍♀' => 'mara tingħata massaġġ: ton medju tal-ġilda',
    '💆🏾‍♀' => 'mara tingħata massaġġ: ton medju-skur tal-ġilda',
    '💆🏿‍♀' => 'mara tingħata massaġġ: ton skur tal-ġilda',
    '💇🏻‍♂' => 'raġel jaqta’ xagħaru: ton ċar tal-ġilda',
    '💇🏼‍♂' => 'raġel jaqta’ xagħaru: ton medju-ċar tal-ġilda',
    '💇🏽‍♂' => 'raġel jaqta’ xagħaru: ton medju tal-ġilda',
    '💇🏾‍♂' => 'raġel jaqta’ xagħaru: ton medju-skur tal-ġilda',
    '💇🏿‍♂' => 'raġel jaqta’ xagħaru: ton skur tal-ġilda',
    '💇🏻‍♀' => 'mara taqta’ xagħarha: ton ċar tal-ġilda',
    '💇🏼‍♀' => 'mara taqta’ xagħarha: ton medju-ċar tal-ġilda',
    '💇🏽‍♀' => 'mara taqta’ xagħarha: ton medju tal-ġilda',
    '💇🏾‍♀' => 'mara taqta’ xagħarha: ton medju-skur tal-ġilda',
    '💇🏿‍♀' => 'mara taqta’ xagħarha: ton skur tal-ġilda',
    '🚶🏻‍♂' => 'raġel miexi: ton ċar tal-ġilda',
    '🚶🏼‍♂' => 'raġel miexi: ton medju-ċar tal-ġilda',
    '🚶🏽‍♂' => 'raġel miexi: ton medju tal-ġilda',
    '🚶🏾‍♂' => 'raġel miexi: ton medju-skur tal-ġilda',
    '🚶🏿‍♂' => 'raġel miexi: ton skur tal-ġilda',
    '🚶🏻‍♀' => 'mara miexja: ton ċar tal-ġilda',
    '🚶🏼‍♀' => 'mara miexja: ton medju-ċar tal-ġilda',
    '🚶🏽‍♀' => 'mara miexja: ton medju tal-ġilda',
    '🚶🏾‍♀' => 'mara miexja: ton medju-skur tal-ġilda',
    '🚶🏿‍♀' => 'mara miexja: ton skur tal-ġilda',
    '🏃🏻‍♂' => 'raġel qed jiġri: ton ċar tal-ġilda',
    '🏃🏼‍♂' => 'raġel qed jiġri: ton medju-ċar tal-ġilda',
    '🏃🏽‍♂' => 'raġel qed jiġri: ton medju tal-ġilda',
    '🏃🏾‍♂' => 'raġel qed jiġri: ton medju-skur tal-ġilda',
    '🏃🏿‍♂' => 'raġel qed jiġri: ton skur tal-ġilda',
    '🏃🏻‍♀' => 'mara qed tiġri: ton ċar tal-ġilda',
    '🏃🏼‍♀' => 'mara qed tiġri: ton medju-ċar tal-ġilda',
    '🏃🏽‍♀' => 'mara qed tiġri: ton medju tal-ġilda',
    '🏃🏾‍♀' => 'mara qed tiġri: ton medju-skur tal-ġilda',
    '🏃🏿‍♀' => 'mara qed tiġri: ton skur tal-ġilda',
    '👯🏻‍♀' => 'nisa b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda',
    '👯🏼‍♀' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda',
    '👯🏽‍♀' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda',
    '👯🏾‍♀' => 'nisa b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda',
    '👯🏿‍♀' => 'nisa b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda',
    '👯🏻‍♂' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda',
    '👯🏼‍♂' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda',
    '👯🏽‍♂' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda',
    '👯🏾‍♂' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda',
    '👯🏿‍♂' => 'rġiel b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda',
    '🧖🏻‍♂' => 'raġel f’kamra tal-fwar: ton ċar tal-ġilda',
    '🧖🏼‍♂' => 'raġel f’kamra tal-fwar: ton medju-ċar tal-ġilda',
    '🧖🏽‍♂' => 'raġel f’kamra tal-fwar: ton medju tal-ġilda',
    '🧖🏾‍♂' => 'raġel f’kamra tal-fwar: ton medju-skur tal-ġilda',
    '🧖🏿‍♂' => 'raġel f’kamra tal-fwar: ton skur tal-ġilda',
    '🧖🏻‍♀' => 'mara f’kamra tal-fwar: ton ċar tal-ġilda',
    '🧖🏼‍♀' => 'mara f’kamra tal-fwar: ton medju-ċar tal-ġilda',
    '🧖🏽‍♀' => 'mara f’kamra tal-fwar: ton medju tal-ġilda',
    '🧖🏾‍♀' => 'mara f’kamra tal-fwar: ton medju-skur tal-ġilda',
    '🧖🏿‍♀' => 'mara f’kamra tal-fwar: ton skur tal-ġilda',
    '🧗🏻‍♂' => 'raġel tiela’: ton ċar tal-ġilda',
    '🧗🏼‍♂' => 'raġel tiela’: ton medju-ċar tal-ġilda',
    '🧗🏽‍♂' => 'raġel tiela’: ton medju tal-ġilda',
    '🧗🏾‍♂' => 'raġel tiela’: ton medju-skur tal-ġilda',
    '🧗🏿‍♂' => 'raġel tiela’: ton skur tal-ġilda',
    '🧗🏻‍♀' => 'mara tiela’: ton ċar tal-ġilda',
    '🧗🏼‍♀' => 'mara tiela’: ton medju-ċar tal-ġilda',
    '🧗🏽‍♀' => 'mara tiela’: ton medju tal-ġilda',
    '🧗🏾‍♀' => 'mara tiela’: ton medju-skur tal-ġilda',
    '🧗🏿‍♀' => 'mara tiela’: ton skur tal-ġilda',
    '🏌🏻‍♂' => 'raġel jilgħab il-golf: ton ċar tal-ġilda',
    '🏌🏼‍♂' => 'raġel jilgħab il-golf: ton medju-ċar tal-ġilda',
    '🏌🏽‍♂' => 'raġel jilgħab il-golf: ton medju tal-ġilda',
    '🏌🏾‍♂' => 'raġel jilgħab il-golf: ton medju-skur tal-ġilda',
    '🏌🏿‍♂' => 'raġel jilgħab il-golf: ton skur tal-ġilda',
    '🏌🏻‍♀' => 'mara tilgħab il-golf: ton ċar tal-ġilda',
    '🏌🏼‍♀' => 'mara tilgħab il-golf: ton medju-ċar tal-ġilda',
    '🏌🏽‍♀' => 'mara tilgħab il-golf: ton medju tal-ġilda',
    '🏌🏾‍♀' => 'mara tilgħab il-golf: ton medju-skur tal-ġilda',
    '🏌🏿‍♀' => 'mara tilgħab il-golf: ton skur tal-ġilda',
    '🏄🏻‍♂' => 'raġel surfing: ton ċar tal-ġilda',
    '🏄🏼‍♂' => 'raġel surfing: ton medju-ċar tal-ġilda',
    '🏄🏽‍♂' => 'raġel surfing: ton medju tal-ġilda',
    '🏄🏾‍♂' => 'raġel surfing: ton medju-skur tal-ġilda',
    '🏄🏿‍♂' => 'raġel surfing: ton skur tal-ġilda',
    '🏄🏻‍♀' => 'mara surfing: ton ċar tal-ġilda',
    '🏄🏼‍♀' => 'mara surfing: ton medju-ċar tal-ġilda',
    '🏄🏽‍♀' => 'mara surfing: ton medju tal-ġilda',
    '🏄🏾‍♀' => 'mara surfing: ton medju-skur tal-ġilda',
    '🏄🏿‍♀' => 'mara surfing: ton skur tal-ġilda',
    '🚣🏻‍♂' => 'raġel taqdef dgħajsa: ton ċar tal-ġilda',
    '🚣🏼‍♂' => 'raġel taqdef dgħajsa: ton medju-ċar tal-ġilda',
    '🚣🏽‍♂' => 'raġel taqdef dgħajsa: ton medju tal-ġilda',
    '🚣🏾‍♂' => 'raġel taqdef dgħajsa: ton medju-skur tal-ġilda',
    '🚣🏿‍♂' => 'raġel taqdef dgħajsa: ton skur tal-ġilda',
    '🚣🏻‍♀' => 'mara taqdef dgħajsa: ton ċar tal-ġilda',
    '🚣🏼‍♀' => 'mara taqdef dgħajsa: ton medju-ċar tal-ġilda',
    '🚣🏽‍♀' => 'mara taqdef dgħajsa: ton medju tal-ġilda',
    '🚣🏾‍♀' => 'mara taqdef dgħajsa: ton medju-skur tal-ġilda',
    '🚣🏿‍♀' => 'mara taqdef dgħajsa: ton skur tal-ġilda',
    '🏊🏻‍♂' => 'raġel jgħum: ton ċar tal-ġilda',
    '🏊🏼‍♂' => 'raġel jgħum: ton medju-ċar tal-ġilda',
    '🏊🏽‍♂' => 'raġel jgħum: ton medju tal-ġilda',
    '🏊🏾‍♂' => 'raġel jgħum: ton medju-skur tal-ġilda',
    '🏊🏿‍♂' => 'raġel jgħum: ton skur tal-ġilda',
    '🏊🏻‍♀' => 'mara tgħum: ton ċar tal-ġilda',
    '🏊🏼‍♀' => 'mara tgħum: ton medju-ċar tal-ġilda',
    '🏊🏽‍♀' => 'mara tgħum: ton medju tal-ġilda',
    '🏊🏾‍♀' => 'mara tgħum: ton medju-skur tal-ġilda',
    '🏊🏿‍♀' => 'mara tgħum: ton skur tal-ġilda',
    '⛹🏻‍♂' => 'raġel iqabbeż ballun: ton ċar tal-ġilda',
    '⛹🏼‍♂' => 'raġel iqabbeż ballun: ton medju-ċar tal-ġilda',
    '⛹🏽‍♂' => 'raġel iqabbeż ballun: ton medju tal-ġilda',
    '⛹🏾‍♂' => 'raġel iqabbeż ballun: ton medju-skur tal-ġilda',
    '⛹🏿‍♂' => 'raġel iqabbeż ballun: ton skur tal-ġilda',
    '⛹🏻‍♀' => 'mara tqabbeż ballun: ton ċar tal-ġilda',
    '⛹🏼‍♀' => 'mara tqabbeż ballun: ton medju-ċar tal-ġilda',
    '⛹🏽‍♀' => 'mara tqabbeż ballun: ton medju tal-ġilda',
    '⛹🏾‍♀' => 'mara tqabbeż ballun: ton medju-skur tal-ġilda',
    '⛹🏿‍♀' => 'mara tqabbeż ballun: ton skur tal-ġilda',
    '🏋🏻‍♂' => 'raġel jerfa’ l-piżijiet: ton ċar tal-ġilda',
    '🏋🏼‍♂' => 'raġel jerfa’ l-piżijiet: ton medju-ċar tal-ġilda',
    '🏋🏽‍♂' => 'raġel jerfa’ l-piżijiet: ton medju tal-ġilda',
    '🏋🏾‍♂' => 'raġel jerfa’ l-piżijiet: ton medju-skur tal-ġilda',
    '🏋🏿‍♂' => 'raġel jerfa’ l-piżijiet: ton skur tal-ġilda',
    '🏋🏻‍♀' => 'mara terfa’ l-piżijiet: ton ċar tal-ġilda',
    '🏋🏼‍♀' => 'mara terfa’ l-piżijiet: ton medju-ċar tal-ġilda',
    '🏋🏽‍♀' => 'mara terfa’ l-piżijiet: ton medju tal-ġilda',
    '🏋🏾‍♀' => 'mara terfa’ l-piżijiet: ton medju-skur tal-ġilda',
    '🏋🏿‍♀' => 'mara terfa’ l-piżijiet: ton skur tal-ġilda',
    '🚴🏻‍♂' => 'raġel isuq rota: ton ċar tal-ġilda',
    '🚴🏼‍♂' => 'raġel isuq rota: ton medju-ċar tal-ġilda',
    '🚴🏽‍♂' => 'raġel isuq rota: ton medju tal-ġilda',
    '🚴🏾‍♂' => 'raġel isuq rota: ton medju-skur tal-ġilda',
    '🚴🏿‍♂' => 'raġel isuq rota: ton skur tal-ġilda',
    '🚴🏻‍♀' => 'mara ssuq rota: ton ċar tal-ġilda',
    '🚴🏼‍♀' => 'mara ssuq rota: ton medju-ċar tal-ġilda',
    '🚴🏽‍♀' => 'mara ssuq rota: ton medju tal-ġilda',
    '🚴🏾‍♀' => 'mara ssuq rota: ton medju-skur tal-ġilda',
    '🚴🏿‍♀' => 'mara ssuq rota: ton skur tal-ġilda',
    '🚵🏻‍♂' => 'raġel isuq mountain bike: ton ċar tal-ġilda',
    '🚵🏼‍♂' => 'raġel isuq mountain bike: ton medju-ċar tal-ġilda',
    '🚵🏽‍♂' => 'raġel isuq mountain bike: ton medju tal-ġilda',
    '🚵🏾‍♂' => 'raġel isuq mountain bike: ton medju-skur tal-ġilda',
    '🚵🏿‍♂' => 'raġel isuq mountain bike: ton skur tal-ġilda',
    '🚵🏻‍♀' => 'mara ssuq mountain bike: ton ċar tal-ġilda',
    '🚵🏼‍♀' => 'mara ssuq mountain bike: ton medju-ċar tal-ġilda',
    '🚵🏽‍♀' => 'mara ssuq mountain bike: ton medju tal-ġilda',
    '🚵🏾‍♀' => 'mara ssuq mountain bike: ton medju-skur tal-ġilda',
    '🚵🏿‍♀' => 'mara ssuq mountain bike: ton skur tal-ġilda',
    '🤸🏻‍♂' => 'raġel jagħmel gabrijoli: ton ċar tal-ġilda',
    '🤸🏼‍♂' => 'raġel jagħmel gabrijoli: ton medju-ċar tal-ġilda',
    '🤸🏽‍♂' => 'raġel jagħmel gabrijoli: ton medju tal-ġilda',
    '🤸🏾‍♂' => 'raġel jagħmel gabrijoli: ton medju-skur tal-ġilda',
    '🤸🏿‍♂' => 'raġel jagħmel gabrijoli: ton skur tal-ġilda',
    '🤸🏻‍♀' => 'mara tagħmel gabrijoli: ton ċar tal-ġilda',
    '🤸🏼‍♀' => 'mara tagħmel gabrijoli: ton medju-ċar tal-ġilda',
    '🤸🏽‍♀' => 'mara tagħmel gabrijoli: ton medju tal-ġilda',
    '🤸🏾‍♀' => 'mara tagħmel gabrijoli: ton medju-skur tal-ġilda',
    '🤸🏿‍♀' => 'mara tagħmel gabrijoli: ton skur tal-ġilda',
    '🤼🏻‍♀' => 'nisa jagħmlu r-wrestling: ton ċar tal-ġilda',
    '🤼🏼‍♀' => 'nisa jagħmlu r-wrestling: ton medju-ċar tal-ġilda',
    '🤼🏽‍♀' => 'nisa jagħmlu r-wrestling: ton medju tal-ġilda',
    '🤼🏾‍♀' => 'nisa jagħmlu r-wrestling: ton medju-skur tal-ġilda',
    '🤼🏿‍♀' => 'nisa jagħmlu r-wrestling: ton skur tal-ġilda',
    '🤼🏻‍♂' => 'irġiel jagħmlu r-wrestling: ton ċar tal-ġilda',
    '🤼🏼‍♂' => 'irġiel jagħmlu r-wrestling: ton medju-ċar tal-ġilda',
    '🤼🏽‍♂' => 'irġiel jagħmlu r-wrestling: ton medju tal-ġilda',
    '🤼🏾‍♂' => 'irġiel jagħmlu r-wrestling: ton medju-skur tal-ġilda',
    '🤼🏿‍♂' => 'irġiel jagħmlu r-wrestling: ton skur tal-ġilda',
    '🤽🏻‍♂' => 'raġel jilgħab il-waterpolo: ton ċar tal-ġilda',
    '🤽🏼‍♂' => 'raġel jilgħab il-waterpolo: ton medju-ċar tal-ġilda',
    '🤽🏽‍♂' => 'raġel jilgħab il-waterpolo: ton medju tal-ġilda',
    '🤽🏾‍♂' => 'raġel jilgħab il-waterpolo: ton medju-skur tal-ġilda',
    '🤽🏿‍♂' => 'raġel jilgħab il-waterpolo: ton skur tal-ġilda',
    '🤽🏻‍♀' => 'mara tilgħab il-waterpolo: ton ċar tal-ġilda',
    '🤽🏼‍♀' => 'mara tilgħab il-waterpolo: ton medju-ċar tal-ġilda',
    '🤽🏽‍♀' => 'mara tilgħab il-waterpolo: ton medju tal-ġilda',
    '🤽🏾‍♀' => 'mara tilgħab il-waterpolo: ton medju-skur tal-ġilda',
    '🤽🏿‍♀' => 'mara tilgħab il-waterpolo: ton skur tal-ġilda',
    '🤾🏻‍♂' => 'raġel jilgħab il-handball: ton ċar tal-ġilda',
    '🤾🏼‍♂' => 'raġel jilgħab il-handball: ton medju-ċar tal-ġilda',
    '🤾🏽‍♂' => 'raġel jilgħab il-handball: ton medju tal-ġilda',
    '🤾🏾‍♂' => 'raġel jilgħab il-handball: ton medju-skur tal-ġilda',
    '🤾🏿‍♂' => 'raġel jilgħab il-handball: ton skur tal-ġilda',
    '🤾🏻‍♀' => 'mara tilgħab il-handball: ton ċar tal-ġilda',
    '🤾🏼‍♀' => 'mara tilgħab il-handball: ton medju-ċar tal-ġilda',
    '🤾🏽‍♀' => 'mara tilgħab il-handball: ton medju tal-ġilda',
    '🤾🏾‍♀' => 'mara tilgħab il-handball: ton medju-skur tal-ġilda',
    '🤾🏿‍♀' => 'mara tilgħab il-handball: ton skur tal-ġilda',
    '🤹🏻‍♂' => 'raġel jagħmel il-juggling: ton ċar tal-ġilda',
    '🤹🏼‍♂' => 'raġel jagħmel il-juggling: ton medju-ċar tal-ġilda',
    '🤹🏽‍♂' => 'raġel jagħmel il-juggling: ton medju tal-ġilda',
    '🤹🏾‍♂' => 'raġel jagħmel il-juggling: ton medju-skur tal-ġilda',
    '🤹🏿‍♂' => 'raġel jagħmel il-juggling: ton skur tal-ġilda',
    '🤹🏻‍♀' => 'mara tagħmel il-juggling: ton ċar tal-ġilda',
    '🤹🏼‍♀' => 'mara tagħmel il-juggling: ton medju-ċar tal-ġilda',
    '🤹🏽‍♀' => 'mara tagħmel il-juggling: ton medju tal-ġilda',
    '🤹🏾‍♀' => 'mara tagħmel il-juggling: ton medju-skur tal-ġilda',
    '🤹🏿‍♀' => 'mara tagħmel il-juggling: ton skur tal-ġilda',
    '🧘🏻‍♂' => 'raġel fil-pożizzjoni ta’ lotus: ton ċar tal-ġilda',
    '🧘🏼‍♂' => 'raġel fil-pożizzjoni ta’ lotus: ton medju-ċar tal-ġilda',
    '🧘🏽‍♂' => 'raġel fil-pożizzjoni ta’ lotus: ton medju tal-ġilda',
    '🧘🏾‍♂' => 'raġel fil-pożizzjoni ta’ lotus: ton medju-skur tal-ġilda',
    '🧘🏿‍♂' => 'raġel fil-pożizzjoni ta’ lotus: ton skur tal-ġilda',
    '🧘🏻‍♀' => 'mara fil-pożizzjoni ta’ lotus: ton ċar tal-ġilda',
    '🧘🏼‍♀' => 'mara fil-pożizzjoni ta’ lotus: ton medju-ċar tal-ġilda',
    '🧘🏽‍♀' => 'mara fil-pożizzjoni ta’ lotus: ton medju tal-ġilda',
    '🧘🏾‍♀' => 'mara fil-pożizzjoni ta’ lotus: ton medju-skur tal-ġilda',
    '🧘🏿‍♀' => 'mara fil-pożizzjoni ta’ lotus: ton skur tal-ġilda',
    '👨‍👦' => 'familja: raġel u tifel',
    '👨‍👧' => 'familja: raġel u tifla',
    '👩‍👦' => 'familja: mara u tifel',
    '👩‍👧' => 'familja: mara u tifla',
    '👁‍🗨' => 'għajnejn f’bużżieqa tad-diskors',
    '👱‍♂' => 'raġel b’xagħar isfar',
    '👱‍♀' => 'mara b’xagħar isfar',
    '🙍‍♂' => 'raġel jitkerrah',
    '🙍‍♀' => 'mara titkerrah',
    '🙎‍♂' => 'raġel jisporġi x-xofftejn',
    '🙎‍♀' => 'mara tisporġi x-xofftejn',
    '🙅‍♂' => 'raġel jagħmel sinjal ta’ LE',
    '🙅‍♀' => 'mara tagħmel sinjal ta’ LE',
    '🙆‍♂' => 'raġel jagħmel sinjal ta’ OK',
    '🙆‍♀' => 'mara tagħmel sinjal ta’ OK',
    '💁‍♂' => 'raġel ibaxxi idejh',
    '💁‍♀' => 'mara tbaxxi idha',
    '🙋‍♂' => 'raġel jgħolli idejh',
    '🙋‍♀' => 'mara tgħolli idha',
    '🙇‍♂' => 'raġel jikina',
    '🙇‍♀' => 'mara tikina',
    '🤦‍♂' => 'raġel jagħmel facepalming',
    '🤦‍♀' => 'mara tagħmel facepalming',
    '🤷‍♂' => 'raġel ixengel spallejh',
    '🤷‍♀' => 'mara xxengel spallejha',
    '👨‍⚕' => 'ħaddiem fil-kura tal-bniedem',
    '👩‍⚕' => 'mara fil-kura tas-saħħa',
    '👨‍🎓' => 'student maskil',
    '👩‍🎓' => 'student femminil',
    '👨‍🏫' => 'għalliem',
    '👩‍🏫' => 'għalliema',
    '👨‍⚖' => 'imħallef maskil',
    '👩‍⚖' => 'imħallef mara',
    '👨‍🌾' => 'bidwi maskil',
    '👩‍🌾' => 'bidwi femminil',
    '👨‍🍳' => 'kok maskil',
    '👩‍🍳' => 'kok femminil',
    '👨‍🔧' => 'mekkanik maskili',
    '👩‍🔧' => 'mekkanik mara',
    '👨‍🏭' => 'ħaddiem tal-fabbrika',
    '👩‍🏭' => 'ħaddiema tal-fabbrika',
    '👨‍💼' => 'raġel jaħdem f’uffiċċju',
    '👩‍💼' => 'mara taħdem f’uffiċċju',
    '👨‍🔬' => 'xjenzat maskili',
    '👩‍🔬' => 'xjenzata mara',
    '👨‍💻' => 'teknoloġist maskili',
    '👩‍💻' => 'teknoloġist femminili',
    '👨‍🎤' => 'kantant maskili',
    '👩‍🎤' => 'katant femminil',
    '👨‍🎨' => 'artist maskili',
    '👩‍🎨' => 'artist femminil',
    '👨‍✈' => 'pilota tal-bniedem',
    '👩‍✈' => 'pilota mara',
    '👨‍🚀' => 'astronawt maskil',
    '👩‍🚀' => 'astronawta mara',
    '👨‍🚒' => 'ħaddiem tat-tifi tan-nar maskil',
    '👩‍🚒' => 'ħaddiem tat-tifi tan-nar femminil',
    '👮‍♂' => 'uffiċjal tal-pulizija raġel',
    '👮‍♀' => 'uffiċjal tal-pulizija mara',
    '🕵‍♂' => 'ditektiv raġel',
    '🕵‍♀' => 'ditektiv mara',
    '💂‍♂' => 'gwardjan raġel',
    '💂‍♀' => 'gwardjan mara',
    '👷‍♂' => 'ħaddiem tal-kostruzzjoni maskili',
    '👷‍♀' => 'ħaddiem tal-kostruzzjoni femminili',
    '👳‍♂' => 'raġel liebes turban',
    '👳‍♀' => 'mara liebsa turban',
    '🧙‍♂' => 'raġel magu',
    '🧙‍♀' => 'mara magu',
    '🧚‍♂' => 'fatat maskil',
    '🧚‍♀' => 'fatat femminil',
    '🧛‍♂' => 'raġel vampira',
    '🧛‍♀' => 'mara vampira',
    '🧜‍♂' => 'merman',
    '🧜‍♀' => 'serena',
    '🧝‍♂' => 'għafrit raġel',
    '🧝‍♀' => 'għafrit mara',
    '🧞‍♂' => 'ġenju raġel',
    '🧞‍♀' => 'ġenju mara',
    '🧟‍♂' => 'raġel żombi',
    '🧟‍♀' => 'mara żombi',
    '💆‍♂' => 'raġel jingħata massaġġ',
    '💆‍♀' => 'mara tingħata massaġġ',
    '💇‍♂' => 'raġel jaqta’ xagħaru',
    '💇‍♀' => 'mara taqta’ xagħarha',
    '🚶‍♂' => 'raġel miexi',
    '🚶‍♀' => 'mara miexja',
    '🏃‍♂' => 'raġel qed jiġri',
    '🏃‍♀' => 'mara qed tiġri',
    '👯‍♂' => 'rġiel b’widnejn ta’ fenek jiddevertu',
    '👯‍♀' => 'nisa b’widnejn ta’ fenek jiddevertu',
    '🧖‍♂' => 'raġel f’kamra tal-fwar',
    '🧖‍♀' => 'mara f’kamra tal-fwar',
    '🧗‍♂' => 'raġel tiela’',
    '🧗‍♀' => 'mara tiela’',
    '🏌‍♂' => 'raġel jilgħab il-golf',
    '🏌‍♀' => 'mara tilgħab il-golf',
    '🏄‍♂' => 'raġel surfing',
    '🏄‍♀' => 'mara surfing',
    '🚣‍♂' => 'raġel taqdef dgħajsa',
    '🚣‍♀' => 'mara taqdef dgħajsa',
    '🏊‍♂' => 'raġel jgħum',
    '🏊‍♀' => 'mara tgħum',
    '⛹‍♂' => 'raġel iqabbeż ballun',
    '⛹‍♀' => 'mara tqabbeż ballun',
    '🏋‍♂' => 'raġel jerfa’ l-piżijiet',
    '🏋‍♀' => 'mara terfa’ l-piżijiet',
    '🚴‍♂' => 'raġel isuq rota',
    '🚴‍♀' => 'mara ssuq rota',
    '🚵‍♂' => 'raġel isuq mountain bike',
    '🚵‍♀' => 'mara ssuq mountain bike',
    '🤸‍♂' => 'raġel jagħmel gabrijoli',
    '🤸‍♀' => 'mara tagħmel gabrijoli',
    '🤼‍♂' => 'irġiel jagħmlu r-wrestling',
    '🤼‍♀' => 'nisa jagħmlu r-wrestling',
    '🤽‍♂' => 'raġel jilgħab il-waterpolo',
    '🤽‍♀' => 'mara tilgħab il-waterpolo',
    '🤾‍♂' => 'raġel jilgħab il-handball',
    '🤾‍♀' => 'mara tilgħab il-handball',
    '🤹‍♂' => 'raġel jagħmel il-juggling',
    '🤹‍♀' => 'mara tagħmel il-juggling',
    '🧘‍♂' => 'raġel fil-pożizzjoni ta’ lotus',
    '🧘‍♀' => 'mara fil-pożizzjoni ta’ lotus',
    '🏳‍🌈' => 'bandiera tal-qawsalla',
    '👋🏻' => 'id ixxejjer: ton ċar tal-ġilda',
    '👋🏼' => 'id ixxejjer: ton medju-ċar tal-ġilda',
    '👋🏽' => 'id ixxejjer: ton medju tal-ġilda',
    '👋🏾' => 'id ixxejjer: ton medju-skur tal-ġilda',
    '👋🏿' => 'id ixxejjer: ton skur tal-ġilda',
    '🤚🏻' => 'id minn wara mgħollija: ton ċar tal-ġilda',
    '🤚🏼' => 'id minn wara mgħollija: ton medju-ċar tal-ġilda',
    '🤚🏽' => 'id minn wara mgħollija: ton medju tal-ġilda',
    '🤚🏾' => 'id minn wara mgħollija: ton medju-skur tal-ġilda',
    '🤚🏿' => 'id minn wara mgħollija: ton skur tal-ġilda',
    '🖐🏻' => 'id mgħollija bl-iswaba’ mfettħa: ton ċar tal-ġilda',
    '🖐🏼' => 'id mgħollija bl-iswaba’ mfettħa: ton medju-ċar tal-ġilda',
    '🖐🏽' => 'id mgħollija bl-iswaba’ mfettħa: ton medju tal-ġilda',
    '🖐🏾' => 'id mgħollija bl-iswaba’ mfettħa: ton medju-skur tal-ġilda',
    '🖐🏿' => 'id mgħollija bl-iswaba’ mfettħa: ton skur tal-ġilda',
    '✋🏻' => 'id mgħollija: ton ċar tal-ġilda',
    '✋🏼' => 'id mgħollija: ton medju-ċar tal-ġilda',
    '✋🏽' => 'id mgħollija: ton medju tal-ġilda',
    '✋🏾' => 'id mgħollija: ton medju-skur tal-ġilda',
    '✋🏿' => 'id mgħollija: ton skur tal-ġilda',
    '🖖🏻' => 'salut ta’ vulcan: ton ċar tal-ġilda',
    '🖖🏼' => 'salut ta’ vulcan: ton medju-ċar tal-ġilda',
    '🖖🏽' => 'salut ta’ vulcan: ton medju tal-ġilda',
    '🖖🏾' => 'salut ta’ vulcan: ton medju-skur tal-ġilda',
    '🖖🏿' => 'salut ta’ vulcan: ton skur tal-ġilda',
    '👌🏻' => 'id OK: ton ċar tal-ġilda',
    '👌🏼' => 'id OK: ton medju-ċar tal-ġilda',
    '👌🏽' => 'id OK: ton medju tal-ġilda',
    '👌🏾' => 'id OK: ton medju-skur tal-ġilda',
    '👌🏿' => 'id OK: ton skur tal-ġilda',
    '✌🏻' => 'id tar-rebħa: ton ċar tal-ġilda',
    '✌🏼' => 'id tar-rebħa: ton medju-ċar tal-ġilda',
    '✌🏽' => 'id tar-rebħa: ton medju tal-ġilda',
    '✌🏾' => 'id tar-rebħa: ton medju-skur tal-ġilda',
    '✌🏿' => 'id tar-rebħa: ton skur tal-ġilda',
    '🤞🏻' => 'swaba nkroċjati: ton ċar tal-ġilda',
    '🤞🏼' => 'swaba nkroċjati: ton medju-ċar tal-ġilda',
    '🤞🏽' => 'swaba nkroċjati: ton medju tal-ġilda',
    '🤞🏾' => 'swaba nkroċjati: ton medju-skur tal-ġilda',
    '🤞🏿' => 'swaba nkroċjati: ton skur tal-ġilda',
    '🤟🏻' => 'ġest ta’ mħabba: ton ċar tal-ġilda',
    '🤟🏼' => 'ġest ta’ mħabba: ton medju-ċar tal-ġilda',
    '🤟🏽' => 'ġest ta’ mħabba: ton medju tal-ġilda',
    '🤟🏾' => 'ġest ta’ mħabba: ton medju-skur tal-ġilda',
    '🤟🏿' => 'ġest ta’ mħabba: ton skur tal-ġilda',
    '🤘🏻' => 'sinjal tal-qrun: ton ċar tal-ġilda',
    '🤘🏼' => 'sinjal tal-qrun: ton medju-ċar tal-ġilda',
    '🤘🏽' => 'sinjal tal-qrun: ton medju tal-ġilda',
    '🤘🏾' => 'sinjal tal-qrun: ton medju-skur tal-ġilda',
    '🤘🏿' => 'sinjal tal-qrun: ton skur tal-ġilda',
    '🤙🏻' => 'id ċempilli: ton ċar tal-ġilda',
    '🤙🏼' => 'id ċempilli: ton medju-ċar tal-ġilda',
    '🤙🏽' => 'id ċempilli: ton medju tal-ġilda',
    '🤙🏾' => 'id ċempilli: ton medju-skur tal-ġilda',
    '🤙🏿' => 'id ċempilli: ton skur tal-ġilda',
    '👈🏻' => 'indiċi b’lura iipponta lejn ix-xellug: ton ċar tal-ġilda',
    '👈🏼' => 'indiċi b’lura iipponta lejn ix-xellug: ton medju-ċar tal-ġilda',
    '👈🏽' => 'indiċi b’lura iipponta lejn ix-xellug: ton medju tal-ġilda',
    '👈🏾' => 'indiċi b’lura iipponta lejn ix-xellug: ton medju-skur tal-ġilda',
    '👈🏿' => 'indiċi b’lura iipponta lejn ix-xellug: ton skur tal-ġilda',
    '👉🏻' => 'indiċi b’lura li jipponta lejn il-lemin: ton ċar tal-ġilda',
    '👉🏼' => 'indiċi b’lura li jipponta lejn il-lemin: ton medju-ċar tal-ġilda',
    '👉🏽' => 'indiċi b’lura li jipponta lejn il-lemin: ton medju tal-ġilda',
    '👉🏾' => 'indiċi b’lura li jipponta lejn il-lemin: ton medju-skur tal-ġilda',
    '👉🏿' => 'indiċi b’lura li jipponta lejn il-lemin: ton skur tal-ġilda',
    '👆🏻' => 'indiċi b’lura li jipponta ’l fuq: ton ċar tal-ġilda',
    '👆🏼' => 'indiċi b’lura li jipponta ’l fuq: ton medju-ċar tal-ġilda',
    '👆🏽' => 'indiċi b’lura li jipponta ’l fuq: ton medju tal-ġilda',
    '👆🏾' => 'indiċi b’lura li jipponta ’l fuq: ton medju-skur tal-ġilda',
    '👆🏿' => 'indiċi b’lura li jipponta ’l fuq: ton skur tal-ġilda',
    '🖕🏻' => 'suba’ tan-nofs: ton ċar tal-ġilda',
    '🖕🏼' => 'suba’ tan-nofs: ton medju-ċar tal-ġilda',
    '🖕🏽' => 'suba’ tan-nofs: ton medju tal-ġilda',
    '🖕🏾' => 'suba’ tan-nofs: ton medju-skur tal-ġilda',
    '🖕🏿' => 'suba’ tan-nofs: ton skur tal-ġilda',
    '👇🏻' => 'indiċi b’lura li jipponta ’l isfel: ton ċar tal-ġilda',
    '👇🏼' => 'indiċi b’lura li jipponta ’l isfel: ton medju-ċar tal-ġilda',
    '👇🏽' => 'indiċi b’lura li jipponta ’l isfel: ton medju tal-ġilda',
    '👇🏾' => 'indiċi b’lura li jipponta ’l isfel: ton medju-skur tal-ġilda',
    '👇🏿' => 'indiċi b’lura li jipponta ’l isfel: ton skur tal-ġilda',
    '☝🏻' => 'indiċi li jipponta ’l fuq: ton ċar tal-ġilda',
    '☝🏼' => 'indiċi li jipponta ’l fuq: ton medju-ċar tal-ġilda',
    '☝🏽' => 'indiċi li jipponta ’l fuq: ton medju tal-ġilda',
    '☝🏾' => 'indiċi li jipponta ’l fuq: ton medju-skur tal-ġilda',
    '☝🏿' => 'indiċi li jipponta ’l fuq: ton skur tal-ġilda',
    '👍🏻' => 'behem ’il fuq: ton ċar tal-ġilda',
    '👍🏼' => 'behem ’il fuq: ton medju-ċar tal-ġilda',
    '👍🏽' => 'behem ’il fuq: ton medju tal-ġilda',
    '👍🏾' => 'behem ’il fuq: ton medju-skur tal-ġilda',
    '👍🏿' => 'behem ’il fuq: ton skur tal-ġilda',
    '👎🏻' => 'behem ’l isfel: ton ċar tal-ġilda',
    '👎🏼' => 'behem ’l isfel: ton medju-ċar tal-ġilda',
    '👎🏽' => 'behem ’l isfel: ton medju tal-ġilda',
    '👎🏾' => 'behem ’l isfel: ton medju-skur tal-ġilda',
    '👎🏿' => 'behem ’l isfel: ton skur tal-ġilda',
    '✊🏻' => 'ponn mgħolli: ton ċar tal-ġilda',
    '✊🏼' => 'ponn mgħolli: ton medju-ċar tal-ġilda',
    '✊🏽' => 'ponn mgħolli: ton medju tal-ġilda',
    '✊🏾' => 'ponn mgħolli: ton medju-skur tal-ġilda',
    '✊🏿' => 'ponn mgħolli: ton skur tal-ġilda',
    '👊🏻' => 'ponn dieħel: ton ċar tal-ġilda',
    '👊🏼' => 'ponn dieħel: ton medju-ċar tal-ġilda',
    '👊🏽' => 'ponn dieħel: ton medju tal-ġilda',
    '👊🏾' => 'ponn dieħel: ton medju-skur tal-ġilda',
    '👊🏿' => 'ponn dieħel: ton skur tal-ġilda',
    '🤛🏻' => 'ponn iħares lejn ix-xellug: ton ċar tal-ġilda',
    '🤛🏼' => 'ponn iħares lejn ix-xellug: ton medju-ċar tal-ġilda',
    '🤛🏽' => 'ponn iħares lejn ix-xellug: ton medju tal-ġilda',
    '🤛🏾' => 'ponn iħares lejn ix-xellug: ton medju-skur tal-ġilda',
    '🤛🏿' => 'ponn iħares lejn ix-xellug: ton skur tal-ġilda',
    '🤜🏻' => 'ponn iħares lemin: ton ċar tal-ġilda',
    '🤜🏼' => 'ponn iħares lemin: ton medju-ċar tal-ġilda',
    '🤜🏽' => 'ponn iħares lemin: ton medju tal-ġilda',
    '🤜🏾' => 'ponn iħares lemin: ton medju-skur tal-ġilda',
    '🤜🏿' => 'ponn iħares lemin: ton skur tal-ġilda',
    '👏🏻' => 'idejn iċapċpu: ton ċar tal-ġilda',
    '👏🏼' => 'idejn iċapċpu: ton medju-ċar tal-ġilda',
    '👏🏽' => 'idejn iċapċpu: ton medju tal-ġilda',
    '👏🏾' => 'idejn iċapċpu: ton medju-skur tal-ġilda',
    '👏🏿' => 'idejn iċapċpu: ton skur tal-ġilda',
    '🙌🏻' => 'idejn mgħollija: ton ċar tal-ġilda',
    '🙌🏼' => 'idejn mgħollija: ton medju-ċar tal-ġilda',
    '🙌🏽' => 'idejn mgħollija: ton medju tal-ġilda',
    '🙌🏾' => 'idejn mgħollija: ton medju-skur tal-ġilda',
    '🙌🏿' => 'idejn mgħollija: ton skur tal-ġilda',
    '👐🏻' => 'idejn miftuħa: ton ċar tal-ġilda',
    '👐🏼' => 'idejn miftuħa: ton medju-ċar tal-ġilda',
    '👐🏽' => 'idejn miftuħa: ton medju tal-ġilda',
    '👐🏾' => 'idejn miftuħa: ton medju-skur tal-ġilda',
    '👐🏿' => 'idejn miftuħa: ton skur tal-ġilda',
    '🤲🏻' => 'pali tal-idejn flimkien: ton ċar tal-ġilda',
    '🤲🏼' => 'pali tal-idejn flimkien: ton medju-ċar tal-ġilda',
    '🤲🏽' => 'pali tal-idejn flimkien: ton medju tal-ġilda',
    '🤲🏾' => 'pali tal-idejn flimkien: ton medju-skur tal-ġilda',
    '🤲🏿' => 'pali tal-idejn flimkien: ton skur tal-ġilda',
    '🤝🏻' => 'ħu bl-idejn: ton ċar tal-ġilda',
    '🤝🏼' => 'ħu bl-idejn: ton medju-ċar tal-ġilda',
    '🤝🏽' => 'ħu bl-idejn: ton medju tal-ġilda',
    '🤝🏾' => 'ħu bl-idejn: ton medju-skur tal-ġilda',
    '🤝🏿' => 'ħu bl-idejn: ton skur tal-ġilda',
    '🙏🏻' => 'idejn magħluqa: ton ċar tal-ġilda',
    '🙏🏼' => 'idejn magħluqa: ton medju-ċar tal-ġilda',
    '🙏🏽' => 'idejn magħluqa: ton medju tal-ġilda',
    '🙏🏾' => 'idejn magħluqa: ton medju-skur tal-ġilda',
    '🙏🏿' => 'idejn magħluqa: ton skur tal-ġilda',
    '✍🏻' => 'id li tikteb biha: ton ċar tal-ġilda',
    '✍🏼' => 'id li tikteb biha: ton medju-ċar tal-ġilda',
    '✍🏽' => 'id li tikteb biha: ton medju tal-ġilda',
    '✍🏾' => 'id li tikteb biha: ton medju-skur tal-ġilda',
    '✍🏿' => 'id li tikteb biha: ton skur tal-ġilda',
    '💅🏻' => 'nail polish: ton ċar tal-ġilda',
    '💅🏼' => 'nail polish: ton medju-ċar tal-ġilda',
    '💅🏽' => 'nail polish: ton medju tal-ġilda',
    '💅🏾' => 'nail polish: ton medju-skur tal-ġilda',
    '💅🏿' => 'nail polish: ton skur tal-ġilda',
    '🤳🏻' => 'stessu: ton ċar tal-ġilda',
    '🤳🏼' => 'stessu: ton medju-ċar tal-ġilda',
    '🤳🏽' => 'stessu: ton medju tal-ġilda',
    '🤳🏾' => 'stessu: ton medju-skur tal-ġilda',
    '🤳🏿' => 'stessu: ton skur tal-ġilda',
    '💪🏻' => 'biceps bil-muskoli: ton ċar tal-ġilda',
    '💪🏼' => 'biceps bil-muskoli: ton medju-ċar tal-ġilda',
    '💪🏽' => 'biceps bil-muskoli: ton medju tal-ġilda',
    '💪🏾' => 'biceps bil-muskoli: ton medju-skur tal-ġilda',
    '💪🏿' => 'biceps bil-muskoli: ton skur tal-ġilda',
    '👂🏻' => 'widna: ton ċar tal-ġilda',
    '👂🏼' => 'widna: ton medju-ċar tal-ġilda',
    '👂🏽' => 'widna: ton medju tal-ġilda',
    '👂🏾' => 'widna: ton medju-skur tal-ġilda',
    '👂🏿' => 'widna: ton skur tal-ġilda',
    '👃🏻' => 'imnieħer: ton ċar tal-ġilda',
    '👃🏼' => 'imnieħer: ton medju-ċar tal-ġilda',
    '👃🏽' => 'imnieħer: ton medju tal-ġilda',
    '👃🏾' => 'imnieħer: ton medju-skur tal-ġilda',
    '👃🏿' => 'imnieħer: ton skur tal-ġilda',
    '👶🏻' => 'tarbija: ton ċar tal-ġilda',
    '👶🏼' => 'tarbija: ton medju-ċar tal-ġilda',
    '👶🏽' => 'tarbija: ton medju tal-ġilda',
    '👶🏾' => 'tarbija: ton medju-skur tal-ġilda',
    '👶🏿' => 'tarbija: ton skur tal-ġilda',
    '🧒🏻' => 'tfal: ton ċar tal-ġilda',
    '🧒🏼' => 'tfal: ton medju-ċar tal-ġilda',
    '🧒🏽' => 'tfal: ton medju tal-ġilda',
    '🧒🏾' => 'tfal: ton medju-skur tal-ġilda',
    '🧒🏿' => 'tfal: ton skur tal-ġilda',
    '👦🏻' => 'tifel: ton ċar tal-ġilda',
    '👦🏼' => 'tifel: ton medju-ċar tal-ġilda',
    '👦🏽' => 'tifel: ton medju tal-ġilda',
    '👦🏾' => 'tifel: ton medju-skur tal-ġilda',
    '👦🏿' => 'tifel: ton skur tal-ġilda',
    '👧🏻' => 'tifla: ton ċar tal-ġilda',
    '👧🏼' => 'tifla: ton medju-ċar tal-ġilda',
    '👧🏽' => 'tifla: ton medju tal-ġilda',
    '👧🏾' => 'tifla: ton medju-skur tal-ġilda',
    '👧🏿' => 'tifla: ton skur tal-ġilda',
    '🧑🏻' => 'adult: ton ċar tal-ġilda',
    '🧑🏼' => 'adult: ton medju-ċar tal-ġilda',
    '🧑🏽' => 'adult: ton medju tal-ġilda',
    '🧑🏾' => 'adult: ton medju-skur tal-ġilda',
    '🧑🏿' => 'adult: ton skur tal-ġilda',
    '👱🏻' => 'persuna b’xagħar isfar: ton ċar tal-ġilda',
    '👱🏼' => 'persuna b’xagħar isfar: ton medju-ċar tal-ġilda',
    '👱🏽' => 'persuna b’xagħar isfar: ton medju tal-ġilda',
    '👱🏾' => 'persuna b’xagħar isfar: ton medju-skur tal-ġilda',
    '👱🏿' => 'persuna b’xagħar isfar: ton skur tal-ġilda',
    '👨🏻' => 'raġel: ton ċar tal-ġilda',
    '👨🏼' => 'raġel: ton medju-ċar tal-ġilda',
    '👨🏽' => 'raġel: ton medju tal-ġilda',
    '👨🏾' => 'raġel: ton medju-skur tal-ġilda',
    '👨🏿' => 'raġel: ton skur tal-ġilda',
    '🧔🏻' => 'persuna bil-baffi: ton ċar tal-ġilda',
    '🧔🏼' => 'persuna bil-baffi: ton medju-ċar tal-ġilda',
    '🧔🏽' => 'persuna bil-baffi: ton medju tal-ġilda',
    '🧔🏾' => 'persuna bil-baffi: ton medju-skur tal-ġilda',
    '🧔🏿' => 'persuna bil-baffi: ton skur tal-ġilda',
    '👩🏻' => 'mara: ton ċar tal-ġilda',
    '👩🏼' => 'mara: ton medju-ċar tal-ġilda',
    '👩🏽' => 'mara: ton medju tal-ġilda',
    '👩🏾' => 'mara: ton medju-skur tal-ġilda',
    '👩🏿' => 'mara: ton skur tal-ġilda',
    '🧓🏻' => 'adulti anzjan: ton ċar tal-ġilda',
    '🧓🏼' => 'adulti anzjan: ton medju-ċar tal-ġilda',
    '🧓🏽' => 'adulti anzjan: ton medju tal-ġilda',
    '🧓🏾' => 'adulti anzjan: ton medju-skur tal-ġilda',
    '🧓🏿' => 'adulti anzjan: ton skur tal-ġilda',
    '👴🏻' => 'raġel xiħ: ton ċar tal-ġilda',
    '👴🏼' => 'raġel xiħ: ton medju-ċar tal-ġilda',
    '👴🏽' => 'raġel xiħ: ton medju tal-ġilda',
    '👴🏾' => 'raġel xiħ: ton medju-skur tal-ġilda',
    '👴🏿' => 'raġel xiħ: ton skur tal-ġilda',
    '👵🏻' => 'mara xiħa: ton ċar tal-ġilda',
    '👵🏼' => 'mara xiħa: ton medju-ċar tal-ġilda',
    '👵🏽' => 'mara xiħa: ton medju tal-ġilda',
    '👵🏾' => 'mara xiħa: ton medju-skur tal-ġilda',
    '👵🏿' => 'mara xiħa: ton skur tal-ġilda',
    '🙍🏻' => 'persuna titkerrah: ton ċar tal-ġilda',
    '🙍🏼' => 'persuna titkerrah: ton medju-ċar tal-ġilda',
    '🙍🏽' => 'persuna titkerrah: ton medju tal-ġilda',
    '🙍🏾' => 'persuna titkerrah: ton medju-skur tal-ġilda',
    '🙍🏿' => 'persuna titkerrah: ton skur tal-ġilda',
    '🙎🏻' => 'persuna tisporġi x-xofftejn: ton ċar tal-ġilda',
    '🙎🏼' => 'persuna tisporġi x-xofftejn: ton medju-ċar tal-ġilda',
    '🙎🏽' => 'persuna tisporġi x-xofftejn: ton medju tal-ġilda',
    '🙎🏾' => 'persuna tisporġi x-xofftejn: ton medju-skur tal-ġilda',
    '🙎🏿' => 'persuna tisporġi x-xofftejn: ton skur tal-ġilda',
    '🙅🏻' => 'persuna tagħmel sinjal ta’ LE: ton ċar tal-ġilda',
    '🙅🏼' => 'persuna tagħmel sinjal ta’ LE: ton medju-ċar tal-ġilda',
    '🙅🏽' => 'persuna tagħmel sinjal ta’ LE: ton medju tal-ġilda',
    '🙅🏾' => 'persuna tagħmel sinjal ta’ LE: ton medju-skur tal-ġilda',
    '🙅🏿' => 'persuna tagħmel sinjal ta’ LE: ton skur tal-ġilda',
    '🙆🏻' => 'persuna tagħmel sinjal ta’ OK: ton ċar tal-ġilda',
    '🙆🏼' => 'persuna tagħmel sinjal ta’ OK: ton medju-ċar tal-ġilda',
    '🙆🏽' => 'persuna tagħmel sinjal ta’ OK: ton medju tal-ġilda',
    '🙆🏾' => 'persuna tagħmel sinjal ta’ OK: ton medju-skur tal-ġilda',
    '🙆🏿' => 'persuna tagħmel sinjal ta’ OK: ton skur tal-ġilda',
    '💁🏻' => 'persuna tbaxxi idha: ton ċar tal-ġilda',
    '💁🏼' => 'persuna tbaxxi idha: ton medju-ċar tal-ġilda',
    '💁🏽' => 'persuna tbaxxi idha: ton medju tal-ġilda',
    '💁🏾' => 'persuna tbaxxi idha: ton medju-skur tal-ġilda',
    '💁🏿' => 'persuna tbaxxi idha: ton skur tal-ġilda',
    '🙋🏻' => 'persuna tgħolli idha: ton ċar tal-ġilda',
    '🙋🏼' => 'persuna tgħolli idha: ton medju-ċar tal-ġilda',
    '🙋🏽' => 'persuna tgħolli idha: ton medju tal-ġilda',
    '🙋🏾' => 'persuna tgħolli idha: ton medju-skur tal-ġilda',
    '🙋🏿' => 'persuna tgħolli idha: ton skur tal-ġilda',
    '🙇🏻' => 'persuna tinkina: ton ċar tal-ġilda',
    '🙇🏼' => 'persuna tinkina: ton medju-ċar tal-ġilda',
    '🙇🏽' => 'persuna tinkina: ton medju tal-ġilda',
    '🙇🏾' => 'persuna tinkina: ton medju-skur tal-ġilda',
    '🙇🏿' => 'persuna tinkina: ton skur tal-ġilda',
    '🤦🏻' => 'persuna tagħmel facepalm: ton ċar tal-ġilda',
    '🤦🏼' => 'persuna tagħmel facepalm: ton medju-ċar tal-ġilda',
    '🤦🏽' => 'persuna tagħmel facepalm: ton medju tal-ġilda',
    '🤦🏾' => 'persuna tagħmel facepalm: ton medju-skur tal-ġilda',
    '🤦🏿' => 'persuna tagħmel facepalm: ton skur tal-ġilda',
    '🤷🏻' => 'persuna xxengel spallejha: ton ċar tal-ġilda',
    '🤷🏼' => 'persuna xxengel spallejha: ton medju-ċar tal-ġilda',
    '🤷🏽' => 'persuna xxengel spallejha: ton medju tal-ġilda',
    '🤷🏾' => 'persuna xxengel spallejha: ton medju-skur tal-ġilda',
    '🤷🏿' => 'persuna xxengel spallejha: ton skur tal-ġilda',
    '👮🏻' => 'uffiċjal tal-pulizija: ton ċar tal-ġilda',
    '👮🏼' => 'uffiċjal tal-pulizija: ton medju-ċar tal-ġilda',
    '👮🏽' => 'uffiċjal tal-pulizija: ton medju tal-ġilda',
    '👮🏾' => 'uffiċjal tal-pulizija: ton medju-skur tal-ġilda',
    '👮🏿' => 'uffiċjal tal-pulizija: ton skur tal-ġilda',
    '🕵🏻' => 'ditektiv: ton ċar tal-ġilda',
    '🕵🏼' => 'ditektiv: ton medju-ċar tal-ġilda',
    '🕵🏽' => 'ditektiv: ton medju tal-ġilda',
    '🕵🏾' => 'ditektiv: ton medju-skur tal-ġilda',
    '🕵🏿' => 'ditektiv: ton skur tal-ġilda',
    '💂🏻' => 'gwardjan: ton ċar tal-ġilda',
    '💂🏼' => 'gwardjan: ton medju-ċar tal-ġilda',
    '💂🏽' => 'gwardjan: ton medju tal-ġilda',
    '💂🏾' => 'gwardjan: ton medju-skur tal-ġilda',
    '💂🏿' => 'gwardjan: ton skur tal-ġilda',
    '👷🏻' => 'ħaddiem tal-kostruzzjoni: ton ċar tal-ġilda',
    '👷🏼' => 'ħaddiem tal-kostruzzjoni: ton medju-ċar tal-ġilda',
    '👷🏽' => 'ħaddiem tal-kostruzzjoni: ton medju tal-ġilda',
    '👷🏾' => 'ħaddiem tal-kostruzzjoni: ton medju-skur tal-ġilda',
    '👷🏿' => 'ħaddiem tal-kostruzzjoni: ton skur tal-ġilda',
    '🤴🏻' => 'prinċep: ton ċar tal-ġilda',
    '🤴🏼' => 'prinċep: ton medju-ċar tal-ġilda',
    '🤴🏽' => 'prinċep: ton medju tal-ġilda',
    '🤴🏾' => 'prinċep: ton medju-skur tal-ġilda',
    '🤴🏿' => 'prinċep: ton skur tal-ġilda',
    '👸🏻' => 'prinċipessa: ton ċar tal-ġilda',
    '👸🏼' => 'prinċipessa: ton medju-ċar tal-ġilda',
    '👸🏽' => 'prinċipessa: ton medju tal-ġilda',
    '👸🏾' => 'prinċipessa: ton medju-skur tal-ġilda',
    '👸🏿' => 'prinċipessa: ton skur tal-ġilda',
    '👳🏻' => 'persuna liebsa turban: ton ċar tal-ġilda',
    '👳🏼' => 'persuna liebsa turban: ton medju-ċar tal-ġilda',
    '👳🏽' => 'persuna liebsa turban: ton medju tal-ġilda',
    '👳🏾' => 'persuna liebsa turban: ton medju-skur tal-ġilda',
    '👳🏿' => 'persuna liebsa turban: ton skur tal-ġilda',
    '👲🏻' => 'raġel b’kappell Ċiniż: ton ċar tal-ġilda',
    '👲🏼' => 'raġel b’kappell Ċiniż: ton medju-ċar tal-ġilda',
    '👲🏽' => 'raġel b’kappell Ċiniż: ton medju tal-ġilda',
    '👲🏾' => 'raġel b’kappell Ċiniż: ton medju-skur tal-ġilda',
    '👲🏿' => 'raġel b’kappell Ċiniż: ton skur tal-ġilda',
    '🧕🏻' => 'mara b’velu: ton ċar tal-ġilda',
    '🧕🏼' => 'mara b’velu: ton medju-ċar tal-ġilda',
    '🧕🏽' => 'mara b’velu: ton medju tal-ġilda',
    '🧕🏾' => 'mara b’velu: ton medju-skur tal-ġilda',
    '🧕🏿' => 'mara b’velu: ton skur tal-ġilda',
    '🤵🏻' => 'raġel b’tuxedo: ton ċar tal-ġilda',
    '🤵🏼' => 'raġel b’tuxedo: ton medju-ċar tal-ġilda',
    '🤵🏽' => 'raġel b’tuxedo: ton medju tal-ġilda',
    '🤵🏾' => 'raġel b’tuxedo: ton medju-skur tal-ġilda',
    '🤵🏿' => 'raġel b’tuxedo: ton skur tal-ġilda',
    '👰🏻' => 'għarusa b’velu: ton ċar tal-ġilda',
    '👰🏼' => 'għarusa b’velu: ton medju-ċar tal-ġilda',
    '👰🏽' => 'għarusa b’velu: ton medju tal-ġilda',
    '👰🏾' => 'għarusa b’velu: ton medju-skur tal-ġilda',
    '👰🏿' => 'għarusa b’velu: ton skur tal-ġilda',
    '🤰🏻' => 'mara tqila: ton ċar tal-ġilda',
    '🤰🏼' => 'mara tqila: ton medju-ċar tal-ġilda',
    '🤰🏽' => 'mara tqila: ton medju tal-ġilda',
    '🤰🏾' => 'mara tqila: ton medju-skur tal-ġilda',
    '🤰🏿' => 'mara tqila: ton skur tal-ġilda',
    '🤱🏻' => 'irdigħ: ton ċar tal-ġilda',
    '🤱🏼' => 'irdigħ: ton medju-ċar tal-ġilda',
    '🤱🏽' => 'irdigħ: ton medju tal-ġilda',
    '🤱🏾' => 'irdigħ: ton medju-skur tal-ġilda',
    '🤱🏿' => 'irdigħ: ton skur tal-ġilda',
    '👼🏻' => 'anġlu tarbija: ton ċar tal-ġilda',
    '👼🏼' => 'anġlu tarbija: ton medju-ċar tal-ġilda',
    '👼🏽' => 'anġlu tarbija: ton medju tal-ġilda',
    '👼🏾' => 'anġlu tarbija: ton medju-skur tal-ġilda',
    '👼🏿' => 'anġlu tarbija: ton skur tal-ġilda',
    '🎅🏻' => 'Santa Klaws: ton ċar tal-ġilda',
    '🎅🏼' => 'Santa Klaws: ton medju-ċar tal-ġilda',
    '🎅🏽' => 'Santa Klaws: ton medju tal-ġilda',
    '🎅🏾' => 'Santa Klaws: ton medju-skur tal-ġilda',
    '🎅🏿' => 'Santa Klaws: ton skur tal-ġilda',
    '🤶🏻' => 'Is-Sinjura Klaws: ton ċar tal-ġilda',
    '🤶🏼' => 'Is-Sinjura Klaws: ton medju-ċar tal-ġilda',
    '🤶🏽' => 'Is-Sinjura Klaws: ton medju tal-ġilda',
    '🤶🏾' => 'Is-Sinjura Klaws: ton medju-skur tal-ġilda',
    '🤶🏿' => 'Is-Sinjura Klaws: ton skur tal-ġilda',
    '🧙🏻' => 'magu: ton ċar tal-ġilda',
    '🧙🏼' => 'magu: ton medju-ċar tal-ġilda',
    '🧙🏽' => 'magu: ton medju tal-ġilda',
    '🧙🏾' => 'magu: ton medju-skur tal-ġilda',
    '🧙🏿' => 'magu: ton skur tal-ġilda',
    '🧚🏻' => 'fatatina: ton ċar tal-ġilda',
    '🧚🏼' => 'fatatina: ton medju-ċar tal-ġilda',
    '🧚🏽' => 'fatatina: ton medju tal-ġilda',
    '🧚🏾' => 'fatatina: ton medju-skur tal-ġilda',
    '🧚🏿' => 'fatatina: ton skur tal-ġilda',
    '🧛🏻' => 'vampira: ton ċar tal-ġilda',
    '🧛🏼' => 'vampira: ton medju-ċar tal-ġilda',
    '🧛🏽' => 'vampira: ton medju tal-ġilda',
    '🧛🏾' => 'vampira: ton medju-skur tal-ġilda',
    '🧛🏿' => 'vampira: ton skur tal-ġilda',
    '🧜🏻' => 'merperson: ton ċar tal-ġilda',
    '🧜🏼' => 'merperson: ton medju-ċar tal-ġilda',
    '🧜🏽' => 'merperson: ton medju tal-ġilda',
    '🧜🏾' => 'merperson: ton medju-skur tal-ġilda',
    '🧜🏿' => 'merperson: ton skur tal-ġilda',
    '🧝🏻' => 'għafrit: ton ċar tal-ġilda',
    '🧝🏼' => 'għafrit: ton medju-ċar tal-ġilda',
    '🧝🏽' => 'għafrit: ton medju tal-ġilda',
    '🧝🏾' => 'għafrit: ton medju-skur tal-ġilda',
    '🧝🏿' => 'għafrit: ton skur tal-ġilda',
    '💆🏻' => 'persuna tingħata massaġġ: ton ċar tal-ġilda',
    '💆🏼' => 'persuna tingħata massaġġ: ton medju-ċar tal-ġilda',
    '💆🏽' => 'persuna tingħata massaġġ: ton medju tal-ġilda',
    '💆🏾' => 'persuna tingħata massaġġ: ton medju-skur tal-ġilda',
    '💆🏿' => 'persuna tingħata massaġġ: ton skur tal-ġilda',
    '💇🏻' => 'persuna taqta’ xagħarha: ton ċar tal-ġilda',
    '💇🏼' => 'persuna taqta’ xagħarha: ton medju-ċar tal-ġilda',
    '💇🏽' => 'persuna taqta’ xagħarha: ton medju tal-ġilda',
    '💇🏾' => 'persuna taqta’ xagħarha: ton medju-skur tal-ġilda',
    '💇🏿' => 'persuna taqta’ xagħarha: ton skur tal-ġilda',
    '🚶🏻' => 'persuna timxi: ton ċar tal-ġilda',
    '🚶🏼' => 'persuna timxi: ton medju-ċar tal-ġilda',
    '🚶🏽' => 'persuna timxi: ton medju tal-ġilda',
    '🚶🏾' => 'persuna timxi: ton medju-skur tal-ġilda',
    '🚶🏿' => 'persuna timxi: ton skur tal-ġilda',
    '🏃🏻' => 'persuna tiġri: ton ċar tal-ġilda',
    '🏃🏼' => 'persuna tiġri: ton medju-ċar tal-ġilda',
    '🏃🏽' => 'persuna tiġri: ton medju tal-ġilda',
    '🏃🏾' => 'persuna tiġri: ton medju-skur tal-ġilda',
    '🏃🏿' => 'persuna tiġri: ton skur tal-ġilda',
    '💃🏻' => 'mara tiżfen: ton ċar tal-ġilda',
    '💃🏼' => 'mara tiżfen: ton medju-ċar tal-ġilda',
    '💃🏽' => 'mara tiżfen: ton medju tal-ġilda',
    '💃🏾' => 'mara tiżfen: ton medju-skur tal-ġilda',
    '💃🏿' => 'mara tiżfen: ton skur tal-ġilda',
    '🕺🏻' => 'raġel jiżfen: ton ċar tal-ġilda',
    '🕺🏼' => 'raġel jiżfen: ton medju-ċar tal-ġilda',
    '🕺🏽' => 'raġel jiżfen: ton medju tal-ġilda',
    '🕺🏾' => 'raġel jiżfen: ton medju-skur tal-ġilda',
    '🕺🏿' => 'raġel jiżfen: ton skur tal-ġilda',
    '🕴🏻' => 'raġel jillevita b’libsa ta’ negozju: ton ċar tal-ġilda',
    '🕴🏼' => 'raġel jillevita b’libsa ta’ negozju: ton medju-ċar tal-ġilda',
    '🕴🏽' => 'raġel jillevita b’libsa ta’ negozju: ton medju tal-ġilda',
    '🕴🏾' => 'raġel jillevita b’libsa ta’ negozju: ton medju-skur tal-ġilda',
    '🕴🏿' => 'raġel jillevita b’libsa ta’ negozju: ton skur tal-ġilda',
    '👯🏻' => 'persuni b’widnejn ta’ fenek jiddevertu: ton ċar tal-ġilda',
    '👯🏼' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-ċar tal-ġilda',
    '👯🏽' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju tal-ġilda',
    '👯🏾' => 'persuni b’widnejn ta’ fenek jiddevertu: ton medju-skur tal-ġilda',
    '👯🏿' => 'persuni b’widnejn ta’ fenek jiddevertu: ton skur tal-ġilda',
    '🧖🏻' => 'persuna f’kamra tal-fwar: ton ċar tal-ġilda',
    '🧖🏼' => 'persuna f’kamra tal-fwar: ton medju-ċar tal-ġilda',
    '🧖🏽' => 'persuna f’kamra tal-fwar: ton medju tal-ġilda',
    '🧖🏾' => 'persuna f’kamra tal-fwar: ton medju-skur tal-ġilda',
    '🧖🏿' => 'persuna f’kamra tal-fwar: ton skur tal-ġilda',
    '🧗🏻' => 'persuna tiela’: ton ċar tal-ġilda',
    '🧗🏼' => 'persuna tiela’: ton medju-ċar tal-ġilda',
    '🧗🏽' => 'persuna tiela’: ton medju tal-ġilda',
    '🧗🏾' => 'persuna tiela’: ton medju-skur tal-ġilda',
    '🧗🏿' => 'persuna tiela’: ton skur tal-ġilda',
    '🏇🏻' => 'żiemel itellaq: ton ċar tal-ġilda',
    '🏇🏼' => 'żiemel itellaq: ton medju-ċar tal-ġilda',
    '🏇🏽' => 'żiemel itellaq: ton medju tal-ġilda',
    '🏇🏾' => 'żiemel itellaq: ton medju-skur tal-ġilda',
    '🏇🏿' => 'żiemel itellaq: ton skur tal-ġilda',
    '🏂🏻' => 'snowboarder: ton ċar tal-ġilda',
    '🏂🏼' => 'snowboarder: ton medju-ċar tal-ġilda',
    '🏂🏽' => 'snowboarder: ton medju tal-ġilda',
    '🏂🏾' => 'snowboarder: ton medju-skur tal-ġilda',
    '🏂🏿' => 'snowboarder: ton skur tal-ġilda',
    '🏌🏻' => 'persuna tilgħab il-golf: ton ċar tal-ġilda',
    '🏌🏼' => 'persuna tilgħab il-golf: ton medju-ċar tal-ġilda',
    '🏌🏽' => 'persuna tilgħab il-golf: ton medju tal-ġilda',
    '🏌🏾' => 'persuna tilgħab il-golf: ton medju-skur tal-ġilda',
    '🏌🏿' => 'persuna tilgħab il-golf: ton skur tal-ġilda',
    '🏄🏻' => 'persuna surfing: ton ċar tal-ġilda',
    '🏄🏼' => 'persuna surfing: ton medju-ċar tal-ġilda',
    '🏄🏽' => 'persuna surfing: ton medju tal-ġilda',
    '🏄🏾' => 'persuna surfing: ton medju-skur tal-ġilda',
    '🏄🏿' => 'persuna surfing: ton skur tal-ġilda',
    '🚣🏻' => 'persuna taqdef dgħajsa: ton ċar tal-ġilda',
    '🚣🏼' => 'persuna taqdef dgħajsa: ton medju-ċar tal-ġilda',
    '🚣🏽' => 'persuna taqdef dgħajsa: ton medju tal-ġilda',
    '🚣🏾' => 'persuna taqdef dgħajsa: ton medju-skur tal-ġilda',
    '🚣🏿' => 'persuna taqdef dgħajsa: ton skur tal-ġilda',
    '🏊🏻' => 'persuna tgħum: ton ċar tal-ġilda',
    '🏊🏼' => 'persuna tgħum: ton medju-ċar tal-ġilda',
    '🏊🏽' => 'persuna tgħum: ton medju tal-ġilda',
    '🏊🏾' => 'persuna tgħum: ton medju-skur tal-ġilda',
    '🏊🏿' => 'persuna tgħum: ton skur tal-ġilda',
    '⛹🏻' => 'persuna tqabbeż ballun: ton ċar tal-ġilda',
    '⛹🏼' => 'persuna tqabbeż ballun: ton medju-ċar tal-ġilda',
    '⛹🏽' => 'persuna tqabbeż ballun: ton medju tal-ġilda',
    '⛹🏾' => 'persuna tqabbeż ballun: ton medju-skur tal-ġilda',
    '⛹🏿' => 'persuna tqabbeż ballun: ton skur tal-ġilda',
    '🏋🏻' => 'persuna terfa’ l-piż: ton ċar tal-ġilda',
    '🏋🏼' => 'persuna terfa’ l-piż: ton medju-ċar tal-ġilda',
    '🏋🏽' => 'persuna terfa’ l-piż: ton medju tal-ġilda',
    '🏋🏾' => 'persuna terfa’ l-piż: ton medju-skur tal-ġilda',
    '🏋🏿' => 'persuna terfa’ l-piż: ton skur tal-ġilda',
    '🚴🏻' => 'persuna ssuq rota: ton ċar tal-ġilda',
    '🚴🏼' => 'persuna ssuq rota: ton medju-ċar tal-ġilda',
    '🚴🏽' => 'persuna ssuq rota: ton medju tal-ġilda',
    '🚴🏾' => 'persuna ssuq rota: ton medju-skur tal-ġilda',
    '🚴🏿' => 'persuna ssuq rota: ton skur tal-ġilda',
    '🚵🏻' => 'persuna ssuq mountain bike: ton ċar tal-ġilda',
    '🚵🏼' => 'persuna ssuq mountain bike: ton medju-ċar tal-ġilda',
    '🚵🏽' => 'persuna ssuq mountain bike: ton medju tal-ġilda',
    '🚵🏾' => 'persuna ssuq mountain bike: ton medju-skur tal-ġilda',
    '🚵🏿' => 'persuna ssuq mountain bike: ton skur tal-ġilda',
    '🤸🏻' => 'persuna tagħmel gabrijoli: ton ċar tal-ġilda',
    '🤸🏼' => 'persuna tagħmel gabrijoli: ton medju-ċar tal-ġilda',
    '🤸🏽' => 'persuna tagħmel gabrijoli: ton medju tal-ġilda',
    '🤸🏾' => 'persuna tagħmel gabrijoli: ton medju-skur tal-ġilda',
    '🤸🏿' => 'persuna tagħmel gabrijoli: ton skur tal-ġilda',
    '🤼🏻' => 'persuna jagħmlu r-wrestling: ton ċar tal-ġilda',
    '🤼🏼' => 'persuna jagħmlu r-wrestling: ton medju-ċar tal-ġilda',
    '🤼🏽' => 'persuna jagħmlu r-wrestling: ton medju tal-ġilda',
    '🤼🏾' => 'persuna jagħmlu r-wrestling: ton medju-skur tal-ġilda',
    '🤼🏿' => 'persuna jagħmlu r-wrestling: ton skur tal-ġilda',
    '🤽🏻' => 'persuna tilgħab il-waterpolo: ton ċar tal-ġilda',
    '🤽🏼' => 'persuna tilgħab il-waterpolo: ton medju-ċar tal-ġilda',
    '🤽🏽' => 'persuna tilgħab il-waterpolo: ton medju tal-ġilda',
    '🤽🏾' => 'persuna tilgħab il-waterpolo: ton medju-skur tal-ġilda',
    '🤽🏿' => 'persuna tilgħab il-waterpolo: ton skur tal-ġilda',
    '🤾🏻' => 'persuna tilgħab il-handball: ton ċar tal-ġilda',
    '🤾🏼' => 'persuna tilgħab il-handball: ton medju-ċar tal-ġilda',
    '🤾🏽' => 'persuna tilgħab il-handball: ton medju tal-ġilda',
    '🤾🏾' => 'persuna tilgħab il-handball: ton medju-skur tal-ġilda',
    '🤾🏿' => 'persuna tilgħab il-handball: ton skur tal-ġilda',
    '🤹🏻' => 'persuna tagħmel il-juggling: ton ċar tal-ġilda',
    '🤹🏼' => 'persuna tagħmel il-juggling: ton medju-ċar tal-ġilda',
    '🤹🏽' => 'persuna tagħmel il-juggling: ton medju tal-ġilda',
    '🤹🏾' => 'persuna tagħmel il-juggling: ton medju-skur tal-ġilda',
    '🤹🏿' => 'persuna tagħmel il-juggling: ton skur tal-ġilda',
    '🧘🏻' => 'persuna fil-pożizzjoni ta’ lotus: ton ċar tal-ġilda',
    '🧘🏼' => 'persuna fil-pożizzjoni ta’ lotus: ton medju-ċar tal-ġilda',
    '🧘🏽' => 'persuna fil-pożizzjoni ta’ lotus: ton medju tal-ġilda',
    '🧘🏾' => 'persuna fil-pożizzjoni ta’ lotus: ton medju-skur tal-ġilda',
    '🧘🏿' => 'persuna fil-pożizzjoni ta’ lotus: ton skur tal-ġilda',
    '🛀🏻' => 'persuna tieħu banju: ton ċar tal-ġilda',
    '🛀🏼' => 'persuna tieħu banju: ton medju-ċar tal-ġilda',
    '🛀🏽' => 'persuna tieħu banju: ton medju tal-ġilda',
    '🛀🏾' => 'persuna tieħu banju: ton medju-skur tal-ġilda',
    '🛀🏿' => 'persuna tieħu banju: ton skur tal-ġilda',
    '🛌🏻' => 'persuna fis-sodda: ton ċar tal-ġilda',
    '🛌🏼' => 'persuna fis-sodda: ton medju-ċar tal-ġilda',
    '🛌🏽' => 'persuna fis-sodda: ton medju tal-ġilda',
    '🛌🏾' => 'persuna fis-sodda: ton medju-skur tal-ġilda',
    '🛌🏿' => 'persuna fis-sodda: ton skur tal-ġilda',
    '👭🏻' => 'żewġ nisa jżommu jdejhom: ton ċar tal-ġilda',
    '👭🏼' => 'żewġ nisa jżommu jdejhom: ton medju-ċar tal-ġilda',
    '👭🏽' => 'żewġ nisa jżommu jdejhom: ton medju tal-ġilda',
    '👭🏾' => 'żewġ nisa jżommu jdejhom: ton medju-skur tal-ġilda',
    '👭🏿' => 'żewġ nisa jżommu jdejhom: ton skur tal-ġilda',
    '👫🏻' => 'raġel u mara jżommu jdejhom: ton ċar tal-ġilda',
    '👫🏼' => 'raġel u mara jżommu jdejhom: ton medju-ċar tal-ġilda',
    '👫🏽' => 'raġel u mara jżommu jdejhom: ton medju tal-ġilda',
    '👫🏾' => 'raġel u mara jżommu jdejhom: ton medju-skur tal-ġilda',
    '👫🏿' => 'raġel u mara jżommu jdejhom: ton skur tal-ġilda',
    '👬🏻' => 'żewġt irġiel iżommu jdejhom: ton ċar tal-ġilda',
    '👬🏼' => 'żewġt irġiel iżommu jdejhom: ton medju-ċar tal-ġilda',
    '👬🏽' => 'żewġt irġiel iżommu jdejhom: ton medju tal-ġilda',
    '👬🏾' => 'żewġt irġiel iżommu jdejhom: ton medju-skur tal-ġilda',
    '👬🏿' => 'żewġt irġiel iżommu jdejhom: ton skur tal-ġilda',
    '💏🏻' => 'bewsa: ton ċar tal-ġilda',
    '💏🏼' => 'bewsa: ton medju-ċar tal-ġilda',
    '💏🏽' => 'bewsa: ton medju tal-ġilda',
    '💏🏾' => 'bewsa: ton medju-skur tal-ġilda',
    '💏🏿' => 'bewsa: ton skur tal-ġilda',
    '💑🏻' => 'koppja b’qalb: ton ċar tal-ġilda',
    '💑🏼' => 'koppja b’qalb: ton medju-ċar tal-ġilda',
    '💑🏽' => 'koppja b’qalb: ton medju tal-ġilda',
    '💑🏾' => 'koppja b’qalb: ton medju-skur tal-ġilda',
    '💑🏿' => 'koppja b’qalb: ton skur tal-ġilda',
    '🏻' => 'ton ċar tal-ġilda',
    '🏼' => 'ton medju-ċar tal-ġilda',
    '🏽' => 'ton medju tal-ġilda',
    '🏾' => 'ton medju-skur tal-ġilda',
    '🏿' => 'ton skur tal-ġilda',
    '😀' => 'wiċċ jidħak ħafna',
    '😃' => 'wiċċ jidħaq bil-ħalq miftuħ',
    '😄' => 'wiċċ jidħaq b’ħalq miftuħ u għajnejn jitbissmu',
    '😁' => 'wiċċ jidħak ħafna b’għajnejn jitbissmu',
    '😆' => 'wiċċ jidħaq b’ħalq miftuħ u għajnejn magħluqa',
    '😅' => 'wiċċ jidħaq b’ħalq miftuħ u għaraq kiesaħ',
    '🤣' => 'jirrombla mal-art jidħaq',
    '😂' => 'wiċċ bi dmugħ ta’ ferħ',
    '🙂' => 'wiċċ jitbissem ftit',
    '🙃' => 'wiċċ ta’ taħt fuq',
    '😉' => 'wiċċ jehmeż',
    '😊' => 'wiċċ jitbissem b’għajnejn jitbissmu',
    '😇' => 'wiċċ jitbissem b’raġġiera',
    '😍' => 'wiċċ jitbissem b’għajnejn bil-qlub',
    '🤩' => 'star-struck',
    '😘' => 'wiċċ jitfa’ bewsa',
    '😗' => 'wiċċ ibewwes',
    '☺' => 'wiċċ jitbissem',
    '😚' => 'wiċċ ibewwes b’għajnejn magħluqin',
    '😙' => 'wiċċ ibewwes b’għajnejn jitbissmu',
    '😋' => 'wiċċ iduq ikel delizzjuż',
    '😛' => 'wiċċ b’ilsien barra',
    '😜' => 'wiċċ b’ilsien barra u għajn tehmeż',
    '🤪' => 'wiċċ miġnun',
    '😝' => 'wiċċ b’ilsien barra u għajnejn magħluqin',
    '🤑' => 'wiċċ b’ħalq tal-flus',
    '🤗' => 'wiċċ jgħannaq',
    '🤭' => 'wiċċ bl-idejn fuq il-ħalq',
    '🤫' => 'wiċċ qed isikket',
    '🤔' => 'wiċċ ħosbien',
    '🤐' => 'wiċċ b’ħalq b’żipp',
    '🤨' => 'wiċċ b’ħuġbejn imtella’',
    '😐' => 'wiċċ newtrali',
    '😑' => 'wiċċ mingħajr espressjoni',
    '😶' => 'wiċċ mingħajr ħalq',
    '😏' => 'wiċċ jitkerraħ',
    '😒' => 'wiċċ mhux ferrieħi',
    '🙄' => 'wiċċ b’għajnejn iduru',
    '😬' => 'wiċċ jistmerraħ',
    '🤥' => 'wiċċ jigdeb',
    '😌' => 'wiċċ sollevat',
    '😔' => 'wiċċ imħasseb',
    '😪' => 'wiċċ bi ngħas',
    '🤤' => 'wiċċ ibeżlaq',
    '😴' => 'wiċċ rieqed',
    '😷' => 'wiċċ bil-maskra medika',
    '🤒' => 'wiċċ b’termometru',
    '🤕' => 'wiċċ b’faxxa mar-ras',
    '🤢' => 'wiċċ jirremetti',
    '🤮' => 'wiċċ qed jirremetti',
    '🤧' => 'wiċċ jagħtas',
    '😵' => 'wiċċ sturdut',
    '🤯' => 'ras tisplodi',
    '🤠' => 'wiċċ b’kappell tal-cowboys',
    '😎' => 'wiċċ jitbissem b’nuċċali tax-xemx',
    '🤓' => 'wiċċ nerd',
    '🧐' => 'wiċċ bil-monokolu',
    '😕' => 'wiċċ konfuż',
    '😟' => 'wiċċ inkwetat',
    '🙁' => 'wiċċ imkemmex ftit',
    '☹' => 'wiċċ imkemmex',
    '😮' => 'wiċċ b’ħalq miftuħ',
    '😯' => 'wiċċ imsikket',
    '😲' => 'wiċċ skantat',
    '😳' => 'wiċċ ruxxan',
    '😦' => 'wiċċ imkemmex b’ħalq miftuħ',
    '😧' => 'wiċċ imdejjaq ħafna',
    '😨' => 'wiċċ imbeżża’',
    '😰' => 'wiċċ b’ħalq miftuħ u għaraq kiesaħ',
    '😥' => 'wiċċ diżappuntat iżda sollevat',
    '😢' => 'wiċċ jibki',
    '😭' => 'wiċċ jibki jgħajjat',
    '😱' => 'wiċċ iwerżaq bil-biża’',
    '😖' => 'wiċċ imħawwad',
    '😣' => 'wiċċ perseveranti',
    '😞' => 'wiċċ diżappuntat',
    '😓' => 'wiċċ b’għaraq kiesaħ',
    '😩' => 'wiċċ mimli għeja',
    '😫' => 'wiċċ għajjien',
    '😤' => 'wiċċ bid-duħħan ħiereġ mill-imnieħer',
    '😡' => 'wiċċ jisporġi x-xofftejn',
    '😠' => 'wiċċ irrabjat',
    '🤬' => 'wiċċ bis-simboli fuq il-ħalq',
    '😈' => 'wiċċ jitbissem bil-qrun',
    '👿' => 'wiċċ irrabjat bil-qrun',
    '💀' => 'kranju',
    '☠' => 'kranju u crossbones',
    '💩' => 'munzell ħmieġ',
    '🤡' => 'wiċċ ta’ buffu',
    '👹' => 'orku',
    '👺' => 'goblin',
    '👻' => 'fatat',
    '👽' => 'aljen',
    '👾' => 'mostru aljen',
    '🤖' => 'wiċċ ta’ robot',
    '😺' => 'wiċċ ta’ qattus jitbissem b’ħalq miftuħ',
    '😸' => 'wiċċ ta’ qattus jidħak ħafna b’għajnejn jitbissmu',
    '😹' => 'wiċċ ta’ qattus bi dmugħ ta’ ferħ',
    '😻' => 'wiċċ ta’ qattus jitbissem b’għajnejn bil-qlub',
    '😼' => 'wiċċ ta’ qattus bi tbissima mqarrsa',
    '😽' => 'wiċċ ta’ qattus ibewwes b’għajnejn magħluqin',
    '🙀' => 'wiċċ ta’ qattus għajjien',
    '😿' => 'wiċċ ta’ qattus jibki',
    '😾' => 'wiċċ ta’ qattus jisporġi x-xofftejn',
    '🙈' => 'xadina li ma tara ebda ħażen',
    '🙉' => 'xadina li ma tisma’ ebda ħażen',
    '🙊' => 'xadina li ma titkellem ebda ħażen',
    '💌' => 'ittra ta’ mħabba',
    '💘' => 'qalb bi vleġġa',
    '💝' => 'qalb b’ċoff',
    '💖' => 'qalb tfexfex',
    '💗' => 'qalb tikber',
    '💓' => 'qalb tħabbat',
    '💞' => 'qlub iduru',
    '💕' => 'żewġt iqlub',
    '💟' => 'dekorazzjoni ta’ qalb',
    '❣' => 'esklamazzjoni ta’ qalb miġugħa',
    '💔' => 'qalb maqsuma',
    '❤' => 'qalb ħamra',
    '🧡' => 'qalb oranġjo',
    '💛' => 'qalb safra',
    '💚' => 'qalb ħadra',
    '💙' => 'qalb blu',
    '💜' => 'qalb vjola',
    '🖤' => 'qalb sewda',
    '💋' => 'marka ta’ bewsa',
    '💯' => 'mitt punt',
    '💢' => 'simbolu ta’ rabja',
    '💥' => 'ħabta',
    '💫' => 'stordut',
    '💦' => 'qtar tal-għaraq',
    '💨' => 'jaħrab ’l hemm',
    '🕳' => 'toqba',
    '💬' => 'bużżieqa tad-diskors',
    '🗨' => 'bużżieqa tad-diskors fuq ix-xellug',
    '🗯' => 'bużżieqa ta’ rabja fuq il-lemin',
    '💭' => 'bużżieqa tal-ħsibijiet',
    '💤' => 'zzz',
    '👋' => 'id ixxejjer',
    '🤚' => 'id minn wara mgħollija',
    '🖐' => 'id mgħollija bl-iswaba’ mfettħa',
    '✋' => 'id mgħollija',
    '🖖' => 'salut ta’ vulcan',
    '👌' => 'id OK',
    '✌' => 'id tar-rebħa',
    '🤞' => 'swaba nkroċjati',
    '🤟' => 'ġest ta’ mħabba',
    '🤘' => 'sinjal tal-qrun',
    '🤙' => 'id ċempilli',
    '👈' => 'indiċi b’lura iipponta lejn ix-xellug',
    '👉' => 'indiċi b’lura li jipponta lejn il-lemin',
    '👆' => 'indiċi b’lura li jipponta ’l fuq',
    '🖕' => 'suba’ tan-nofs',
    '👇' => 'indiċi b’lura li jipponta ’l isfel',
    '☝' => 'indiċi li jipponta ’l fuq',
    '👍' => 'behem ’il fuq',
    '👎' => 'behem ’l isfel',
    '✊' => 'ponn mgħolli',
    '👊' => 'ponn dieħel',
    '🤛' => 'ponn iħares lejn ix-xellug',
    '🤜' => 'ponn iħares lemin',
    '👏' => 'idejn iċapċpu',
    '🙌' => 'idejn mgħollija',
    '👐' => 'idejn miftuħa',
    '🤲' => 'pali tal-idejn flimkien',
    '🤝' => 'ħu bl-idejn',
    '🙏' => 'idejn magħluqa',
    '✍' => 'id li tikteb biha',
    '💅' => 'nail polish',
    '🤳' => 'stessu',
    '💪' => 'biceps bil-muskoli',
    '👂' => 'widna',
    '👃' => 'imnieħer',
    '🧠' => 'moħħ',
    '👀' => 'għajnejn',
    '👁' => 'għajn',
    '👅' => 'ilsien',
    '👄' => 'ħalq',
    '👶' => 'tarbija',
    '🧒' => 'tfal',
    '👦' => 'tifel',
    '👧' => 'tifla',
    '🧑' => 'adult',
    '👱' => 'persuna b’xagħar isfar',
    '👨' => 'raġel',
    '🧔' => 'persuna bil-baffi',
    '👩' => 'mara',
    '🧓' => 'adulti anzjan',
    '👴' => 'raġel xiħ',
    '👵' => 'mara xiħa',
    '🙍' => 'persuna titkerrah',
    '🙎' => 'persuna tisporġi x-xofftejn',
    '🙅' => 'persuna tagħmel sinjal ta’ LE',
    '🙆' => 'persuna tagħmel sinjal ta’ OK',
    '💁' => 'persuna tbaxxi idha',
    '🙋' => 'persuna tgħolli idha',
    '🙇' => 'persuna tinkina',
    '🤦' => 'persuna tagħmel facepalm',
    '🤷' => 'persuna xxengel spallejha',
    '👮' => 'uffiċjal tal-pulizija',
    '🕵' => 'ditektiv',
    '💂' => 'gwardjan',
    '👷' => 'ħaddiem tal-kostruzzjoni',
    '🤴' => 'prinċep',
    '👸' => 'prinċipessa',
    '👳' => 'persuna liebsa turban',
    '👲' => 'raġel b’kappell Ċiniż',
    '🧕' => 'mara b’velu',
    '🤵' => 'raġel b’tuxedo',
    '👰' => 'għarusa b’velu',
    '🤰' => 'mara tqila',
    '🤱' => 'irdigħ',
    '👼' => 'anġlu tarbija',
    '🎅' => 'Santa Klaws',
    '🤶' => 'Is-Sinjura Klaws',
    '🧙' => 'magu',
    '🧚' => 'fatatina',
    '🧛' => 'vampira',
    '🧜' => 'merperson',
    '🧝' => 'għafrit',
    '🧞' => 'ġenju',
    '🧟' => 'żombi',
    '💆' => 'persuna tingħata massaġġ',
    '💇' => 'persuna taqta’ xagħarha',
    '🚶' => 'persuna timxi',
    '🏃' => 'persuna tiġri',
    '💃' => 'mara tiżfen',
    '🕺' => 'raġel jiżfen',
    '🕴' => 'raġel jillevita b’libsa ta’ negozju',
    '👯' => 'persuni b’widnejn ta’ fenek jiddevertu',
    '🧖' => 'persuna f’kamra tal-fwar',
    '🧗' => 'persuna tiela’',
    '🤺' => 'persuna fencing',
    '🏇' => 'żiemel itellaq',
    '⛷' => 'skier',
    '🏂' => 'snowboarder',
    '🏌' => 'persuna tilgħab il-golf',
    '🏄' => 'persuna surfing',
    '🚣' => 'persuna taqdef dgħajsa',
    '🏊' => 'persuna tgħum',
    '⛹' => 'persuna tqabbeż ballun',
    '🏋' => 'persuna terfa’ l-piż',
    '🚴' => 'persuna ssuq rota',
    '🚵' => 'persuna ssuq mountain bike',
    '🤸' => 'persuna tagħmel gabrijoli',
    '🤼' => 'persuna jagħmlu r-wrestling',
    '🤽' => 'persuna tilgħab il-waterpolo',
    '🤾' => 'persuna tilgħab il-handball',
    '🤹' => 'persuna tagħmel il-juggling',
    '🧘' => 'persuna fil-pożizzjoni ta’ lotus',
    '🛀' => 'persuna tieħu banju',
    '🛌' => 'persuna fis-sodda',
    '👭' => 'żewġ nisa jżommu jdejhom',
    '👫' => 'raġel u mara jżommu jdejhom',
    '👬' => 'żewġt irġiel iżommu jdejhom',
    '💏' => 'bewsa',
    '💑' => 'koppja b’qalb',
    '🗣' => 'titkellem ras',
    '👤' => 'bust f’silwett',
    '👥' => 'busti f’silwett',
    '👪' => 'familja',
    '👣' => 'marki tas-saqajn',
    '🐵' => 'wiċċ ta’ xadina',
    '🐒' => 'xadina',
    '🦍' => 'gorilla',
    '🐶' => 'wiċċ ta’ kelb',
    '🐕' => 'kelb',
    '🐩' => 'poodle',
    '🐺' => 'wiċċ ta’ lupu',
    '🦊' => 'wiċċ ta’ volpi',
    '🐱' => 'wiċċ ta’ qattus',
    '🐈' => 'qattus',
    '🦁' => 'wiċċ ta’ ljun',
    '🐯' => 'wiċċ ta’ tigra',
    '🐅' => 'tigra',
    '🐆' => 'leopard',
    '🐴' => 'wiċċ ta’ żiemel',
    '🐎' => 'żiemel',
    '🦄' => 'wiċċ ta’ unikornu',
    '🦓' => 'żebra',
    '🦌' => 'ċerva',
    '🐮' => 'wiċċ ta’ baqra',
    '🐂' => 'bhima',
    '🐃' => 'buflu tal-ilma',
    '🐄' => 'baqra',
    '🐷' => 'wiċċ ta’ ħanżir',
    '🐖' => 'ħanżir',
    '🐗' => 'ċingjal',
    '🐽' => 'imnieħer ta’ ħanżir',
    '🐏' => 'muntun',
    '🐑' => 'nagħġa',
    '🐐' => 'mogħża',
    '🐪' => 'ġemel',
    '🐫' => 'ġemel b’żewġ ħotob',
    '🦒' => 'ġiraff',
    '🐘' => 'iljunfant',
    '🦏' => 'rinoċeronti',
    '🐭' => 'wiċċ ta’ ġurdien',
    '🐁' => 'ġurdien',
    '🐀' => 'far',
    '🐹' => 'wiċċ ta’ ħamster',
    '🐰' => 'wiċċ ta’ fenek',
    '🐇' => 'fenek',
    '🐿' => 'chipmunk',
    '🦔' => 'qanfud',
    '🦇' => 'farfett il-lejl',
    '🐻' => 'wiċċ ta’ ors',
    '🐨' => 'koala',
    '🐼' => 'wiċċ ta’ panda',
    '🐾' => 'marki tas-saqajn ta’ annimal',
    '🦃' => 'dundjan',
    '🐔' => 'tiġieġa',
    '🐓' => 'serduk',
    '🐣' => 'fellus qed ifaqqas',
    '🐤' => 'fellus żgħir',
    '🐥' => 'fellus żgħir iħares ’il quddiem',
    '🐦' => 'għasfur',
    '🐧' => 'pingwin',
    '🕊' => 'ħamiema',
    '🦅' => 'ajkla',
    '🦆' => 'papra',
    '🦉' => 'kokka',
    '🐸' => 'wiċċ ta’ żrinġ',
    '🐊' => 'kukkudrill',
    '🐢' => 'fekruna',
    '🦎' => 'wiża’',
    '🐍' => 'serp',
    '🐲' => 'wiċċ ta’ dragun',
    '🐉' => 'dragun',
    '🦕' => 'sawropodu',
    '🦖' => 'T-Rex',
    '🐳' => 'baliena tfawwar l-ilma',
    '🐋' => 'baliena',
    '🐬' => 'denfil',
    '🐟' => 'ħut',
    '🐠' => 'ħut tropikali',
    '🐡' => 'blowfish',
    '🦈' => 'kelb il-baħar',
    '🐙' => 'qarnita',
    '🐚' => 'qoxra spirali',
    '🦀' => 'granċ',
    '🦐' => 'gamblu',
    '🦑' => 'klamari',
    '🐌' => 'bebbuxu',
    '🦋' => 'farfett',
    '🐛' => 'insett',
    '🐜' => 'nemla',
    '🐝' => 'żunżana',
    '🐞' => 'ħanfusa',
    '🦗' => 'cricket',
    '🕷' => 'brimba',
    '🕸' => 'għanqbuta',
    '🦂' => 'skorpjun',
    '💐' => 'bukkett',
    '🌸' => 'fjur taċ-ċirasa',
    '💮' => 'fjura bajda',
    '🏵' => 'rożetta',
    '🌹' => 'warda',
    '🥀' => 'fjura mitbiela',
    '🌺' => 'hibiscus',
    '🌻' => 'ġirasol',
    '🌼' => 'fjur',
    '🌷' => 'tulipan',
    '🌱' => 'żerriegħa',
    '🌲' => 'siġra tħaddar',
    '🌳' => 'siġra deċiduża',
    '🌴' => 'siġra tal-palm',
    '🌵' => 'kaktus',
    '🌾' => 'għarma ross',
    '🌿' => 'ħwawar',
    '☘' => 'xamrok',
    '🍀' => 'silla ta’ erba’ werqiet',
    '🍁' => 'werqa tal-aġġru',
    '🍂' => 'werqa mwaqqa’',
    '🍃' => 'werqa tixxejjer fir-riħ',
    '🍄' => 'faqqiegħa',
    '🍇' => 'għeneb',
    '🍈' => 'bettieħa',
    '🍉' => 'dulliegħa',
    '🍊' => 'mandolina',
    '🍋' => 'lumija',
    '🍌' => 'banana',
    '🍍' => 'ananas',
    '🍎' => 'tuffieħa ħamra',
    '🍏' => 'tuffieħa ħadra',
    '🍐' => 'lanġasa',
    '🍑' => 'ħawħa',
    '🍒' => 'ċirasa',
    '🍓' => 'frawla',
    '🥝' => 'frotta tal-kiwi',
    '🍅' => 'tadama',
    '🥥' => 'ġewż tal-indi',
    '🥑' => 'avokado',
    '🍆' => 'brunġiela',
    '🥔' => 'patata',
    '🥕' => 'zunnerija',
    '🌽' => 'widna tal-qamħ',
    '🌶' => 'bżar jaħraq',
    '🥒' => 'ħjara',
    '🥦' => 'brokkoli',
    '🥜' => 'karawett',
    '🌰' => 'qastan',
    '🍞' => 'ħobż',
    '🥐' => 'croissant',
    '🥖' => 'ħobż baguette',
    '🥨' => 'pretzel',
    '🥞' => 'pancakes',
    '🧀' => 'biċċa ġobon',
    '🍖' => 'laħam fuq l-għadma',
    '🍗' => 'sieq ta’ tjur',
    '🥩' => 'biċċa laħam',
    '🥓' => 'bejken',
    '🍔' => 'hamburger',
    '🍟' => 'ċips',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🥙' => 'ħobż ċatt mimli',
    '🥚' => 'bajda',
    '🍳' => 'tisjir',
    '🥘' => 'taġen baxx tal-Ikel',
    '🍲' => 'borma tal-ikel',
    '🥣' => 'skutella b’mgħarfa',
    '🥗' => 'insalata ħadra',
    '🍿' => 'popcorn',
    '🥫' => 'ikel fil-laned',
    '🍱' => 'bento box',
    '🍘' => 'rice cracker',
    '🍙' => 'pulpetta tar-ross',
    '🍚' => 'ross imsajjar',
    '🍛' => 'ross tal-karì',
    '🍜' => 'bieqja tal-fwar',
    '🍝' => 'spagetti',
    '🍠' => 'patata ħelwa mixwija',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'gambli moqli',
    '🍥' => 'pulpetta tal-ħut innokklata',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'fortune cookie',
    '🥡' => 'kaxxa tat-takeout',
    '🍦' => 'ġelat artab',
    '🍧' => 'silġ imqaxxar',
    '🍨' => 'ġelat',
    '🍩' => 'doughnut',
    '🍪' => 'gallettina',
    '🎂' => 'kejk ta’ għeluq is-snin',
    '🍰' => 'shortcake',
    '🥧' => 'torta',
    '🍫' => 'biċċa ċikkulata',
    '🍬' => 'ħelu',
    '🍭' => 'lolipop',
    '🍮' => 'kastard',
    '🍯' => 'vażett għasel',
    '🍼' => 'flixkun tat-trabi',
    '🥛' => 'tazza ħalib',
    '☕' => 'xarba sħuna',
    '🍵' => 'kikkra tat-te mingħajr manku',
    '🍶' => 'sake',
    '🍾' => 'flixkun b’tapp tas-sufra jinfetaħ',
    '🍷' => 'tazza nbid',
    '🍸' => 'tazza tal-cocktails',
    '🍹' => 'xarba tropikali',
    '🍺' => 'magg birra',
    '🍻' => 'maggijiet tal-birra jċekċku',
    '🥂' => 'tazzi jċekċku',
    '🥃' => 'tazza kbira tal-ħġieġ',
    '🥤' => 'tazza bi stro',
    '🥢' => 'chopsticks',
    '🍽' => 'furketta u sikkina ma’ platt',
    '🍴' => 'furketta u sikkina',
    '🥄' => 'mgħarfa',
    '🔪' => 'sikkina tal-kċina',
    '🏺' => 'anfora',
    '🌍' => 'globu juri l-Ewropa-Afrika',
    '🌎' => 'globu juri l-Ameriki',
    '🌏' => 'globu juri l-Asja-Awstralja',
    '🌐' => 'globu bil-meridjani',
    '🗺' => 'mappa tad-dinjija',
    '🗾' => 'mappa tal-Ġappun',
    '🏔' => 'muntanja miksija bis-silġ',
    '⛰' => 'muntanja',
    '🌋' => 'vulkan',
    '🗻' => 'muntanja fuji',
    '🏕' => 'kampeġġ',
    '🏖' => 'bajja b’umbrella',
    '🏜' => 'deżert',
    '🏝' => 'gżira deżert',
    '🏞' => 'park nazzjonali',
    '🏟' => 'stadium',
    '🏛' => 'bini klassiku',
    '🏗' => 'kostruzzjoni tal-bini',
    '🏘' => 'djar',
    '🏚' => 'dar mitluqa',
    '🏠' => 'binja',
    '🏡' => 'dar bil-ġnien',
    '🏢' => 'bini tal-uffiċċju',
    '🏣' => 'uffiċċju tal-posta Ġappuniż',
    '🏤' => 'uffiċċju tal-posta',
    '🏥' => 'sptar',
    '🏦' => 'bank',
    '🏨' => 'lukanda',
    '🏩' => 'lukanda tal-imħabba',
    '🏪' => 'ħanut tal-merċa',
    '🏫' => 'skola',
    '🏬' => 'stabbiliment',
    '🏭' => 'fabbrika',
    '🏯' => 'kastell Ġappuniż',
    '🏰' => 'kastell',
    '💒' => 'tieġ',
    '🗼' => 'torri ta’ Tokjo',
    '🗽' => 'Statwa tal-Libertà',
    '⛪' => 'knisja',
    '🕌' => 'moskea',
    '🕍' => 'sinagoga',
    '⛩' => 'maqdes shinto',
    '🕋' => 'kaaba',
    '⛲' => 'funtana',
    '⛺' => 'tinda',
    '🌁' => 'imċajpar',
    '🌃' => 'lejl bl-istilel',
    '🏙' => 'silwett tal-belt',
    '🌄' => 'tlugħ ix-xemx fuq il-muntanji',
    '🌅' => 'tlugħ ix-xemx',
    '🌆' => 'silwett tal-belt fi nżul ix-xemx',
    '🌇' => 'nżul ix-xemx',
    '🌉' => 'pont billejl',
    '♨' => 'nixxigħat sħan',
    '🎠' => 'żiemel tal-karusell',
    '🎡' => 'ferris wheel',
    '🎢' => 'roller coaster',
    '💈' => 'arblu tal-barbier',
    '🎪' => 'tinda taċ-ċirklu',
    '🚂' => 'lokomottiva',
    '🚃' => 'karozza tal-ferrovija',
    '🚄' => 'ferrovija b’velocità għolja',
    '🚅' => 'ferrovija b’veloċità għolja bil-bullet nose',
    '🚆' => 'ferrovija',
    '🚇' => 'metro',
    '🚈' => 'ferrovija ħafifa',
    '🚉' => 'stazzjon',
    '🚊' => 'tramm',
    '🚝' => 'monorail',
    '🚞' => 'ferrovija tal-muntanji',
    '🚋' => 'karozza tat-tramm',
    '🚌' => 'xarabank',
    '🚍' => 'xarabank ġejja ’l hawn',
    '🚎' => 'trolleybus',
    '🚐' => 'minibus',
    '🚑' => 'ambulanza',
    '🚒' => 'vettura tat-tifi tan-nar',
    '🚓' => 'karozza tal-pulizija',
    '🚔' => 'karozza tal-pulizija ġejja ’l hawn',
    '🚕' => 'taxi',
    '🚖' => 'taxi ġejja ’l hawn',
    '🚗' => 'karozza',
    '🚘' => 'karozza ġejja ’l hawn',
    '🚙' => 'vettura għal utilità sportiva',
    '🚚' => 'trakk tal-konsenji',
    '🚛' => 'trakk artikolat',
    '🚜' => 'trattur',
    '🏎' => 'tlielaq tal-karozzi',
    '🏍' => 'mutur',
    '🛵' => 'scooter bil-mutur',
    '🚲' => 'rota',
    '🛴' => 'scooter',
    '🚏' => 'bus stop',
    '🛣' => 'awtostrada',
    '🛤' => 'linja tal-ferrovija',
    '🛢' => 'landa żejt',
    '⛽' => 'pompa tal-petrol',
    '🚨' => 'dawl tal-karozza tal-pulizija',
    '🚥' => 'dawl tat-traffiku orizzontali',
    '🚦' => 'dawl tat-traffiku vertikali',
    '🛑' => 'sinjal biex tieqaf',
    '🚧' => 'kostruzzjoni',
    '⚓' => 'ankra',
    '⛵' => 'dgħajsa bil-qlugħ',
    '🛶' => 'canoe',
    '🚤' => 'speedboat',
    '🛳' => 'vapur tal-passiġġieri',
    '⛴' => 'lanċa',
    '🛥' => 'dgħajsa bil-mutur',
    '🚢' => 'vapur',
    '✈' => 'ajruplan',
    '🛩' => 'ajruplan żgħir',
    '🛫' => 'tluq ta’ ajruplan',
    '🛬' => 'wasla ta’ ajruplan',
    '💺' => 'sedil',
    '🚁' => 'elikotteru',
    '🚟' => 'ferrovija fuq sospensjoni',
    '🚠' => 'funikular tal-muntanji',
    '🚡' => 'linja tat-ramm fl-ajru',
    '🛰' => 'satellita',
    '🚀' => 'rokit',
    '🛸' => 'flying saucer',
    '🛎' => 'qanpiena ta’ bellhop',
    '⌛' => 'klessidra',
    '⏳' => 'klessidra bir-ramel nieżel',
    '⌚' => 'arloġġ',
    '⏰' => 'żveljarin',
    '⏱' => 'stopwatch',
    '⏲' => 'kronometru tal-arloġġ',
    '🕰' => 'arloġġ ta’ fuq l-ixkaffa',
    '🕛' => 'nofsinhar',
    '🕧' => 'in-nofs siegħa',
    '🕐' => 'is-siegħa',
    '🕜' => 'is-siegħa u nofs',
    '🕑' => 'is-sagħtejn',
    '🕝' => 'is-sagħtejn u nofs',
    '🕒' => 'it-tlieta',
    '🕞' => 'it-tlieta u nofs',
    '🕓' => 'l-erbgħa',
    '🕟' => 'l-erbgħa u nofs',
    '🕔' => 'il-ħamsa',
    '🕠' => 'il-ħamsa u nofs',
    '🕕' => 'is-sitta',
    '🕡' => 'is-sitta u nofs',
    '🕖' => 'is-sebgħa',
    '🕢' => 'is-sebgħa u nofs',
    '🕗' => 'it-tmienja',
    '🕣' => 'it-tmienja u nofs',
    '🕘' => 'id-disgħa',
    '🕤' => 'id-disgħa u nofs',
    '🕙' => 'l-għaxra',
    '🕥' => 'l-għaxra u nofs',
    '🕚' => 'il-ħdax',
    '🕦' => 'il-ħdax u nofs',
    '🌑' => 'qamar ġdid',
    '🌒' => 'felli qamar qed jikber',
    '🌓' => 'l-ewwel kwart tal-qamar',
    '🌔' => 'qamar akbar minn nofs li qed jikber',
    '🌕' => 'qamar sħiħ',
    '🌖' => 'qamar akbar minn nofs li qed jonqos',
    '🌗' => 'l-aħħar kwart tal-qamar',
    '🌘' => 'felli qamar li qed jonqos',
    '🌙' => 'felli qamar',
    '🌚' => 'wiċċ ta’ qamar ġdid',
    '🌛' => 'wiċċ tal-ewwel kwart tal-qamar',
    '🌜' => 'wiċċ tal-aħħar kwart tal-qamar',
    '🌡' => 'termometru',
    '☀' => 'xemx',
    '🌝' => 'wiċċ ta’ qamar sħiħ',
    '🌞' => 'xemx b’wiċċ',
    '⭐' => 'stilla medja bajda',
    '🌟' => 'stilla tiddi',
    '🌠' => 'stilla feġġa',
    '🌌' => 'triq ta’ Sant’Anna',
    '☁' => 'sħaba',
    '⛅' => 'xemx wara sħaba',
    '⛈' => 'sħaba b’sajjetti u x-xita',
    '🌤' => 'xemx wara sħaba żgħira',
    '🌥' => 'xemx wara sħaba kbira',
    '🌦' => 'xemx wara sħaba tax-xita',
    '🌧' => 'sħaba bix-xita',
    '🌨' => 'sħaba bis-silġ',
    '🌩' => 'sħaba bis-sajjetti',
    '🌪' => 'tornado',
    '🌫' => 'ċpar',
    '🌬' => 'wiċċ tar-riħ',
    '🌀' => 'ċiklun',
    '🌈' => 'qawsalla',
    '🌂' => 'umbrella magħluqa',
    '☂' => 'umbrella',
    '☔' => 'umbrella bi qtar tax-xita',
    '⛱' => 'umbrella fuq art',
    '⚡' => 'vultaġġ għoli',
    '❄' => 'farka borra',
    '☃' => 'borrinu',
    '⛄' => 'borrinu mingħajr borra',
    '☄' => 'kometa',
    '🔥' => 'nar',
    '💧' => 'qattra',
    '🌊' => 'mewġa ilma',
    '🎃' => 'jack-o-lantern',
    '🎄' => 'siġra tal-Milied',
    '🎆' => 'logħob tan-nar',
    '🎇' => 'sparkler',
    '✨' => 'tlellix',
    '🎈' => 'bużżieqa',
    '🎉' => 'party popper',
    '🎊' => 'ballun konfetti',
    '🎋' => 'siġra tat-tanabata',
    '🎍' => 'dekorazzjoni tal-arżnu',
    '🎎' => 'pupi Ġappuniżi',
    '🎏' => 'streamer ta’ karpjun',
    '🎐' => 'qniepen tar-riħ',
    '🎑' => 'ċerimonja biex tara l-qamar',
    '🎀' => 'żigarella',
    '🎁' => 'rigal imgeżwer',
    '🎗' => 'żigarella ta’ tfakkira',
    '🎟' => 'biljetti tad-dħul',
    '🎫' => 'biljett',
    '🎖' => 'midalja militari',
    '🏆' => 'trofew',
    '🏅' => 'midalja sportiva',
    '🥇' => 'midalja tal-1 post',
    '🥈' => 'midalja tat-2 post',
    '🥉' => 'midalja tat-3 post',
    '⚽' => 'ballun tal-futbol',
    '⚾' => 'baseball',
    '🏀' => 'basketball',
    '🏐' => 'volleyball',
    '🏈' => 'futbol Amerikan',
    '🏉' => 'futbol tar-rugby',
    '🎾' => 'tennis',
    '🎳' => 'bowling',
    '🏏' => 'logħba tal-cricket',
    '🏑' => 'field hockey',
    '🏒' => 'ice hockey',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'ingwanta tal-boxing',
    '🥋' => 'uniformi tal-arti marzjali',
    '🥅' => 'xibka tal-gowl',
    '⛳' => 'bandiera fit-toqba',
    '⛸' => 'skating fuq is-silġ',
    '🎣' => 'qasba tas-sajd',
    '🎽' => 'qmis tal-ġiri',
    '🎿' => 'skis',
    '🛷' => 'slitta',
    '🥌' => 'ġebla tal-curling',
    '🎯' => 'tir dirett',
    '🔫' => 'pistola',
    '🎱' => 'ballun ta’ pool 8',
    '🔮' => 'boċċa tal-kristal',
    '🎮' => 'video game',
    '🕹' => 'joystick',
    '🎰' => 'slot machine',
    '🎲' => 'dadi tal-logħob',
    '♠' => 'taqsima tal-ispati',
    '♥' => 'taqsima tal-kwori',
    '♦' => 'taqsima tad-denari',
    '♣' => 'taqsima tal-fjuri',
    '🃏' => 'joker',
    '🀄' => 'mahjong red dragon',
    '🎴' => 'fjuri tal-karti tal-logħob',
    '🎭' => 'arti, żfin u mużika',
    '🖼' => 'stampa fi frejm',
    '🎨' => 'tavlozza',
    '👓' => 'nuċċali',
    '🕶' => 'nuċċali tax-xemx',
    '👔' => 'ingravata',
    '👕' => 't-shirt',
    '👖' => 'jeans',
    '🧣' => 'xalpa',
    '🧤' => 'ingwanti',
    '🧥' => 'kowt',
    '🧦' => 'kalzetti qosra',
    '👗' => 'libsa',
    '👘' => 'kimono',
    '👙' => 'bikini',
    '👚' => 'ħwejjeġ ta’ mara',
    '👛' => 'portmoni',
    '👜' => 'handbag',
    '👝' => 'kartiera',
    '🛍' => 'basktijiet tax-xiri',
    '🎒' => 'basket tal-iskola',
    '👞' => 'żarbun tal-irġiel',
    '👟' => 'papoċċ tal-ġiri',
    '👠' => 'żarbun b’takkuna għolja',
    '👡' => 'sandli ta’ mara',
    '👢' => 'buts ta’ mara',
    '👑' => 'kuruna',
    '👒' => 'kappell ta’ mara',
    '🎩' => 'kpiepel top',
    '🎓' => 'berettin tal-gradwazzjoni',
    '🧢' => 'kappell',
    '⛑' => 'l-elmu tal-ħaddiem tas-salvataġġ',
    '📿' => 'żibeġ tat-talb',
    '💄' => 'lipstick',
    '💍' => 'ċurkett',
    '💎' => 'ġawhra',
    '🔇' => 'muted ta ’ l-ispiker',
    '🔈' => 'speaker volum baxx',
    '🔉' => 'speaker volum medju',
    '🔊' => 'speaker volum għoli',
    '📢' => 'loudspeaker',
    '📣' => 'megafonu',
    '📯' => 'tromba postali',
    '🔔' => 'qanpiena',
    '🔕' => 'qanpiena bi slash',
    '🎼' => 'partitura mużikali',
    '🎵' => 'nota mużikali',
    '🎶' => 'noti mużikali',
    '🎙' => 'mikrofonu tal-istudjo',
    '🎚' => 'slajder tal-livell',
    '🎛' => 'pumi tal-kontroll',
    '🎤' => 'mikrofonu',
    '🎧' => 'headphone',
    '📻' => 'radju',
    '🎷' => 'sassofonu',
    '🎺' => 'trumbetta',
    '🎸' => 'kitarra',
    '🎹' => 'tastiera mużikali',
    '🎻' => 'vjolin',
    '🥁' => 'tanbur',
    '📱' => 'mowbajl',
    '📲' => 'mowbajl bi vleġġa',
    '☎' => 'telefon',
    '📞' => 'riċevitur tat-telefon',
    '📟' => 'pejġer',
    '📠' => 'magna tal-fax',
    '🔋' => 'batterija',
    '🔌' => 'plagga elettrika',
    '💻' => 'kompjuter laptop',
    '🖥' => 'kompjuter desktop',
    '🖨' => 'printer',
    '⌨' => 'tastiera',
    '🖱' => 'maws tal-kompjuter',
    '🖲' => 'trackball',
    '💽' => 'diska tal-kompjuter',
    '💾' => 'diskett',
    '💿' => 'diska ottika',
    '📀' => 'dvd',
    '🎥' => 'kamera tal-films',
    '🎞' => 'frejms tal-film',
    '📽' => 'projettur tal-filmati',
    '🎬' => 'clapper board',
    '📺' => 'televiżjoni',
    '📷' => 'kamera',
    '📸' => 'kamera bi flash',
    '📹' => 'vidjo kamera',
    '📼' => 'videocassette',
    '🔍' => 'lenti tat-tkabbir tipponta xellug',
    '🔎' => 'lenti tat-tkabbir tipponta Lemin',
    '🕯' => 'xemgħa',
    '💡' => 'bozza',
    '🔦' => 'torċ',
    '🏮' => 'lanterna tal-karti ħamra',
    '📔' => 'notebook b’kopertura dekorattiva',
    '📕' => 'ktieb magħluq',
    '📖' => 'ktieb miftuħ',
    '📗' => 'ktieb aħdar',
    '📘' => 'ktieb blu',
    '📙' => 'ktieb oranġjo',
    '📚' => 'kotba',
    '📓' => 'notebook',
    '📒' => 'leġer',
    '📃' => 'paġna b’nokkla',
    '📜' => 'skrollja',
    '📄' => 'paġna wiċċha ’l fuq',
    '📰' => 'gazzetta',
    '🗞' => 'gazzetti rromblati',
    '📑' => 'tabs tal-bookmarks',
    '🔖' => 'bookmark',
    '🏷' => 'tikketta',
    '💰' => 'borża tal-flus',
    '💴' => 'karta tal-flus yen',
    '💵' => 'karta tal-flus dollaru',
    '💶' => 'karta tal-flus ewro',
    '💷' => 'karta tal-flus lira sterlina',
    '💸' => 'flus bil-ġwienaħ',
    '💳' => 'karta tal-kreditu',
    '💹' => 'ċart tiżdied bil-yen',
    '✉' => 'envelop',
    '📧' => 'posta elettronika',
    '📨' => 'envelop dieħel',
    '📩' => 'envelop bi vleġġa',
    '📤' => 'trej tal-posta ħierġa',
    '📥' => 'trej tal-posta rċivuta',
    '📦' => 'pakkett',
    '📫' => 'kaxxa tal-ittri magħluqa bil-bandiera mtellgħa',
    '📪' => 'kaxxa tal-ittri magħluqa bil-bandiera mniżżla',
    '📬' => 'kaxxa tal-ittri miftuħa bil-bandiera mtellgħa',
    '📭' => 'kaxxa tal-ittri miftuħa bil-bandiera mniżżla',
    '📮' => 'kaxxa tal-ittri',
    '🗳' => 'kaxxa tal-votazzjoni b’votazzjoni',
    '✏' => 'lapes',
    '✒' => 'ponta sewda',
    '🖋' => 'fountain pen',
    '🖊' => 'pinna',
    '🖌' => 'pinzell',
    '🖍' => 'crayon',
    '📝' => 'memo',
    '💼' => 'briefcase',
    '📁' => 'fowlder tal-fajls',
    '📂' => 'fowlder tal-fajls miftuħ',
    '🗂' => 'kard dividers tal-indiċi tal-biljett',
    '📅' => 'kalendarju',
    '📆' => 'kalendarju bil-karti jitqaċċtu',
    '🗒' => 'notepad spirali',
    '🗓' => 'kalendarju spirali',
    '📇' => 'indiċi tal-kards',
    '📈' => 'ċart tiżdied',
    '📉' => 'ċart tonqos',
    '📊' => 'barċart',
    '📋' => 'klibbord',
    '📌' => 'pushpin',
    '📍' => 'pushpin tond',
    '📎' => 'paperclip',
    '🖇' => 'paperclips illinkjati',
    '📏' => 'riga dritta',
    '📐' => 'riga trijangulari',
    '✂' => 'imqass',
    '🗃' => 'kaxxa tal-biljetti tal-fajl',
    '🗄' => 'kabinet tal-fajls',
    '🗑' => 'landa tal-iskart',
    '🔒' => 'imsakkar',
    '🔓' => 'mhux imsakkar',
    '🔏' => 'imsakkar b’pinna',
    '🔐' => 'msakkar b’ċavetta',
    '🔑' => 'ċavetta',
    '🗝' => 'ċavetta qadima',
    '🔨' => 'martell',
    '⛏' => 'agħżel',
    '⚒' => 'martell u fies',
    '🛠' => 'martell u spaner',
    '🗡' => 'stallet',
    '⚔' => 'xwabel inkroċjati',
    '💣' => 'bomba',
    '🏹' => 'qaws u vleġġa',
    '🛡' => 'tarka',
    '🔧' => 'spanner',
    '🔩' => 'vit u skorfina',
    '⚙' => 'apparat',
    '🗜' => 'klamp',
    '⚖' => 'miżien',
    '🔗' => 'katina',
    '⛓' => 'ktajjen',
    '⚗' => 'lampik',
    '🔬' => 'mikroskopju',
    '🔭' => 'teleskopju',
    '📡' => 'antenna tas-satellita',
    '💉' => 'siringa',
    '💊' => 'pillola',
    '🚪' => 'bieb',
    '🛏' => 'sodda',
    '🛋' => 'sufan u lampa',
    '🚽' => 'toilet',
    '🚿' => 'doxxa',
    '🛁' => 'banju',
    '🛒' => 'basket tax-xiri',
    '🚬' => 'sigarett',
    '⚰' => 'tebut',
    '⚱' => 'urna tal-funerali',
    '🗿' => 'moai',
    '🏧' => 'tabella tal-ATM',
    '🚮' => 'tabella ta’ barmil taż-żibel',
    '🚰' => 'ilma tax-xorb',
    '♿' => 'simbolu ta’ siġġu tar-roti',
    '🚹' => 'kamra tal-irġiel',
    '🚺' => 'kamra tan-nisa',
    '🚻' => 'toilets',
    '🚼' => 'simbolu ta’ trabi',
    '🚾' => 'wc',
    '🛂' => 'kontroll tal-passaport',
    '🛃' => 'dwana',
    '🛄' => 'uffiċċju tal-bagalji',
    '🛅' => 'bagalji mitlufa',
    '⚠' => 'twissija',
    '🚸' => 'tfal jaqsmu',
    '⛔' => 'ebda dħul',
    '🚫' => 'projbit',
    '🚳' => 'ebda rota',
    '🚭' => 'tipjip mhux permess',
    '🚯' => 'ebda rimi',
    '🚱' => 'ilma mhux tajjeb għax-xorb',
    '🚷' => 'ebda nies pedonali',
    '📵' => 'ebda mowbajl',
    '🔞' => 'ħadd taħt it-tmintax',
    '☢' => 'radjoattiv',
    '☣' => 'perikolu bijoloġiku',
    '⬆' => 'vleġġa ’l fuq',
    '↗' => 'vleġġa ’l fuq leminija',
    '➡' => 'vleġġa leminija',
    '↘' => 'vleġġa ’l isfel leminija',
    '⬇' => 'vleġġa ’l isfel',
    '↙' => 'vleġġa xellugija ’l isfel',
    '⬅' => 'vleġġa xellugija',
    '↖' => 'vleġġa xellugija ’l fuq',
    '↕' => 'vleġġa ’l isfel u ’l isfel',
    '↔' => 'vleġġa ’l isfel xellugija',
    '↩' => 'vleġġa leminija mgħawġa lejn ix-xellug',
    '↪' => 'vleġġa tax-xellug mgħawġa lejn il-lemin',
    '⤴' => 'vleġġa leminija mgħawġa ’l fuq',
    '⤵' => 'vleġġa leminija mgħawġa ’l isfel',
    '🔃' => 'vleġeġ vertikali favur l-arloġġ',
    '🔄' => 'buttuna vleġeġ kontra l-arloġġ',
    '🔙' => 'vleġġa BACK',
    '🔚' => 'vleġġa END',
    '🔛' => 'vleġġa ON!',
    '🔜' => 'vleġġa SOON',
    '🔝' => 'vleġġa TOP',
    '🛐' => 'post ta’ qima',
    '⚛' => 'simbolu tal-atomu',
    '🕉' => 'om',
    '✡' => 'l-istilla ta’ David',
    '☸' => 'ir-rota ta’ dharma',
    '☯' => 'yin yang',
    '✝' => 'salib latin',
    '☦' => 'salib ortodoss',
    '☪' => 'stilla u nofs qamar',
    '☮' => 'is-simbolu tal-paċi',
    '🕎' => 'menora',
    '🔯' => 'stilla bit-tikek b’sitt ponot',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Cancer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpius',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'buttuna shuffle tracks',
    '🔁' => 'buttuna irrepeti',
    '🔂' => 'buttuna irrepeti darba',
    '▶' => 'il-buttuna aqra',
    '⏩' => 'buttuna fast-forward',
    '⏭' => 'buttuna trekk li jmiss',
    '⏯' => 'buttuna aqra jew issospendi',
    '◀' => 'buttuna reverse',
    '⏪' => 'buttuna fast reverse',
    '⏮' => 'buttuna l-aħħar trekk',
    '🔼' => 'buttuna up',
    '⏫' => 'buttuna fast up',
    '🔽' => 'buttuna down',
    '⏬' => 'buttuna fast down',
    '⏸' => 'buttuna issospendi',
    '⏹' => 'buttuna waqqaf',
    '⏺' => 'buttuna tar-rekord',
    '⏏' => 'il-buttuna oħroġ',
    '🎦' => 'ċinema',
    '🔅' => 'buttuna dim',
    '🔆' => 'buttuna bright',
    '📶' => 'virgi tal-antenna',
    '📳' => 'mod ta’ vibrazzjoni',
    '📴' => 'mowbajl mitfi',
    '♀' => 'sinjal femminili',
    '♂' => 'sinjal maskili',
    '✖' => 'multiplikazzjoni grassett x',
    '➕' => 'sinjal plus grassett',
    '➖' => 'sinjal minus grassett',
    '➗' => 'sinjal diviżjoni grassett',
    '‼' => 'punt doppju esklamattiv',
    '⁉' => 'punt interrogattiv ta’ esklamazzjoni',
    '❓' => 'punt interrogattiv',
    '❔' => 'punt interrogattiv abjad',
    '❕' => 'punt esklamattiv abjad',
    '❗' => 'punt esklamattiv',
    '〰' => 'sing immewwweġ',
    '💱' => 'kambju tal-munita',
    '💲' => 'sinjal tad-dollaru grassett',
    '⚕' => 'simbolu mediku',
    '♻' => 'simbolu tar-riċiklaġġ',
    '⚜' => 'fleur-de-lis',
    '🔱' => 'emblema trident',
    '📛' => 'beġġ bl-isem',
    '🔰' => 'simbolu Ġappuniż għal prinċipjant',
    '⭕' => 'ċirku kbir grassett',
    '✅' => 'marka ta’ verifika bajda grassett',
    '☑' => 'kaxxa tal-votazzjoni b’marka',
    '✔' => 'marka ta’ verifika grassett',
    '❌' => 'marka salib',
    '❎' => 'buttuna ta’ marka salib',
    '➰' => 'loop innukklata',
    '➿' => 'loop innukklata doppja',
    '〽' => 'marka ta’ alternanza ta’ parti',
    '✳' => 'stilla bi tmien linji',
    '✴' => 'stilla bi tmien ponot',
    '❇' => 'ileħħ',
    '™' => 'trade mark',
    '🔠' => 'input latin kapitali',
    '🔡' => 'input latin ittra żgħira',
    '🔢' => 'numri tal-input',
    '🔣' => 'simboli tal-input',
    '🔤' => 'input ittri latin',
    '🅰' => 'buttuna A (tip tad-demm)',
    '🆎' => 'buttuna AB (tip tad-demm)',
    '🅱' => 'buttuna B (tip tad-demm)',
    '🆑' => 'buttuna CL',
    '🆒' => 'buttuna COOL',
    '🆓' => 'buttuna FREE',
    'ℹ' => 'informazzjoni',
    '🆔' => 'buttuna ID',
    'Ⓜ' => 'ċirku M',
    '🆕' => 'buttuna NEW',
    '🆖' => 'buttuna NG',
    '🅾' => 'buttuna O (tip tad-demm)',
    '🆗' => 'buttuna OK',
    '🅿' => 'buttuna P',
    '🆘' => 'buttuna SOS',
    '🆚' => 'buttuna VS',
    '🈁' => 'buttuna Ġappuniż “hawn”',
    '🈂' => 'buttuna Ġappuniż “imposta’ għal servizz“',
    '🈷' => 'buttuna Ġappuniż “ammont ta’ kull xahar”',
    '🈶' => 'buttuna Ġappuniż “mhux Bla Ħlas”',
    '🈯' => 'buttuna Ġappuniż “riservat”',
    '🉐' => 'buttuna Ġappuniż “bargain”',
    '🈹' => 'buttuna Ġappuniż “skont”',
    '🈚' => 'buttuna Ġappuniż “bla ħlas”',
    '🈲' => 'buttuna Ġappuniż “projbit”',
    '🉑' => 'buttuna Ġappuniż “aċċettabbli”',
    '🈸' => 'buttuna Ġappuniż “applikazzjoni”',
    '🈴' => 'buttuna Ġappuniż “li jgħaddi l-grad”',
    '🈳' => 'buttuna Ġappuniż “post battal”',
    '㊗' => 'buttuna Ġappuniż “awguri”',
    '㊙' => 'buttuna Ġappuniż “sigriet”',
    '🈺' => 'buttuna Ġappuniż “miftuħ għan-negozju”',
    '🈵' => 'buttuna Ġappuniż “ebda post battal”',
    '🔴' => 'ċirku aħmar',
    '🔵' => 'ċirku blu',
    '⚫' => 'ċirku iswed',
    '⚪' => 'ċirku abjad',
    '⬛' => 'kwadrat kbir iswed',
    '⬜' => 'kwadrat kbir abjad',
    '◼' => 'kwadrat medju iswed',
    '◻' => 'kwadrat medju abjad',
    '◾' => 'kwadrat medju żgħar iswed',
    '◽' => 'kwadrat medju żgħar abjad',
    '▪' => 'kwadri żgħir iswed',
    '▫' => 'kwadrat żgħir abjad',
    '🔶' => 'djamant kbir oranġjo',
    '🔷' => 'djamant kbir blu',
    '🔸' => 'djamant żgħir oranġjo',
    '🔹' => 'djamant żgħir blu',
    '🔺' => 'trijangolu aħmar jipponta ’l fuq',
    '🔻' => 'trijangolu aħmar jipponta ’l isfel',
    '💠' => 'djamant b’tikka',
    '🔘' => 'buttuna tal-għażla',
    '🔳' => 'buttuna kwadra bajda',
    '🔲' => 'buttuna kwadra sewda',
    '🏁' => 'bandiera bil-kaxxi',
    '🚩' => 'bandiera trijangolari',
    '🎌' => 'bnadar inkroċjati',
    '🏴' => 'bandiera sewda',
    '🏳' => 'bandiera bajda',
];
